# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Kansas."""


ABBYVILLE_CITY = "00100"
ABILENE_CITY = "00125"
ADA_CDP = "00225"
ADMIRE_CITY = "00325"
AGENDA_CITY = "00475"
AGRA_CITY = "00550"
ALBERT_CITY = "00825"
ALDEN_CITY = "00950"
ALEXANDER_CITY = "01050"
ALLEN_CITY = "01275"
ALMA_CITY = "01350"
ALMENA_CITY = "01425"
ALTA_VISTA_CITY = "01575"
ALTAMONT_CITY = "01550"
ALTON_CITY = "01600"
ALTOONA_CITY = "01625"
AMERICUS_CITY = "01675"
AMES_CDP = "01725"
ANDALE_CITY = "01775"
ANDOVER_CITY = "01800"
ANTHONY_CITY = "01975"
ARCADIA_CITY = "02175"
ARGONIA_CITY = "02250"
ARKANSAS_CITY_CITY = "02300"
ARLINGTON_CITY = "02325"
ARMA_CITY = "02375"
ASHERVILLE_CDP = "02600"
ASHLAND_CITY = "02675"
ASSARIA_CITY = "02850"
ATCHISON_CITY = "02900"
ATHOL_CITY = "03025"
ATLANTA_CITY = "03050"
ATTICA_CITY = "03100"
ATWOOD_CITY = "03150"
AUBURN_CITY = "03250"
AUGUSTA_CITY = "03300"
AURORA_CITY = "03425"
AXTELL_CITY = "03600"
BAILEYVILLE_CDP = "03675"
BALA_CDP = "03800"
BALDWIN_CITY_CITY = "03900"
BARNARD_CITY = "04225"
BARNES_CITY = "04250"
BARTLETT_CITY = "04350"
BASEHOR_CITY = "04400"
BASSETT_CITY = "04450"
BAVARIA_CDP = "04575"
BAXTER_SPRINGS_CITY = "04625"
BAZINE_CITY = "04775"
BEATTIE_CITY = "04900"
BEAUMONT_CDP = "04925"
BEAVER_CDP = "04950"
BEL_AIRE_CITY = "05337"
BELLE_PLAINE_CITY = "05500"
BELLEVILLE_CITY = "05600"
BELOIT_CITY = "05775"
BELPRE_CITY = "05825"
BELVUE_CITY = "05925"
BENDENA_CDP = "05975"
BENEDICT_CITY = "06000"
BENNINGTON_CITY = "06075"
BENTLEY_CITY = "06125"
BENTON_CITY = "06175"
BERN_CITY = "06275"
BEVERLY_CITY = "06500"
BIG_BOW_CDP = "06575"
BIRD_CITY_CITY = "06825"
BISON_CITY = "06950"
BLUE_MOUND_CITY = "07600"
BLUE_RAPIDS_CITY = "07650"
BLUFF_CITY_CITY = "07775"
BOGUE_CITY = "07825"
BONNER_SPRINGS_CITY = "07975"
BREMEN_CDP = "08300"
BREWSTER_CITY = "08425"
BRIDGEPORT_CDP = "08450"
BRONSON_CITY = "08475"
BROOKVILLE_CITY = "08575"
BROWNELL_CITY = "08675"
BUCKLIN_CITY = "09000"
BUCYRUS_CDP = "09050"
BUFFALO_CITY = "09150"
BUHLER_CITY = "09200"
BUNKER_HILL_CITY = "09225"
BURDEN_CITY = "09250"
BURDETT_CITY = "09275"
BURDICK_CDP = "09300"
BURLINGAME_CITY = "09350"
BURLINGTON_CITY = "09400"
BURNS_CITY = "09450"
BURR_OAK_CITY = "09525"
BURRTON_CITY = "09575"
BUSHONG_CITY = "09675"
BUSHTON_CITY = "09700"
BYERS_CITY = "09800"
CALDWELL_CITY = "09900"
CAMBRIDGE_CITY = "10125"
CANEY_CITY = "10375"
CANTON_CITY = "10475"
CARBONDALE_CITY = "10600"
CARLTON_CITY = "10675"
CASSODAY_CITY = "10925"
CATHARINE_CDP = "11025"
CAWKER_CITY_CITY = "11175"
CEDAR_POINT_CITY = "11425"
CEDAR_VALE_CITY = "11450"
CEDAR_CITY = "11325"
CENTERVILLE_CDP = "12325"
CENTRALIA_CITY = "12425"
CENTROPOLIS_CDP = "12450"
CHANUTE_CITY = "12500"
CHAPMAN_CITY = "12550"
CHASE_CITY = "12650"
CHAUTAUQUA_CITY = "12675"
CHENEY_CITY = "12775"
CHEROKEE_CITY = "12825"
CHERRYVALE_CITY = "12925"
CHETOPA_CITY = "12950"
CHICOPEE_CDP = "13100"
CIMARRON_CITY = "13275"
CIRCLEVILLE_CITY = "13375"
CLAFLIN_CITY = "13425"
CLAY_CENTER_CITY = "13625"
CLAYTON_CITY = "13675"
CLEARWATER_CITY = "13925"
CLIFTON_CITY = "14200"
CLIMAX_CITY = "14275"
CLYDE_CITY = "14475"
COATS_CITY = "14525"
CODELL_CDP = "14575"
COFFEYVILLE_CITY = "14600"
COLBY_CITY = "14650"
COLDWATER_CITY = "14700"
COLLYER_CITY = "14900"
COLONY_CITY = "14950"
COLUMBUS_CITY = "15075"
COLWICH_CITY = "15100"
CONCORDIA_CITY = "15200"
CONWAY_SPRINGS_CITY = "15325"
COOLIDGE_CITY = "15400"
COPELAND_CITY = "15475"
CORNING_CITY = "15725"
COTTONWOOD_FALLS_CITY = "15900"
COUNCIL_GROVE_CITY = "15925"
COURTLAND_CITY = "16025"
COYVILLE_CITY = "16150"
CRESTLINE_CDP = "16325"
CROWEBURG_CDP = "16475"
CUBA_CITY = "16625"
CULLISON_CITY = "16675"
CULVER_CITY = "16700"
CUNNINGHAM_CITY = "16775"
DAMAR_CITY = "16975"
DANVILLE_CITY = "17000"
DE_SOTO_CITY = "17850"
DEARING_CITY = "17150"
DEERFIELD_CITY = "17225"
DELIA_CITY = "17525"
DELPHOS_CITY = "17600"
DENISON_CITY = "17625"
DENNIS_CDP = "17675"
DENTON_CITY = "17750"
DERBY_CITY = "17800"
DETROIT_CDP = "17875"
DEVON_CDP = "17900"
DEXTER_CITY = "17925"
DIGHTON_CITY = "18050"
DODGE_CITY_CITY = "18250"
DORRANCE_CITY = "18325"
DOUGLASS_CITY = "18400"
DOWNS_CITY = "18500"
DRESDEN_CITY = "18600"
DUNLAP_CITY = "18950"
DURHAM_CITY = "19050"
DWIGHT_CITY = "19125"
EARLTON_CITY = "19275"
EASTBOROUGH_CITY = "19300"
EASTON_CITY = "19600"
EASTSHORE_CDP = "19700"
EDGERTON_CITY = "19825"
EDMOND_CITY = "19875"
EDNA_CITY = "19900"
EDSON_CDP = "19925"
EDWARDSVILLE_CITY = "20000"
EFFINGHAM_CITY = "20025"
EL_DORADO_CITY = "20075"
ELBING_CITY = "20050"
ELGIN_CITY = "20125"
ELK_CITY_CITY = "20250"
ELK_FALLS_CITY = "20300"
ELKHART_CITY = "20350"
ELLINWOOD_CITY = "20425"
ELLIS_CITY = "20450"
ELLSWORTH_CITY = "20500"
ELMDALE_CITY = "20675"
ELSMORE_CITY = "20875"
ELWOOD_CITY = "20950"
ELYRIA_CDP = "20975"
EMMETT_CITY = "21100"
EMPORIA_CITY = "21275"
ENGLEWOOD_CITY = "21350"
ENSIGN_CITY = "21400"
ENTERPRISE_CITY = "21425"
ERIE_CITY = "21500"
ESBON_CITY = "21600"
ESKRIDGE_CITY = "21650"
EUDORA_CITY = "21675"
EUREKA_CITY = "21800"
EVEREST_CITY = "22025"
FAIRVIEW_CITY = "22425"
FAIRWAY_CITY = "22700"
FALL_RIVER_CITY = "22775"
FALUN_CDP = "22900"
FARLINGTON_CDP = "23050"
FLORENCE_CITY = "23600"
FONTANA_CITY = "23650"
FORD_CITY = "23725"
FORMOSO_CITY = "23825"
FORT_DODGE_CDP = "23890"
FORT_RILEY_CDP = "23975"
FORT_SCOTT_CITY = "24000"
FOWLER_CITY = "24175"
FRANKFORT_CITY = "24275"
FRANKLIN_CDP = "24325"
FREDERICK_CITY = "24550"
FREDONIA_CITY = "24575"
FRONTENAC_CITY = "24850"
FULTON_CITY = "24925"
FURLEY_CDP = "24975"
GALATIA_CITY = "25050"
GALENA_CITY = "25100"
GALESBURG_CITY = "25150"
GALVA_CITY = "25200"
GARDEN_CITY_CITY = "25325"
GARDEN_PLAIN_CITY = "25375"
GARDNER_CITY = "25425"
GARFIELD_CITY = "25750"
GARLAND_CDP = "25900"
GARNETT_CITY = "25925"
GAS_CITY = "25975"
GAYLORD_CITY = "26000"
GEM_CITY = "26050"
GENESEO_CITY = "26075"
GEUDA_SPRINGS_CITY = "26200"
GIRARD_CITY = "26300"
GLADE_CITY = "26325"
GLASCO_CITY = "26375"
GLEN_ELDER_CITY = "26500"
GODDARD_CITY = "26725"
GOESSEL_CITY = "26750"
GOFF_CITY = "26775"
GOODLAND_CITY = "26875"
GORHAM_CITY = "27000"
GOVE_CITY_CITY = "27125"
GRAINFIELD_CITY = "27200"
GRANDVIEW_PLAZA_CITY = "27425"
GRANTVILLE_CDP = "28200"
GREAT_BEND_CITY = "28300"
GREELEY_COUNTY_UNIFIED_GOVERNMENT_BALANCE = "28412"
GREELEY_CITY = "28350"
GREEN_CITY = "28425"
GREENLEAF_CITY = "28625"
GREENSBURG_CITY = "28675"
GREENWICH_CDP = "28700"
GRENOLA_CITY = "28800"
GRIDLEY_CITY = "28850"
GRINNELL_CITY = "28900"
GYPSUM_CITY = "29250"
HADDAM_CITY = "29400"
HALLOWELL_CDP = "29550"
HALSTEAD_CITY = "29600"
HAMILTON_CITY = "29675"
HAMLIN_CITY = "29700"
HANOVER_CITY = "29875"
HANSTON_CITY = "29925"
HARDTNER_CITY = "30000"
HARPER_CITY = "30175"
HARRIS_CDP = "30250"
HARTFORD_CITY = "30475"
HARVEYVILLE_CITY = "30575"
HAVANA_CITY = "30700"
HAVEN_CITY = "30725"
HAVENSVILLE_CITY = "30775"
HAVILAND_CITY = "30825"
HAYS_CITY = "31100"
HAYSVILLE_CITY = "31125"
HAZELTON_CITY = "31150"
HEALY_CDP = "31200"
HEPLER_CITY = "31375"
HERINGTON_CITY = "31400"
HERKIMER_CDP = "31425"
HERNDON_CITY = "31475"
HESSTON_CITY = "31600"
HIAWATHA_CITY = "31675"
HIGHLAND_CITY = "31850"
HILL_CITY_CITY = "32175"
HILLSBORO_CITY = "32275"
HILLSDALE_CDP = "32300"
HOISINGTON_CITY = "32550"
HOLCOMB_CITY = "32575"
HOLLENBERG_CITY = "32650"
HOLTON_CITY = "32825"
HOLYROOD_CITY = "32850"
HOME_CDP = "32875"
HOPE_CITY = "33075"
HORACE_CITY = "33150"
HORTON_CITY = "33200"
HOWARD_CITY = "33250"
HOXIE_CITY = "33350"
HOYT_CITY = "33375"
HUDSON_CITY = "33400"
HUGOTON_CITY = "33425"
HUMBOLDT_CITY = "33450"
HUNNEWELL_CITY = "33500"
HUNTER_CITY = "33525"
HURON_CITY = "33575"
HUTCHINSON_CITY = "33625"
IDANA_CDP = "33700"
INDEPENDENCE_CITY = "33875"
INGALLS_CITY = "34225"
INMAN_CITY = "34275"
IOLA_CITY = "34300"
IONIA_CDP = "34350"
ISABEL_CITY = "34550"
IUKA_CITY = "34625"
JAMESTOWN_CITY = "34975"
JENNINGS_CITY = "35375"
JETMORE_CITY = "35450"
JEWELL_CITY = "35475"
JOHNSON_CITY_CITY = "35600"
JUNCTION_CITY_CITY = "35750"
KANOPOLIS_CITY = "35950"
KANORADO_CITY = "35975"
KANSAS_CITY_CITY = "36000"
KEATS_CDP = "36200"
KECHI_CITY = "36225"
KELLY_CDP = "36375"
KENSINGTON_CITY = "36550"
KICKAPOO_SITE_1_CDP = "36735"
KICKAPOO_SITE_2_CDP = "36736"
KICKAPOO_SITE_5_CDP = "36739"
KICKAPOO_SITE_6_CDP = "36740"
KICKAPOO_SITE_7_CDP = "36741"
KICKAPOO_TRIBAL_CENTER_CDP = "36744"
KINCAID_CITY = "36875"
KINGMAN_CITY = "36950"
KINSLEY_CITY = "37075"
KIOWA_CITY = "37125"
KIPP_CDP = "37200"
KIRWIN_CITY = "37275"
KISMET_CITY = "37325"
LA_CROSSE_CITY = "37500"
LA_CYGNE_CITY = "37575"
LA_HARPE_CITY = "37725"
LABETTE_CITY = "37375"
LAFONTAINE_CDP = "37675"
LAKE_CITY_CDP = "37875"
LAKE_QUIVIRA_CITY = "37975"
LAKIN_CITY = "38175"
LANCASTER_CITY = "38325"
LANE_CITY = "38400"
LANGDON_CITY = "38500"
LANSING_CITY = "38650"
LARNED_CITY = "38700"
LATHAM_CITY = "38775"
LATIMER_CITY = "38800"
LAWRENCE_CITY = "38900"
LEROY_CITY = "39650"
LEAVENWORTH_CITY = "39000"
LEAWOOD_CITY = "39075"
LEBANON_CITY = "39100"
LEBO_CITY = "39125"
LECOMPTON_CITY = "39150"
LEHIGH_CITY = "39225"
LENEXA_CITY = "39350"
LENORA_CITY = "39400"
LEON_CITY = "39450"
LEONA_CITY = "39475"
LEONARDVILLE_CITY = "39500"
LEOTI_CITY = "39550"
LEVANT_CDP = "39700"
LEWIS_CITY = "39725"
LIBERAL_CITY = "39825"
LIBERTY_CITY = "40250"
LIEBENTHAL_CITY = "40400"
LINCOLN_CENTER_CITY = "41300"
LINCOLNVILLE_CITY = "41325"
LINDSBORG_CITY = "41375"
LINN_VALLEY_CITY = "41465"
LINN_CITY = "41425"
LINWOOD_CITY = "41475"
LITTLE_RIVER_CITY = "41575"
LOGAN_CITY = "42100"
LONE_ELM_CITY = "42425"
LONG_ISLAND_CITY = "42600"
LONGFORD_CITY = "42575"
LONGTON_CITY = "42650"
LORRAINE_CITY = "42800"
LOST_SPRINGS_CITY = "42825"
LOUISBURG_CITY = "42875"
LOUISVILLE_CITY = "42925"
LOWELL_CDP = "43050"
LUCAS_CITY = "43150"
LUDELL_CDP = "43175"
LURAY_CITY = "43250"
LYNDON_CITY = "43350"
LYONS_CITY = "43525"
MACKSVILLE_CITY = "43850"
MADISON_CITY = "44050"
MAHASKA_CITY = "44150"
MAIZE_CITY = "44200"
MANCHESTER_CITY = "44225"
MANHATTAN_CITY = "44250"
MANKATO_CITY = "44300"
MANTER_CITY = "44375"
MAPLE_HILL_CITY = "44500"
MAPLETON_CITY = "44550"
MARIENTHAL_CDP = "44600"
MARION_CITY = "44750"
MARQUETTE_CITY = "44925"
MARYSVILLE_CITY = "45050"
MATFIELD_GREEN_CITY = "45150"
MAYETTA_CITY = "45250"
MAYFIELD_CITY = "45275"
MCCONNELL_AFB_CDP = "43675"
MCCRACKEN_CITY = "43700"
MCCUNE_CITY = "43725"
MCDONALD_CITY = "43750"
MCFARLAND_CITY = "43775"
MCLOUTH_CITY = "43900"
MCPHERSON_CITY = "43950"
MEADE_CITY = "45325"
MEDICINE_LODGE_CITY = "45500"
MELVERN_CITY = "45700"
MENLO_CITY = "45750"
MENTOR_CDP = "45875"
MERIDEN_CITY = "45950"
MERRIAM_CITY = "46000"
MILAN_CITY = "46450"
MILDRED_CDP = "46500"
MILFORD_CITY = "46525"
MILTON_CDP = "46925"
MILTONVALE_CITY = "46950"
MINNEAPOLIS_CITY = "47075"
MINNEOLA_CITY = "47150"
MISSION_HILLS_CITY = "47350"
MISSION_WOODS_CITY = "47425"
MISSION_CITY = "47225"
MOLINE_CITY = "47600"
MONT_IDA_CDP = "47975"
MONTEZUMA_CITY = "47875"
MONUMENT_CDP = "48025"
MORAN_CITY = "48125"
MORGANVILLE_CITY = "48225"
MORLAND_CITY = "48275"
MORRILL_CITY = "48300"
MORROWVILLE_CITY = "48450"
MOSCOW_CITY = "48600"
MOUND_CITY_CITY = "48750"
MOUND_VALLEY_CITY = "48825"
MOUNDRIDGE_CITY = "48800"
MOUNT_HOPE_CITY = "48900"
MULBERRY_CITY = "49025"
MULLINVILLE_CITY = "49075"
MULVANE_CITY = "49100"
MUNDEN_CITY = "49150"
MUNJOR_CDP = "49200"
MURDOCK_CDP = "49250"
MUSCOTAH_CITY = "49325"
NARKA_CITY = "49350"
NASHVILLE_CITY = "49400"
NATOMA_CITY = "49425"
NAVARRE_CDP = "49525"
NEAL_CDP = "49550"
NEODESHA_CITY = "49650"
NEOSHO_FALLS_CITY = "49825"
NEOSHO_RAPIDS_CITY = "49875"
NESS_CITY_CITY = "49925"
NETAWAKA_CITY = "49950"
NEW_ALBANY_CITY = "50150"
NEW_CAMBRIA_CITY = "50300"
NEW_SALEM_CDP = "50425"
NEW_STRAWN_CITY = "50450"
NEWBURY_CDP = "50250"
NEWTON_CITY = "50475"
NICKERSON_CITY = "50525"
NICODEMUS_CDP = "50550"
NILES_CDP = "50600"
NIOTAZE_CITY = "50750"
NORCATUR_CITY = "50925"
NORTH_NEWTON_CITY = "51225"
NORTON_CITY = "51500"
NORTONVILLE_CITY = "51525"
NORWAY_CDP = "51550"
NORWICH_CITY = "51600"
OAK_HILL_CITY = "51700"
OAKLAWN_SUNVIEW_CDP = "51810"
OAKLEY_CITY = "51825"
OBERLIN_CITY = "52000"
ODIN_CDP = "52175"
OFFERLE_CITY = "52200"
OGALLAH_CDP = "52225"
OGDEN_CITY = "52275"
OKETO_CITY = "52525"
OLATHE_CITY = "52575"
OLIVET_CITY = "52700"
OLMITZ_CITY = "52750"
OLPE_CITY = "52800"
OLSBURG_CITY = "52825"
ONAGA_CITY = "52875"
ONEIDA_CITY = "52900"
OPOLIS_CDP = "52925"
OSAGE_CITY_CITY = "53200"
OSAWATOMIE_CITY = "53225"
OSBORNE_CITY = "53325"
OSKALOOSA_CITY = "53375"
OSWEGO_CITY = "53450"
OTIS_CITY = "53525"
OTTAWA_CITY = "53550"
OVERBROOK_CITY = "53725"
OVERLAND_PARK_CITY = "53775"
OXFORD_CITY = "53850"
OZAWKIE_CITY = "53925"
PALCO_CITY = "54125"
PALMER_CITY = "54200"
PAOLA_CITY = "54250"
PARADISE_CITY = "54325"
PARK_CITY_CITY = "54450"
PARK_CITY = "54400"
PARKER_CITY = "54500"
PARKERFIELD_CITY = "54560"
PARKERVILLE_CITY = "54575"
PARSONS_CITY = "54675"
PARTRIDGE_CITY = "54700"
PAWNEE_ROCK_CITY = "54875"
PAXICO_CITY = "54950"
PEABODY_CITY = "55100"
PECK_CDP = "55175"
PENALOSA_CITY = "55225"
PERRY_CITY = "55450"
PERU_CITY = "55525"
PHILLIPSBURG_CITY = "55675"
PIEDMONT_CDP = "55750"
PIERCEVILLE_CDP = "55775"
PILSEN_CDP = "55875"
PIQUA_CDP = "56000"
PITTSBURG_CITY = "56025"
PLAINS_CITY = "56100"
PLAINVILLE_CITY = "56150"
PLEASANTON_CITY = "56450"
PLEVNA_CITY = "56725"
POMONA_CITY = "57000"
PORTIS_CITY = "57100"
POTWIN_CITY = "57300"
POWHATTAN_CITY = "57350"
PRAIRIE_VIEW_CITY = "57525"
PRAIRIE_VILLAGE_CITY = "57575"
PRATT_CITY = "57625"
PRESCOTT_CITY = "57650"
PRESTON_CITY = "57675"
PRETTY_PRAIRIE_CITY = "57700"
PRINCETON_CITY = "57725"
PROTECTION_CITY = "57850"
QUENEMO_CITY = "58100"
QUINTER_CITY = "58250"
RADIUM_CITY = "58300"
RADLEY_CDP = "58325"
RAMONA_CITY = "58375"
RANDALL_CITY = "58450"
RANDOLPH_CITY = "58475"
RANSOM_CITY = "58500"
RANTOUL_CITY = "58525"
RAYMOND_CITY = "58550"
READING_CITY = "58600"
REDFIELD_CITY = "58725"
REPUBLIC_CITY = "59000"
RESERVE_CITY = "59050"
REXFORD_CITY = "59125"
RICHFIELD_CITY = "59200"
RICHMOND_CITY = "59675"
RILEY_CITY = "59875"
RINGO_CDP = "59975"
RIVERTON_CDP = "60200"
ROBINSON_CITY = "60325"
ROCK_CDP = "60400"
ROELAND_PARK_CITY = "60825"
ROLLA_CITY = "60900"
ROSALIA_CDP = "61100"
ROSE_HILL_CITY = "61250"
ROSELAND_CITY = "61275"
ROSSVILLE_CITY = "61400"
ROXBURY_CDP = "61550"
ROZEL_CITY = "61600"
RUSH_CENTER_CITY = "61775"
RUSSELL_SPRINGS_CITY = "61875"
RUSSELL_CITY = "61825"
SABETHA_CITY = "62025"
SALINA_CITY = "62700"
SATANTA_CITY = "63150"
SAVONBURG_CITY = "63200"
SAWYER_CITY = "63275"
SCAMMON_CITY = "63325"
SCANDIA_CITY = "63350"
SCHOENCHEN_CITY = "63425"
SCOTT_CITY_CITY = "63600"
SCOTTSVILLE_CITY = "63650"
SCRANTON_CITY = "63675"
SEDAN_CITY = "63750"
SEDGWICK_CITY = "63800"
SELDEN_CITY = "63875"
SENECA_CITY = "63950"
SEVERANCE_CITY = "64025"
SEVERY_CITY = "64050"
SEWARD_CITY = "64100"
SHALLOW_WATER_CDP = "64200"
SHARON_SPRINGS_CITY = "64375"
SHARON_CITY = "64325"
SHAWNEE_CITY = "64500"
SILVER_LAKE_CITY = "65600"
SILVERDALE_CDP = "65550"
SIMPSON_CITY = "65650"
SMITH_CENTER_CITY = "65925"
SMOLAN_CITY = "66100"
SOLDIER_CITY = "66175"
SOLOMON_CITY = "66275"
SOMERSET_CDP = "66475"
SOUTH_HAVEN_CITY = "66650"
SOUTH_HUTCHINSON_CITY = "66750"
SOUTH_MOUND_CDP = "66800"
SPEARVILLE_CITY = "67125"
SPEED_CITY = "67175"
SPIVEY_CITY = "67250"
SPRING_HILL_CITY = "67625"
ST_BENEDICT_CDP = "62075"
ST_FRANCIS_CITY = "62175"
ST_GEORGE_CITY = "62200"
ST_JOHN_CITY = "62275"
ST_MARKS_CDP = "62375"
ST_MARYS_CITY = "62400"
ST_PAUL_CITY = "62500"
STAFFORD_CITY = "67775"
STARK_CITY = "68025"
STERLING_CITY = "68200"
STOCKTON_CITY = "68350"
STRONG_CITY_CITY = "68650"
STUTTGART_CDP = "68750"
SUBLETTE_CITY = "68775"
SUMMERFIELD_CITY = "68950"
SUN_CITY_CITY = "69275"
SUSANK_CITY = "69525"
SYCAMORE_CDP = "69725"
SYLVAN_GROVE_CITY = "69775"
SYLVIA_CITY = "69800"
SYRACUSE_CITY = "69850"
TALMAGE_CDP = "69925"
TAMPA_CITY = "70000"
TECUMSEH_CDP = "70075"
TESCOTT_CITY = "70250"
THAYER_CITY = "70300"
THE_HIGHLANDS_CITY = "70357"
TIMKEN_CITY = "70625"
TIPTON_CITY = "70675"
TONGANOXIE_CITY = "70800"
TOPEKA_CITY = "71000"
TORONTO_CITY = "71050"
TOWANDA_CITY = "71125"
TRIBUNE_CITY = "71450"
TROY_CITY = "71575"
TURON_CITY = "71800"
TYRO_CITY = "71925"
UDALL_CITY = "71950"
ULYSSES_CITY = "71975"
UNIONTOWN_CITY = "72525"
URBANA_CDP = "72600"
UTICA_CITY = "72650"
VALLEY_CENTER_CITY = "73250"
VALLEY_FALLS_CITY = "73300"
VASSAR_CDP = "73450"
VERMILLION_CITY = "73525"
VICTORIA_CITY = "73775"
VINING_CITY = "73950"
VIOLA_CITY = "74025"
VIRGIL_CITY = "74075"
WAKEENEY_CITY = "74450"
WABAUNSEE_CDP = "74225"
WAKARUSA_CDP = "74425"
WAKEFIELD_CITY = "74525"
WALDO_CITY = "74575"
WALDRON_CITY = "74625"
WALLACE_CITY = "74750"
WALNUT_CITY = "74950"
WALTON_CITY = "75200"
WAMEGO_CITY = "75325"
WASHINGTON_CITY = "75825"
WATERVILLE_CITY = "75950"
WATHENA_CITY = "76000"
WAVERLY_CITY = "76050"
WAYSIDE_CDP = "76175"
WEBBER_CITY = "76250"
WEIR_CITY = "76350"
WELDA_CDP = "76425"
WELLINGTON_CITY = "76475"
WELLS_CDP = "76550"
WELLSVILLE_CITY = "76625"
WESKAN_CDP = "76675"
WEST_MINERAL_CITY = "77150"
WESTMORELAND_CITY = "77200"
WESTPHALIA_CITY = "77250"
WESTWOOD_HILLS_CITY = "77525"
WESTWOOD_CITY = "77500"
WETMORE_CITY = "77550"
WHEATON_CITY = "77700"
WHITE_CITY_CITY = "77825"
WHITE_CLOUD_CITY = "77850"
WHITEWATER_CITY = "78050"
WHITING_CITY = "78100"
WICHITA_CITY = "79000"
WILLARD_CITY = "79250"
WILLIAMSBURG_CITY = "79300"
WILLIAMSTOWN_CDP = "79375"
WILLIS_CITY = "79400"
WILLOWBROOK_CITY = "79425"
WILMORE_CITY = "79550"
WILROADS_GARDENS_CDP = "79625"
WILSEY_CITY = "79650"
WILSON_CITY = "79675"
WINCHESTER_CITY = "79800"
WINDOM_CITY = "79850"
WINFIELD_CITY = "79950"
WINONA_CITY = "80075"
WOODBINE_CITY = "80350"
WOODRUFF_CDP = "80400"
WOODSTON_CITY = "80450"
WRIGHT_CDP = "80500"
YALE_CDP = "80650"
YATES_CENTER_CITY = "80700"
YODER_CDP = "80750"
ZEANDALE_CDP = "80875"
ZENDA_CITY = "80925"
ZURICH_CITY = "81025"
