# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Illinois."""


ADAMS = "001"
ALEXANDER = "003"
BOND = "005"
BOONE = "007"
BROWN = "009"
BUREAU = "011"
CALHOUN = "013"
CARROLL = "015"
CASS = "017"
CHAMPAIGN = "019"
CHRISTIAN = "021"
CLARK = "023"
CLAY = "025"
CLINTON = "027"
COLES = "029"
COOK = "031"
CRAWFORD = "033"
CUMBERLAND = "035"
DE_WITT = "039"
DEKALB = "037"
DOUGLAS = "041"
DUPAGE = "043"
EDGAR = "045"
EDWARDS = "047"
EFFINGHAM = "049"
FAYETTE = "051"
FORD = "053"
FRANKLIN = "055"
FULTON = "057"
GALLATIN = "059"
GREENE = "061"
GRUNDY = "063"
HAMILTON = "065"
HANCOCK = "067"
HARDIN = "069"
HENDERSON = "071"
HENRY = "073"
IROQUOIS = "075"
JACKSON = "077"
JASPER = "079"
JEFFERSON = "081"
JERSEY = "083"
JO_DAVIESS = "085"
JOHNSON = "087"
KANE = "089"
KANKAKEE = "091"
KENDALL = "093"
KNOX = "095"
LASALLE = "099"
LAKE = "097"
LAWRENCE = "101"
LEE = "103"
LIVINGSTON = "105"
LOGAN = "107"
MACON = "115"
MACOUPIN = "117"
MADISON = "119"
MARION = "121"
MARSHALL = "123"
MASON = "125"
MASSAC = "127"
MCDONOUGH = "109"
MCHENRY = "111"
MCLEAN = "113"
MENARD = "129"
MERCER = "131"
MONROE = "133"
MONTGOMERY = "135"
MORGAN = "137"
MOULTRIE = "139"
OGLE = "141"
PEORIA = "143"
PERRY = "145"
PIATT = "147"
PIKE = "149"
POPE = "151"
PULASKI = "153"
PUTNAM = "155"
RANDOLPH = "157"
RICHLAND = "159"
ROCK_ISLAND = "161"
SALINE = "165"
SANGAMON = "167"
SCHUYLER = "169"
SCOTT = "171"
SHELBY = "173"
ST_CLAIR = "163"
STARK = "175"
STEPHENSON = "177"
TAZEWELL = "179"
UNION = "181"
VERMILION = "183"
WABASH = "185"
WARREN = "187"
WASHINGTON = "189"
WAYNE = "191"
WHITE = "193"
WHITESIDE = "195"
WILL = "197"
WILLIAMSON = "199"
WINNEBAGO = "201"
WOODFORD = "203"
