# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Arkansas."""


ACORN_CDP = "00190"
ADONA_CITY = "00250"
ALEXANDER_CITY = "00580"
ALICIA_TOWN = "00700"
ALIX_CDP = "00730"
ALLEENE_CDP = "00820"
ALLPORT_TOWN = "00940"
ALMA_CITY = "00970"
ALMYRA_TOWN = "01030"
ALPENA_TOWN = "01060"
ALPINE_CDP = "01090"
ALTHEIMER_CITY = "01150"
ALTUS_CITY = "01210"
AMAGON_TOWN = "01270"
AMITY_CITY = "01360"
ANTHONYVILLE_TOWN = "01457"
ANTOINE_TOWN = "01540"
APLIN_CDP = "01630"
APPLETON_CDP = "01660"
ARKADELPHIA_CITY = "01870"
ARKANSAS_CITY_CITY = "01990"
ARMOREL_CDP = "02230"
ASH_FLAT_CITY = "02470"
ASHDOWN_CITY = "02380"
ATKINS_CITY = "02590"
AUBREY_TOWN = "02680"
AUGUSTA_CITY = "02740"
AUSTIN_CITY = "02860"
AVILLA_CDP = "03010"
AVOCA_TOWN = "03040"
BALD_KNOB_CITY = "03280"
BANKS_TOWN = "03430"
BARLING_CITY = "03640"
BASSETT_TOWN = "03940"
BATAVIA_CDP = "03970"
BATESVILLE_CITY = "04030"
BAUXITE_TOWN = "04090"
BAY_CITY = "04180"
BEARDEN_CITY = "04420"
BEAVER_TOWN = "04540"
BEE_BRANCH_CDP = "04630"
BEEBE_CITY = "04600"
BEEDEVILLE_TOWN = "04720"
BEIRNE_CDP = "04750"
BELLA_VISTA_CITY = "04840"
BELLEFONTE_TOWN = "04900"
BELLEVILLE_CITY = "04960"
BEN_LOMOND_TOWN = "05260"
BENTON_CITY = "05290"
BENTONVILLE_CITY = "05320"
BERGMAN_TOWN = "05440"
BERRYVILLE_CITY = "05560"
BETHESDA_CDP = "05770"
BIG_FLAT_TOWN = "05980"
BIGELOW_TOWN = "05920"
BIGGERS_TOWN = "06040"
BIRDSONG_TOWN = "06340"
BISMARCK_CDP = "06460"
BLACK_OAK_TOWN = "06610"
BLACK_ROCK_CITY = "06700"
BLACK_SPRINGS_TOWN = "06730"
BLEVINS_CITY = "07030"
BLUE_EYE_TOWN = "07150"
BLUE_MOUNTAIN_TOWN = "07210"
BLUFF_CITY_TOWN = "07270"
BLYTHEVILLE_CITY = "07330"
BOARD_CAMP_CDP = "07420"
BODCAW_TOWN = "07450"
BOLES_CDP = "07510"
BONANZA_CITY = "07540"
BONO_CITY = "07630"
BOONEVILLE_CITY = "07720"
BOWMAN_CDP = "08020"
BRADFORD_CITY = "08260"
BRADLEY_CITY = "08290"
BRANCH_CITY = "08440"
BRIARCLIFF_CITY = "08665"
BRINKLEY_CITY = "08950"
BROOKLAND_CITY = "09100"
BRYANT_CITY = "09460"
BUCKNER_CITY = "09550"
BUFFALO_CITY_CDP = "09700"
BULL_SHOALS_CITY = "09790"
BURDETTE_TOWN = "09880"
CABOT_CITY = "10300"
CADDO_GAP_CDP = "10330"
CADDO_VALLEY_TOWN = "10360"
CALDWELL_TOWN = "10450"
CALE_TOWN = "10480"
CALICO_ROCK_CITY = "10570"
CALION_CITY = "10600"
CAMDEN_CITY = "10720"
CAMMACK_VILLAGE_CITY = "10780"
CAMPBELL_STATION_CITY = "10900"
CANEHILL_CDP = "11080"
CARAWAY_CITY = "11410"
CARLISLE_CITY = "11500"
CARTHAGE_CITY = "11830"
CASA_TOWN = "11890"
CASH_TOWN = "11920"
CAULKSVILLE_TOWN = "12190"
CAVE_CITY_CITY = "12280"
CAVE_SPRINGS_CITY = "12340"
CEDARVILLE_CITY = "12520"
CENTER_POINT_CDP = "12700"
CENTER_RIDGE_CDP = "12790"
CENTERTON_CITY = "12820"
CENTERVILLE_CDP = "12940"
CENTRAL_CITY_TOWN = "13120"
CHARLESTON_CITY = "13300"
CHEROKEE_CITY_CDP = "13420"
CHEROKEE_VILLAGE_CITY = "13450"
CHERRY_VALLEY_CITY = "13540"
CHESTER_TOWN = "13570"
CHIDESTER_CITY = "13750"
CINCINNATI_CDP = "13960"
CLARENDON_CITY = "13990"
CLARKEDALE_CITY = "14050"
CLARKSVILLE_CITY = "14140"
CLINTON_CITY = "14260"
COAL_HILL_CITY = "14500"
COLLEGE_STATION_CDP = "14860"
COLLINS_CDP = "14920"
COLT_CITY = "14950"
CONCORD_TOWN = "15100"
CONWAY_CITY = "15190"
CORINTH_TOWN = "15310"
CORNING_CITY = "15460"
COTTER_CITY = "15490"
COTTON_PLANT_CITY = "15550"
COVE_TOWN = "15700"
COY_TOWN = "15790"
CRAWFORDSVILLE_TOWN = "15940"
CROSSETT_CITY = "16240"
CRYSTAL_SPRINGS_CDP = "16690"
CUSHMAN_CITY = "16930"
DAISY_TOWN = "17140"
DAMASCUS_TOWN = "17290"
DANVILLE_CITY = "17320"
DARDANELLE_CITY = "17380"
DATTO_TOWN = "17410"
DE_QUEEN_CITY = "18490"
DE_VALLS_BLUFF_CITY = "18640"
DEWITT_CITY = "18790"
DECATUR_CITY = "17740"
DEER_CDP = "17860"
DELAPLAINE_TOWN = "18010"
DELIGHT_CITY = "18100"
DELL_TOWN = "18160"
DENNARD_CDP = "18340"
DENNING_TOWN = "18370"
DERMOTT_CITY = "18520"
DES_ARC_CITY = "18550"
DESHA_CDP = "18580"
DIAMOND_CITY_CITY = "18850"
DIAZ_CITY = "18940"
DIERKS_CITY = "18970"
DONALDSON_TOWN = "19450"
DORA_CDP = "19540"
DOVER_CITY = "19600"
DRASCO_CDP = "19720"
DUMAS_CITY = "19990"
DYER_CITY = "20200"
DYESS_TOWN = "20230"
EARLE_CITY = "20320"
EAST_CAMDEN_TOWN = "20440"
EAST_END_CDP = "20470"
EDGEMONT_CDP = "20800"
EDMONDSON_TOWN = "20830"
EGYPT_TOWN = "20920"
EL_DORADO_CITY = "21070"
EL_PASO_CDP = "21520"
ELAINE_CITY = "20950"
ELKINS_CITY = "21190"
ELM_SPRINGS_CITY = "21430"
EMERSON_TOWN = "21580"
EMMET_CITY = "21610"
ENGLAND_CITY = "21730"
ENOLA_TOWN = "21820"
ETOWAH_TOWN = "22120"
EUDORA_CITY = "22180"
EUREKA_SPRINGS_CITY = "22240"
EVANSVILLE_CDP = "22300"
EVENING_SHADE_CITY = "22360"
EVERTON_TOWN = "22450"
FAIR_OAKS_CDP = "22720"
FAIRFIELD_BAY_CITY = "22660"
FARGO_TOWN = "23140"
FARMINGTON_CITY = "23170"
FAYETTEVILLE_CITY = "23290"
FELSENTHAL_TOWN = "23320"
FIFTY_SIX_CITY = "23680"
FISHER_CITY = "23800"
FLIPPIN_CITY = "24010"
FLORAL_CDP = "24070"
FLOYD_CDP = "24130"
FORDYCE_CITY = "24220"
FOREMAN_CITY = "24250"
FORREST_CITY_CITY = "24430"
FORT_SMITH_CITY = "24550"
FOUKE_CITY = "24640"
FOUNTAIN_HILL_TOWN = "24670"
FOUNTAIN_LAKE_TOWN = "24700"
FOURCHE_TOWN = "24760"
FOX_CDP = "24910"
FRANKLIN_TOWN = "25030"
FREDONIA_BISCOE_TOWN = "25060"
FRIENDSHIP_TOWN = "25180"
FULTON_TOWN = "25360"
GAMALIEL_CDP = "25630"
GARFIELD_TOWN = "25750"
GARLAND_TOWN = "25780"
GARNER_TOWN = "25900"
GASSVILLE_CITY = "26050"
GATEWAY_TOWN = "26110"
GENOA_CDP = "26260"
GENTRY_CITY = "26290"
GEORGETOWN_TOWN = "26440"
GIBSON_CDP = "26710"
GILBERT_TOWN = "26800"
GILLETT_CITY = "26980"
GILLHAM_TOWN = "27010"
GILMORE_CITY = "27040"
GLENWOOD_CITY = "27310"
GOODWIN_CDP = "27610"
GOSHEN_TOWN = "27670"
GOSNELL_CITY = "27700"
GOULD_CITY = "27730"
GRADY_CITY = "27790"
GRANNIS_CITY = "27970"
GRAVETTE_CITY = "28360"
GREEN_FOREST_CITY = "28600"
GREENBRIER_CITY = "28510"
GREENLAND_CITY = "28660"
GREENWAY_CITY = "28720"
GREENWOOD_CITY = "28780"
GREERS_FERRY_CITY = "28810"
GREGORY_CDP = "28840"
GRIFFITHVILLE_TOWN = "28990"
GRUBBS_CITY = "29020"
GUION_TOWN = "29080"
GUM_SPRINGS_TOWN = "29140"
GURDON_CITY = "29200"
GUY_CITY = "29230"
HACKETT_CITY = "29290"
HAGARVILLE_CDP = "29320"
HALLEY_CDP = "29380"
HAMBURG_CITY = "29500"
HAMPTON_CITY = "29650"
HARDY_CITY = "29920"
HARRELL_TOWN = "30310"
HARRISBURG_CITY = "30400"
HARRISON_CITY = "30460"
HARTFORD_CITY = "30490"
HARTMAN_CITY = "30520"
HASKELL_CITY = "30640"
HATFIELD_TOWN = "30700"
HATTIEVILLE_CDP = "30730"
HAVANA_CITY = "30790"
HAYNES_TOWN = "30880"
HAZEN_CITY = "30940"
HEBER_SPRINGS_CITY = "31090"
HECTOR_TOWN = "31150"
HELENA_WEST_HELENA_CITY = "31190"
HENDERSON_CDP = "31270"
HENSLEY_CDP = "31390"
HERMITAGE_CITY = "31540"
HICKORY_RIDGE_CITY = "31900"
HIGDEN_TOWN = "32080"
HIGGINSON_TOWN = "32140"
HIGHFILL_TOWN = "32200"
HIGHLAND_CITY = "32257"
HINDSVILLE_TOWN = "32470"
HOLIDAY_ISLAND_TOWN = "32650"
HOLLAND_CITY = "32710"
HOLLY_GROVE_CITY = "32800"
HOPE_CITY = "33190"
HORATIO_CITY = "33310"
HORSESHOE_BEND_CITY = "33370"
HORSESHOE_LAKE_TOWN = "33375"
HOT_SPRINGS_VILLAGE_CDP = "33482"
HOT_SPRINGS_CITY = "33400"
HOUSTON_TOWN = "33490"
HOXIE_CITY = "33580"
HUGHES_CITY = "33760"
HUMNOKE_CITY = "33820"
HUMPHREY_CITY = "33850"
HUNTER_TOWN = "33910"
HUNTINGTON_CITY = "33940"
HUNTSVILLE_CITY = "33970"
HUTTIG_CITY = "34090"
IMBODEN_TOWN = "34150"
INDIAN_BAY_CDP = "34220"
IVAN_CDP = "34540"
JACKSONPORT_TOWN = "34720"
JACKSONVILLE_CITY = "34750"
JASPER_CITY = "34900"
JENNETTE_TOWN = "35040"
JERICHO_TOWN = "35140"
JEROME_CDP = "35170"
JERUSALEM_CDP = "35260"
JOHNSON_CITY = "35500"
JOINER_CITY = "35650"
JONES_MILLS_CDP = "35770"
JONESBORO_CITY = "35710"
JUDSONIA_CITY = "36040"
JUNCTION_CITY_CITY = "36130"
KEISER_CITY = "36310"
KENSETT_CITY = "36430"
KEO_TOWN = "36550"
KIBLER_CITY = "36670"
KINGSLAND_CITY = "36880"
KINGSTON_CDP = "36910"
KIRBY_CDP = "37060"
KNOBEL_CITY = "37240"
KNOXVILLE_TOWN = "37300"
LAGRANGE_TOWN = "37720"
LACEY_CDP = "37450"
LAFE_TOWN = "37660"
LAKE_CITY_CITY = "37780"
LAKE_HAMILTON_CDP = "37930"
LAKE_VIEW_CITY = "38110"
LAKE_VILLAGE_CITY = "38170"
LAKEVIEW_CITY = "38050"
LAMAR_CITY = "38290"
LANDMARK_CDP = "38540"
LAVACA_CITY = "38890"
LAWSON_CDP = "38950"
LEACHVILLE_CITY = "39010"
LEAD_HILL_TOWN = "39040"
LEOLA_TOWN = "39310"
LEPANTO_CITY = "39370"
LESLIE_CITY = "39460"
LETONA_TOWN = "39520"
LEWISVILLE_CITY = "39640"
LEXA_TOWN = "39670"
LINCOLN_CITY = "39970"
LITTLE_FLOCK_CITY = "40120"
LITTLE_ROCK_CITY = "41000"
LOCKESBURG_CITY = "41090"
LONDON_CITY = "41270"
LONOKE_CITY = "41420"
LONSDALE_TOWN = "41450"
LOST_BRIDGE_VILLAGE_CDP = "41555"
LOUANN_TOWN = "41630"
LOWELL_CITY = "41720"
LUXORA_CITY = "42170"
LYNN_TOWN = "42260"
MADISON_CITY = "43280"
MAGAZINE_CITY = "43310"
MAGNESS_TOWN = "43370"
MAGNET_COVE_CDP = "43430"
MAGNOLIA_CITY = "43460"
MALVERN_CITY = "43610"
MAMMOTH_SPRING_CITY = "43670"
MANILA_CITY = "43820"
MANSFIELD_CITY = "43880"
MARIANNA_CITY = "44120"
MARIE_TOWN = "44150"
MARION_CITY = "44180"
MARKED_TREE_CITY = "44210"
MARMADUKE_CITY = "44240"
MARSHALL_CITY = "44300"
MARVELL_CITY = "44420"
MAUMELLE_CITY = "44600"
MAYFLOWER_CITY = "44750"
MAYNARD_TOWN = "44780"
MAYSVILLE_CDP = "44810"
MCALMONT_CDP = "42350"
MCCASKILL_TOWN = "42410"
MCCRORY_CITY = "42500"
MCDOUGAL_TOWN = "42560"
MCGEHEE_CITY = "42770"
MCNAB_TOWN = "43070"
MCNEIL_CITY = "43100"
MCRAE_CITY = "43220"
MELBOURNE_CITY = "45080"
MELLWOOD_CDP = "45110"
MENA_CITY = "45170"
MENIFEE_TOWN = "45200"
MIDLAND_TOWN = "45500"
MIDWAY_CDP = "45530"
MIDWAY_TOWN = "45560"
MINERAL_SPRINGS_CITY = "46040"
MINTURN_TOWN = "46100"
MITCHELLVILLE_CITY = "46190"
MONETTE_CITY = "46400"
MONROE_CDP = "46460"
MONTICELLO_CITY = "46580"
MONTROSE_CITY = "46670"
MOOREFIELD_TOWN = "46730"
MORO_TOWN = "46910"
MORRILTON_CITY = "46970"
MORRISON_BLUFF_TOWN = "47030"
MORROW_CDP = "47090"
MOUNT_HOLLY_CDP = "47660"
MOUNT_IDA_CITY = "47690"
MOUNT_JUDEA_CDP = "47720"
MOUNT_OLIVE_CDP = "47810"
MOUNT_PLEASANT_TOWN = "47900"
MOUNT_VERNON_TOWN = "48020"
MOUNTAIN_HOME_CITY = "47390"
MOUNTAIN_PINE_CITY = "47450"
MOUNTAIN_VIEW_CITY = "47540"
MOUNTAINBURG_CITY = "47300"
MULBERRY_CITY = "48200"
MURFREESBORO_CITY = "48290"
NASHVILLE_CITY = "48560"
NATURAL_STEPS_CDP = "48680"
NEW_BLAINE_CDP = "49070"
NEW_EDINBURG_CDP = "49220"
NEWARK_CITY = "49010"
NEWHOPE_CDP = "49370"
NEWPORT_CITY = "49580"
NIMMONS_TOWN = "49820"
NORFORK_CITY = "50000"
NORMAN_TOWN = "50030"
NORPHLET_CITY = "50060"
NORTH_CROSSETT_CDP = "50240"
NORTH_LITTLE_ROCK_CITY = "50450"
OKEAN_TOWN = "51500"
OAK_GROVE_CDP = "50990"
OAK_GROVE_HEIGHTS_TOWN = "51060"
OAK_GROVE_TOWN = "50810"
OAKHAVEN_TOWN = "51080"
OAKLAND_CDP = "51110"
OARK_CDP = "51230"
ODEN_TOWN = "51290"
OGDEN_CITY = "51350"
OIL_TROUGH_TOWN = "51410"
OKOLONA_TOWN = "51530"
OLA_CITY = "51560"
OMAHA_TOWN = "52160"
ONEIDA_CDP = "52280"
OPPELO_CITY = "52430"
OSCEOLA_CITY = "52580"
OXFORD_CITY = "52880"
OZAN_TOWN = "52940"
OZARK_ACRES_CDP = "53000"
OZARK_CITY = "52970"
OZONE_CDP = "53060"
PALESTINE_CITY = "53150"
PANGBURN_CITY = "53240"
PARAGOULD_CITY = "53390"
PARIS_CITY = "53480"
PARKDALE_CITY = "53510"
PARKIN_CITY = "53600"
PATMOS_TOWN = "53900"
PATTERSON_CITY = "53990"
PAYNEWAY_CDP = "54110"
PEA_RIDGE_CITY = "54200"
PEACH_ORCHARD_CITY = "54140"
PEARCY_CDP = "54170"
PENCIL_BLUFF_CDP = "54410"
PERLA_TOWN = "54620"
PERRY_TOWN = "54650"
PERRYTOWN_TOWN = "54680"
PERRYVILLE_CITY = "54710"
PIGGOTT_CITY = "55130"
PINDALL_TOWN = "55280"
PINE_BLUFF_CITY = "55310"
PINEVILLE_TOWN = "55580"
PINEY_CDP = "55610"
PLAINVIEW_CITY = "55970"
PLEASANT_GROVE_CDP = "56060"
PLEASANT_PLAINS_TOWN = "56270"
PLUMERVILLE_CITY = "56480"
POCAHONTAS_CITY = "56540"
POLLARD_CITY = "56600"
PONCA_CDP = "56630"
POPLAR_GROVE_CDP = "56690"
PORTIA_TOWN = "56720"
PORTLAND_CITY = "56750"
POTTSVILLE_CITY = "56990"
POWHATAN_TOWN = "57050"
POYEN_TOWN = "57080"
PRAIRIE_CREEK_CDP = "57125"
PRAIRIE_GROVE_CITY = "57170"
PRATTSVILLE_TOWN = "57230"
PRESCOTT_CITY = "57260"
PRINCETON_CDP = "57530"
PYATT_TOWN = "57890"
QUITMAN_CITY = "57950"
RATCLIFF_CITY = "58160"
RAVENDEN_SPRINGS_TOWN = "58280"
RAVENDEN_TOWN = "58250"
READER_CDP = "58400"
RECTOR_CITY = "58490"
REDFIELD_CITY = "58580"
REED_TOWN = "58880"
REYNO_CITY = "59180"
RISON_CITY = "59480"
RIVERVALE_CDP = "59630"
ROCKPORT_CITY = "60020"
ROCKWELL_CDP = "60110"
ROE_TOWN = "60380"
ROGERS_CITY = "60410"
ROLAND_CDP = "60470"
RONDO_TOWN = "60590"
ROSE_BUD_TOWN = "60770"
ROSSTON_TOWN = "61040"
ROVER_CDP = "61190"
RUDY_TOWN = "61460"
RUSSELL_TOWN = "61640"
RUSSELLVILLE_CITY = "61670"
RYE_CDP = "61730"
SALADO_CDP = "62120"
SALEM_CDP = "62210"
SALEM_CITY = "62150"
SALESVILLE_CITY = "62240"
SARATOGA_CDP = "62630"
SARDIS_CDP = "62660"
SCOTT_CDP = "62900"
SCRANTON_CITY = "62960"
SEARCY_CITY = "63020"
SEDGWICK_TOWN = "63110"
SHANNON_HILLS_CITY = "63470"
SHERIDAN_CITY = "63710"
SHERRILL_TOWN = "63740"
SHERWOOD_CITY = "63800"
SHIRLEY_TOWN = "63980"
SIDNEY_TOWN = "64280"
SILOAM_SPRINGS_CITY = "64370"
SMACKOVER_CITY = "64730"
SMITHVILLE_TOWN = "64910"
SOUTH_LEAD_HILL_TOWN = "65480"
SOUTHSIDE_CITY = "65630"
SPARKMAN_CITY = "65900"
SPRINGDALE_CITY = "66080"
SPRINGFIELD_CDP = "66110"
SPRINGTOWN_TOWN = "66200"
ST_CHARLES_TOWN = "61940"
ST_FRANCIS_CITY = "61970"
ST_JOE_TOWN = "62030"
ST_PAUL_TOWN = "62060"
STAMPS_CITY = "66320"
STAR_CITY_CITY = "66440"
STAVES_CDP = "66800"
STEPHENS_CITY = "66860"
STRAWBERRY_TOWN = "67250"
STRONG_CITY = "67370"
STUTTGART_CITY = "67490"
SUBIACO_TOWN = "67520"
SUCCESS_TOWN = "67550"
SULPHUR_ROCK_TOWN = "67730"
SULPHUR_SPRINGS_CDP = "67790"
SULPHUR_SPRINGS_CITY = "67760"
SUMMERS_CDP = "67880"
SUMMIT_CITY = "67940"
SUNSET_TOWN = "68060"
SWEET_HOME_CDP = "68330"
SWIFTON_CITY = "68360"
TAYLOR_CITY = "68660"
TEXARKANA_CITY = "68810"
THORNTON_CITY = "69050"
TILLAR_CITY = "69230"
TINSMAN_TOWN = "69350"
TOLLETTE_TOWN = "69500"
TONTITOWN_CITY = "69740"
TRASKWOOD_CITY = "69830"
TRUMANN_CITY = "70010"
TUCKER_CDP = "70070"
TUCKERMAN_CITY = "70100"
TULL_TOWN = "70220"
TUMBLING_SHOALS_CDP = "70310"
TUPELO_TOWN = "70340"
TURRELL_CITY = "70430"
TWIN_GROVES_TOWN = "70540"
TYRONZA_CITY = "70700"
ULM_TOWN = "70760"
UNIONTOWN_CDP = "71060"
URBANA_CDP = "71180"
VALLEY_SPRINGS_TOWN = "71390"
VAN_BUREN_CITY = "71480"
VANDERVOORT_TOWN = "71510"
VANNDALE_CDP = "71570"
VICTORIA_TOWN = "71900"
VILONIA_CITY = "71960"
VIOLA_TOWN = "72140"
VIOLET_HILL_CDP = "72170"
WABBASEKA_TOWN = "72230"
WALCOTT_CDP = "72290"
WALDENBURG_TOWN = "72320"
WALDO_CITY = "72350"
WALDRON_CITY = "72380"
WALNUT_RIDGE_CITY = "72890"
WARD_CITY = "73130"
WARM_SPRINGS_CDP = "73250"
WARREN_CITY = "73310"
WASHINGTON_CITY = "73370"
WATSON_CITY = "73550"
WAYTON_CDP = "73730"
WEINER_CITY = "73940"
WELDON_TOWN = "74000"
WESLEY_CDP = "74090"
WEST_CROSSETT_CDP = "74270"
WEST_FORK_CITY = "74360"
WEST_MEMPHIS_CITY = "74540"
WEST_POINT_TOWN = "74660"
WESTERN_GROVE_TOWN = "74330"
WHEATLEY_CITY = "74840"
WHELEN_SPRINGS_TOWN = "74930"
WHITE_HALL_CITY = "75170"
WICKES_TOWN = "75500"
WIDENER_TOWN = "75560"
WIEDERKEHR_VILLAGE_CITY = "75570"
WILBURN_CDP = "75590"
WILLIFORD_TOWN = "75740"
WILLISVILLE_TOWN = "75770"
WILMAR_CITY = "75860"
WILMOT_CITY = "75890"
WILSON_CITY = "75920"
WILTON_CITY = "75980"
WINCHESTER_TOWN = "76010"
WINSLOW_CITY = "76190"
WINTHROP_CITY = "76250"
WITTS_SPRINGS_CDP = "76460"
WOODLAWN_CDP = "76690"
WOODSON_CDP = "76730"
WOOSTER_TOWN = "76820"
WRIGHTSVILLE_CITY = "76970"
WYNNE_CITY = "77090"
YARBOROUGH_LANDING_CDP = "77203"
YELLVILLE_CITY = "77330"
ZINC_TOWN = "77600"
