# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Massachusetts."""


ABINGTON_CDP = "00135"
ACUSHNET_CENTER_CDP = "00530"
ADAMS_CDP = "00590"
AGAWAM_TOWN_CITY = "00840"
AMESBURY_TOWN_CITY = "01260"
AMHERST_TOWN_CITY = "01370"
ANDOVER_CDP = "01430"
ARLINGTON_CDP = "01640"
ATHOL_CDP = "02515"
ATTLEBORO_CITY = "02690"
AYER_CDP = "03040"
BALDWINVILLE_CDP = "03355"
BARNSTABLE_TOWN_CITY = "03690"
BARRE_CDP = "03705"
BELCHERTOWN_CDP = "04790"
BELLINGHAM_CDP = "04965"
BELMONT_CDP = "05105"
BEVERLY_CITY = "05595"
BLANDFORD_CDP = "06050"
BLISS_CORNER_CDP = "06170"
BOSTON_CITY = "07000"
BOURNE_CDP = "07140"
BOXFORD_CDP = "07385"
BRAINTREE_TOWN_CITY = "07740"
BREWSTER_CDP = "07945"
BRIDGEWATER_TOWN_CITY = "08130"
BROCKTON_CITY = "09000"
BROOKFIELD_CDP = "09070"
BROOKLINE_CDP = "09210"
BURLINGTON_CDP = "09875"
BUZZARDS_BAY_CDP = "10015"
CAMBRIDGE_CITY = "11000"
CEDAR_CREST_CDP = "11945"
CHATHAM_CDP = "12960"
CHELSEA_CITY = "13205"
CHESHIRE_CDP = "13310"
CHESTER_CDP = "13450"
CHICOPEE_CITY = "13660"
CLINTON_CDP = "14430"
COCHITUATE_CDP = "14570"
CORDAVILLE_CDP = "15340"
DANVERS_CDP = "16285"
DEDHAM_CDP = "16530"
DEERFIELD_CDP = "16635"
DENNIS_CDP = "16740"
DENNIS_PORT_CDP = "16810"
DEVENS_CDP = "16840"
DOVER_CDP = "17370"
DUXBURY_CDP = "17860"
EAST_BROOKFIELD_CDP = "18595"
EAST_DENNIS_CDP = "18840"
EAST_DOUGLAS_CDP = "18875"
EAST_FALMOUTH_CDP = "18980"
EAST_HARWICH_CDP = "19400"
EAST_PEPPERELL_CDP = "20310"
EAST_SANDWICH_CDP = "20380"
EASTHAMPTON_TOWN_CITY = "19370"
EDGARTOWN_CDP = "21115"
ESSEX_CDP = "21815"
EVERETT_CITY = "21990"
FALL_RIVER_CITY = "23000"
FALMOUTH_CDP = "23070"
FISKDALE_CDP = "23840"
FITCHBURG_CITY = "23875"
FORESTDALE_CDP = "24190"
FOXBOROUGH_CDP = "24855"
FRAMINGHAM_CITY = "24960"
FRANKLIN_TOWN_CITY = "25172"
GARDNER_CITY = "25485"
GLOUCESTER_CITY = "26150"
GRANBY_CDP = "26500"
GREAT_BARRINGTON_CDP = "26780"
GREEN_HARBOR_CDP = "27130"
GREENFIELD_CITY = "27060"
GROTON_CDP = "27445"
HANSCOM_AFB_CDP = "28425"
HANSON_CDP = "28460"
HARWICH_CENTER_CDP = "29055"
HARWICH_PORT_CDP = "29090"
HATFIELD_CDP = "29230"
HAVERHILL_CITY = "29405"
HINGHAM_CDP = "30175"
HOLBROOK_CDP = "30420"
HOLLAND_CDP = "30630"
HOLYOKE_CITY = "30840"
HOPEDALE_CDP = "30980"
HOPKINTON_CDP = "31050"
HOUSATONIC_CDP = "31295"
HUDSON_CDP = "31575"
HULL_CDP = "31680"
HUNTINGTON_CDP = "31750"
IPSWICH_CDP = "32275"
KINGSTON_CDP = "33185"
LAWRENCE_CITY = "34550"
LEE_CDP = "34620"
LENOX_CDP = "34935"
LENOX_DALE_CDP = "35040"
LEOMINSTER_CITY = "35075"
LEXINGTON_CDP = "35250"
LITTLETON_COMMON_CDP = "36020"
LONGMEADOW_CDP = "36335"
LOWELL_CITY = "37000"
LUNENBURG_CDP = "37385"
LYNN_CITY = "37490"
LYNNFIELD_CDP = "37595"
MADAKET_CDP = "37735"
MALDEN_CITY = "37875"
MANSFIELD_CENTER_CDP = "38230"
MARBLEHEAD_CDP = "38435"
MARION_CENTER_CDP = "38575"
MARLBOROUGH_CITY = "38715"
MARSHFIELD_CDP = "38820"
MARSHFIELD_HILLS_CDP = "38960"
MASHPEE_NECK_CDP = "39152"
MATTAPOISETT_CENTER_CDP = "39485"
MAYNARD_CDP = "39660"
MEDFIELD_CDP = "39730"
MEDFORD_CITY = "39835"
MELROSE_CITY = "40115"
METHUEN_TOWN_CITY = "40710"
MIDDLEBOROUGH_CENTER_CDP = "40885"
MILFORD_CDP = "41200"
MILLERS_FALLS_CDP = "41410"
MILLIS_CLICQUOT_CDP = "41532"
MILTON_CDP = "41725"
MONOMOSCOY_ISLAND_CDP = "41960"
MONSON_CENTER_CDP = "42180"
MONUMENT_BEACH_CDP = "42670"
NAHANT_CDP = "43615"
NANTUCKET_CDP = "43755"
NEEDHAM_CDP = "44140"
NEW_BEDFORD_CITY = "45000"
NEW_SEABURY_CDP = "45500"
NEWBURYPORT_CITY = "45245"
NEWTON_CITY = "45560"
NORTH_ADAMS_CITY = "46225"
NORTH_ATTLEBOROUGH_TOWN_CITY = "46598"
NORTH_BROOKFIELD_CDP = "47100"
NORTH_EASTHAM_CDP = "47590"
NORTH_FALMOUTH_CDP = "47730"
NORTH_LAKEVILLE_CDP = "48220"
NORTH_PEMBROKE_CDP = "48710"
NORTH_PLYMOUTH_CDP = "48780"
NORTH_SCITUATE_CDP = "49165"
NORTH_SEEKONK_CDP = "49200"
NORTH_WESTPORT_CDP = "49710"
NORTHAMPTON_CITY = "46330"
NORTHBOROUGH_CDP = "46785"
NORTHFIELD_CDP = "47800"
NORTHWEST_HARWICH_CDP = "49700"
NORTON_CENTER_CDP = "50005"
NORWOOD_CDP = "50285"
OAK_BLUFFS_CDP = "50425"
OCEAN_BLUFF_BRANT_ROCK_CDP = "50862"
OCEAN_GROVE_CDP = "50880"
ONSET_CDP = "51160"
ORANGE_CDP = "51230"
ORLEANS_CDP = "51405"
OXFORD_CDP = "51790"
PALMER_TOWN_CITY = "52144"
PEABODY_CITY = "52490"
PEPPERELL_CDP = "52770"
PETERSHAM_CDP = "53085"
PINEHURST_CDP = "53680"
PITTSFIELD_CITY = "53960"
PLYMOUTH_CDP = "54275"
POCASSET_CDP = "54450"
POPPONESSET_CDP = "55070"
POPPONESSET_ISLAND_CDP = "55090"
PROVINCETOWN_CDP = "55535"
QUINCY_CITY = "55745"
RANDOLPH_TOWN_CITY = "56000"
RAYNHAM_CENTER_CDP = "56095"
READING_CDP = "56165"
REVERE_CITY = "56585"
ROCKPORT_CDP = "57845"
ROWLEY_CDP = "58370"
RUSSELL_CDP = "58615"
RUTLAND_CDP = "58790"
SAGAMORE_CDP = "58965"
SALEM_CITY = "59105"
SALISBURY_CDP = "59210"
SANDWICH_CDP = "59700"
SAUGUS_CDP = "60050"
SCITUATE_CDP = "60295"
SEABROOK_CDP = "60505"
SECONSETT_ISLAND_CDP = "60627"
SHARON_CDP = "60820"
SHELBURNE_FALLS_CDP = "61205"
SHIRLEY_CDP = "61555"
SIASCONSET_CDP = "61940"
SMITH_MILLS_CDP = "62300"
SOMERSET_CDP = "62465"
SOMERVILLE_CITY = "62535"
SOUTH_ASHBURNHAM_CDP = "62780"
SOUTH_DEERFIELD_CDP = "63620"
SOUTH_DENNIS_CDP = "63655"
SOUTH_DUXBURY_CDP = "63690"
SOUTH_LANCASTER_CDP = "64460"
SOUTH_YARMOUTH_CDP = "66035"
SOUTHBRIDGE_TOWN_CITY = "63345"
SPENCER_CDP = "66070"
SPRINGFIELD_CITY = "67000"
STONEHAM_CDP = "67700"
STURBRIDGE_CDP = "68120"
SWAMPSCOTT_CDP = "68680"
TAUNTON_CITY = "69170"
TEATICKET_CDP = "69205"
THE_PINEHILLS_CDP = "69585"
TOPSFIELD_CDP = "70115"
TOWNSEND_CDP = "70325"
TURNERS_FALLS_CDP = "70815"
UPTON_CDP = "71445"
VINEYARD_HAVEN_CDP = "71970"
WAKEFIELD_CDP = "72250"
WALPOLE_CDP = "72460"
WALTHAM_CITY = "72600"
WARE_CDP = "72845"
WAREHAM_CENTER_CDP = "73020"
WARREN_CDP = "73055"
WATERTOWN_TOWN_CITY = "73440"
WEBSTER_CDP = "73930"
WELLESLEY_CDP = "74210"
WEST_BROOKFIELD_CDP = "75365"
WEST_CHATHAM_CDP = "75505"
WEST_CONCORD_CDP = "75680"
WEST_DENNIS_CDP = "75820"
WEST_FALMOUTH_CDP = "75960"
WEST_SPRINGFIELD_TOWN_CITY = "77890"
WEST_WAREHAM_CDP = "78410"
WEST_WARREN_CDP = "78445"
WEST_YARMOUTH_CDP = "78795"
WESTBOROUGH_CDP = "75050"
WESTFIELD_CITY = "76030"
WEWEANTIC_CDP = "78850"
WEYMOUTH_TOWN_CITY = "78972"
WHITE_ISLAND_SHORES_CDP = "79390"
WHITINSVILLE_CDP = "79495"
WILBRAHAM_CDP = "79705"
WILLIAMSTOWN_CDP = "79950"
WILMINGTON_CDP = "80195"
WINCHENDON_CDP = "80370"
WINCHESTER_CDP = "80545"
WINTHROP_TOWN_CITY = "81005"
WOBURN_CITY = "81035"
WOODS_HOLE_CDP = "81245"
WORCESTER_CITY = "82000"
YARMOUTH_PORT_CDP = "82595"
