# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Missouri."""


ADAIR = "001"
ANDREW = "003"
ATCHISON = "005"
AUDRAIN = "007"
BARRY = "009"
BARTON = "011"
BATES = "013"
BENTON = "015"
BOLLINGER = "017"
BOONE = "019"
BUCHANAN = "021"
BUTLER = "023"
CALDWELL = "025"
CALLAWAY = "027"
CAMDEN = "029"
CAPE_GIRARDEAU = "031"
CARROLL = "033"
CARTER = "035"
CASS = "037"
CEDAR = "039"
CHARITON = "041"
CHRISTIAN = "043"
CLARK = "045"
CLAY = "047"
CLINTON = "049"
COLE = "051"
COOPER = "053"
CRAWFORD = "055"
DADE = "057"
DALLAS = "059"
DAVIESS = "061"
DEKALB = "063"
DENT = "065"
DOUGLAS = "067"
DUNKLIN = "069"
FRANKLIN = "071"
GASCONADE = "073"
GENTRY = "075"
GREENE = "077"
GRUNDY = "079"
HARRISON = "081"
HENRY = "083"
HICKORY = "085"
HOLT = "087"
HOWARD = "089"
HOWELL = "091"
IRON = "093"
JACKSON = "095"
JASPER = "097"
JEFFERSON = "099"
JOHNSON = "101"
KNOX = "103"
LACLEDE = "105"
LAFAYETTE = "107"
LAWRENCE = "109"
LEWIS = "111"
LINCOLN = "113"
LINN = "115"
LIVINGSTON = "117"
MACON = "121"
MADISON = "123"
MARIES = "125"
MARION = "127"
MCDONALD = "119"
MERCER = "129"
MILLER = "131"
MISSISSIPPI = "133"
MONITEAU = "135"
MONROE = "137"
MONTGOMERY = "139"
MORGAN = "141"
NEW_MADRID = "143"
NEWTON = "145"
NODAWAY = "147"
OREGON = "149"
OSAGE = "151"
OZARK = "153"
PEMISCOT = "155"
PERRY = "157"
PETTIS = "159"
PHELPS = "161"
PIKE = "163"
PLATTE = "165"
POLK = "167"
PULASKI = "169"
PUTNAM = "171"
RALLS = "173"
RANDOLPH = "175"
RAY = "177"
REYNOLDS = "179"
RIPLEY = "181"
SALINE = "195"
SCHUYLER = "197"
SCOTLAND = "199"
SCOTT = "201"
SHANNON = "203"
SHELBY = "205"
ST_CHARLES = "183"
ST_CLAIR = "185"
ST_FRANCOIS = "187"
ST_LOUIS = "189"
ST_LOUIS_CITY = "510"
STE_GENEVIEVE = "186"
STODDARD = "207"
STONE = "209"
SULLIVAN = "211"
TANEY = "213"
TEXAS = "215"
VERNON = "217"
WARREN = "219"
WASHINGTON = "221"
WAYNE = "223"
WEBSTER = "225"
WORTH = "227"
WRIGHT = "229"
