# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Utah."""


BEAVER = "001"
BOX_ELDER = "003"
CACHE = "005"
CARBON = "007"
DAGGETT = "009"
DAVIS = "011"
DUCHESNE = "013"
EMERY = "015"
GARFIELD = "017"
GRAND = "019"
IRON = "021"
JUAB = "023"
KANE = "025"
MILLARD = "027"
MORGAN = "029"
PIUTE = "031"
RICH = "033"
SALT_LAKE = "035"
SAN_JUAN = "037"
SANPETE = "039"
SEVIER = "041"
SUMMIT = "043"
TOOELE = "045"
UINTAH = "047"
UTAH = "049"
WASATCH = "051"
WASHINGTON = "053"
WAYNE = "055"
WEBER = "057"
