# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Washington."""


ADAMS = "001"
ASOTIN = "003"
BENTON = "005"
CHELAN = "007"
CLALLAM = "009"
CLARK = "011"
COLUMBIA = "013"
COWLITZ = "015"
DOUGLAS = "017"
FERRY = "019"
FRANKLIN = "021"
GARFIELD = "023"
GRANT = "025"
GRAYS_HARBOR = "027"
ISLAND = "029"
JEFFERSON = "031"
KING = "033"
KITSAP = "035"
KITTITAS = "037"
KLICKITAT = "039"
LEWIS = "041"
LINCOLN = "043"
MASON = "045"
OKANOGAN = "047"
PACIFIC = "049"
PEND_OREILLE = "051"
PIERCE = "053"
SAN_JUAN = "055"
SKAGIT = "057"
SKAMANIA = "059"
SNOHOMISH = "061"
SPOKANE = "063"
STEVENS = "065"
THURSTON = "067"
WAHKIAKUM = "069"
WALLA_WALLA = "071"
WHATCOM = "073"
WHITMAN = "075"
YAKIMA = "077"
