# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Nebraska."""


ADAMS = "001"
ANTELOPE = "003"
ARTHUR = "005"
BANNER = "007"
BLAINE = "009"
BOONE = "011"
BOX_BUTTE = "013"
BOYD = "015"
BROWN = "017"
BUFFALO = "019"
BURT = "021"
BUTLER = "023"
CASS = "025"
CEDAR = "027"
CHASE = "029"
CHERRY = "031"
CHEYENNE = "033"
CLAY = "035"
COLFAX = "037"
CUMING = "039"
CUSTER = "041"
DAKOTA = "043"
DAWES = "045"
DAWSON = "047"
DEUEL = "049"
DIXON = "051"
DODGE = "053"
DOUGLAS = "055"
DUNDY = "057"
FILLMORE = "059"
FRANKLIN = "061"
FRONTIER = "063"
FURNAS = "065"
GAGE = "067"
GARDEN = "069"
GARFIELD = "071"
GOSPER = "073"
GRANT = "075"
GREELEY = "077"
HALL = "079"
HAMILTON = "081"
HARLAN = "083"
HAYES = "085"
HITCHCOCK = "087"
HOLT = "089"
HOOKER = "091"
HOWARD = "093"
JEFFERSON = "095"
JOHNSON = "097"
KEARNEY = "099"
KEITH = "101"
KEYA_PAHA = "103"
KIMBALL = "105"
KNOX = "107"
LANCASTER = "109"
LINCOLN = "111"
LOGAN = "113"
LOUP = "115"
MADISON = "119"
MCPHERSON = "117"
MERRICK = "121"
MORRILL = "123"
NANCE = "125"
NEMAHA = "127"
NUCKOLLS = "129"
OTOE = "131"
PAWNEE = "133"
PERKINS = "135"
PHELPS = "137"
PIERCE = "139"
PLATTE = "141"
POLK = "143"
RED_WILLOW = "145"
RICHARDSON = "147"
ROCK = "149"
SALINE = "151"
SARPY = "153"
SAUNDERS = "155"
SCOTTS_BLUFF = "157"
SEWARD = "159"
SHERIDAN = "161"
SHERMAN = "163"
SIOUX = "165"
STANTON = "167"
THAYER = "169"
THOMAS = "171"
THURSTON = "173"
VALLEY = "175"
WASHINGTON = "177"
WAYNE = "179"
WEBSTER = "181"
WHEELER = "183"
YORK = "185"
