# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Maine."""


ALFRED_CDP = "00695"
ANSON_CDP = "01360"
ASHLAND_CDP = "01675"
AUBURN_CITY = "02060"
AUGUSTA_CITY = "02100"
BANGOR_CITY = "02795"
BAR_HARBOR_CDP = "02830"
BATH_CITY = "03355"
BELFAST_CITY = "03950"
BERWICK_CDP = "04685"
BETHEL_CDP = "04790"
BIDDEFORD_CITY = "04860"
BINGHAM_CDP = "04965"
BLAINE_CDP = "05350"
BLUE_HILL_CDP = "05665"
BOOTHBAY_HARBOR_CDP = "06085"
BOWDOINHAM_CDP = "06330"
BRADLEY_CDP = "06645"
BREWER_CITY = "06925"
BRIDGTON_CDP = "07135"
BROWNVILLE_JUNCTION_CDP = "08360"
BRUNSWICK_CDP = "08395"
BUCKSPORT_CDP = "08780"
CALAIS_CITY = "09585"
CAMDEN_CDP = "09690"
CAPE_NEDDICK_CDP = "10320"
CARIBOU_CITY = "10565"
CASCO_CDP = "11090"
CASTINE_CDP = "11230"
CHISHOLM_CDP = "12770"
CLINTON_CDP = "13435"
CORINNA_CDP = "14275"
CORNISH_CDP = "14450"
COUSINS_ISLAND_CDP = "14800"
CUMBERLAND_CENTER_CDP = "15500"
DAMARISCOTTA_CDP = "16200"
DANFORTH_CDP = "16375"
DEXTER_CDP = "17495"
DIXFIELD_CDP = "17705"
DOVER_FOXCROFT_CDP = "18230"
DUNSTAN_CDP = "18965"
EAGLE_LAKE_CDP = "19385"
EAST_MILLINOCKET_CDP = "21065"
EASTPORT_CITY = "21730"
ELLSWORTH_CITY = "23200"
FAIRFIELD_CDP = "24285"
FALMOUTH_CDP = "24480"
FALMOUTH_FORESIDE_CDP = "24530"
FARMINGDALE_CDP = "24635"
FARMINGTON_CDP = "24740"
FORT_FAIRFIELD_CDP = "25580"
FORT_KENT_CDP = "25720"
FREEPORT_CDP = "26490"
FRYEBURG_CDP = "26875"
GARDINER_CITY = "27085"
GORHAM_CDP = "28205"
GRAND_ISLE_CDP = "28555"
GRAY_CDP = "28835"
GREENE_CDP = "29220"
GREENVILLE_CDP = "29500"
GUILFORD_CDP = "30060"
HALLOWELL_CITY = "30550"
HAMPDEN_CDP = "30760"
HARTLAND_CDP = "31705"
HOULTON_CDP = "33945"
HOWLAND_CDP = "34225"
ISLAND_FALLS_CDP = "35030"
JONESPORT_CDP = "35975"
KENNEBUNK_CDP = "36500"
KENNEBUNKPORT_CDP = "36710"
KEZAR_FALLS_CDP = "36885"
KINGFIELD_CDP = "36990"
KITTERY_CDP = "37235"
KITTERY_POINT_CDP = "37375"
LAKE_ARROWHEAD_CDP = "37795"
LEWISTON_CITY = "38740"
LIMESTONE_CDP = "39265"
LINCOLN_CDP = "39440"
LISBON_CDP = "40000"
LISBON_FALLS_CDP = "40105"
LITTLE_FALLS_CDP = "40350"
LITTLEJOHN_ISLAND_CDP = "40470"
LIVERMORE_FALLS_CDP = "40735"
LUBEC_CDP = "41575"
MACHIAS_CDP = "41925"
MADAWASKA_CDP = "42485"
MADISON_CDP = "42625"
MAPLETON_CDP = "43220"
MARS_HILL_CDP = "43675"
MATTAWAMKEAG_CDP = "44235"
MECHANIC_FALLS_CDP = "44620"
MEXICO_CDP = "45250"
MILBRIDGE_CDP = "45565"
MILFORD_CDP = "45635"
MILLINOCKET_CDP = "45845"
MILO_CDP = "45985"
NAPLES_CDP = "48050"
NEWCASTLE_CDP = "48610"
NEWPORT_CDP = "49100"
NORRIDGEWOCK_CDP = "49800"
NORTH_ANSON_CDP = "49975"
NORTH_BERWICK_CDP = "50290"
NORTH_WINDHAM_CDP = "53685"
NORTHEAST_HARBOR_CDP = "51095"
NORWAY_CDP = "53965"
OAK_HILL_CDP = "54490"
OAKFIELD_CDP = "54350"
OAKLAND_CDP = "54525"
OLD_ORCHARD_BEACH_CDP = "55120"
OLD_TOWN_CITY = "55225"
ORONO_CDP = "55575"
OXFORD_CDP = "56240"
PATTEN_CDP = "57115"
PITTSFIELD_CDP = "58970"
PORTLAND_CITY = "60545"
PRESQUE_ISLE_CITY = "60825"
RANDOLPH_CDP = "61735"
RANGELEY_CDP = "61805"
RICHMOND_CDP = "62610"
ROCKLAND_CITY = "63590"
RUMFORD_CDP = "64255"
SABATTUS_CDP = "64535"
SACO_CITY = "64675"
SANFORD_CITY = "65725"
SEARSPORT_CDP = "66600"
SKOWHEGAN_CDP = "68875"
SOUTH_BERWICK_CDP = "69995"
SOUTH_ELIOT_CDP = "70660"
SOUTH_PARIS_CDP = "71780"
SOUTH_PORTLAND_CITY = "71990"
SOUTH_WINDHAM_CDP = "72900"
SOUTHWEST_HARBOR_CDP = "72830"
STANDISH_CDP = "73635"
STEEP_FALLS_CDP = "73985"
THOMASTON_CDP = "76330"
TOPSHAM_CDP = "76925"
TURNER_CDP = "77765"
UNITY_CDP = "78220"
VAN_BUREN_CDP = "78535"
VANCEBORO_CDP = "78640"
VEAZIE_CDP = "78815"
WALDOBORO_CDP = "79515"
WASHBURN_CDP = "80250"
WATERVILLE_CITY = "80740"
WEST_KENNEBUNK_CDP = "83330"
WESTBROOK_CITY = "82105"
WILTON_CDP = "85815"
WINSLOW_CDP = "86480"
WINTER_HARBOR_CDP = "86620"
WINTERPORT_CDP = "86725"
WINTHROP_CDP = "86935"
WISCASSET_CDP = "87040"
WOODLAND_CDP = "87250"
YARMOUTH_CDP = "87810"
YORK_HARBOR_CDP = "88160"
