# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Minnesota."""


AITKIN = "001"
ANOKA = "003"
BECKER = "005"
BELTRAMI = "007"
BENTON = "009"
BIG_STONE = "011"
BLUE_EARTH = "013"
BROWN = "015"
CARLTON = "017"
CARVER = "019"
CASS = "021"
CHIPPEWA = "023"
CHISAGO = "025"
CLAY = "027"
CLEARWATER = "029"
COOK = "031"
COTTONWOOD = "033"
CROW_WING = "035"
DAKOTA = "037"
DODGE = "039"
DOUGLAS = "041"
FARIBAULT = "043"
FILLMORE = "045"
FREEBORN = "047"
GOODHUE = "049"
GRANT = "051"
HENNEPIN = "053"
HOUSTON = "055"
HUBBARD = "057"
ISANTI = "059"
ITASCA = "061"
JACKSON = "063"
KANABEC = "065"
KANDIYOHI = "067"
KITTSON = "069"
KOOCHICHING = "071"
LAC_QUI_PARLE = "073"
LAKE = "075"
LAKE_OF_THE_WOODS = "077"
LE_SUEUR = "079"
LINCOLN = "081"
LYON = "083"
MAHNOMEN = "087"
MARSHALL = "089"
MARTIN = "091"
MCLEOD = "085"
MEEKER = "093"
MILLE_LACS = "095"
MORRISON = "097"
MOWER = "099"
MURRAY = "101"
NICOLLET = "103"
NOBLES = "105"
NORMAN = "107"
OLMSTED = "109"
OTTER_TAIL = "111"
PENNINGTON = "113"
PINE = "115"
PIPESTONE = "117"
POLK = "119"
POPE = "121"
RAMSEY = "123"
RED_LAKE = "125"
REDWOOD = "127"
RENVILLE = "129"
RICE = "131"
ROCK = "133"
ROSEAU = "135"
SCOTT = "139"
SHERBURNE = "141"
SIBLEY = "143"
ST_LOUIS = "137"
STEARNS = "145"
STEELE = "147"
STEVENS = "149"
SWIFT = "151"
TODD = "153"
TRAVERSE = "155"
WABASHA = "157"
WADENA = "159"
WASECA = "161"
WASHINGTON = "163"
WATONWAN = "165"
WILKIN = "167"
WINONA = "169"
WRIGHT = "171"
YELLOW_MEDICINE = "173"
