# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Vermont."""


ADDISON = "001"
BENNINGTON = "003"
CALEDONIA = "005"
CHITTENDEN = "007"
ESSEX = "009"
FRANKLIN = "011"
GRAND_ISLE = "013"
LAMOILLE = "015"
ORANGE = "017"
ORLEANS = "019"
RUTLAND = "021"
WASHINGTON = "023"
WINDHAM = "025"
WINDSOR = "027"
