# Copyright (c) 2023 Darren Erik Vengroff
"""Places in North Carolina."""


ABERDEEN_TOWN = "00160"
ADVANCE_CDP = "00440"
AHOSKIE_TOWN = "00500"
ALAMANCE_VILLAGE = "00640"
ALBEMARLE_CITY = "00680"
ALEXIS_CDP = "00880"
ALLIANCE_TOWN = "01000"
ALTAMAHAW_CDP = "01140"
ANDERSON_CREEK_CDP = "01340"
ANDREWS_TOWN = "01380"
ANGIER_TOWN = "01400"
ANSONVILLE_TOWN = "01420"
APEX_TOWN = "01520"
AQUADALE_CDP = "01560"
ARAPAHOE_TOWN = "01640"
ARCHDALE_CITY = "01720"
ARCHER_LODGE_TOWN = "01760"
ARROWHEAD_BEACH_CDP = "01972"
ASHEBORO_CITY = "02080"
ASHEVILLE_CITY = "02140"
ASHLEY_HEIGHTS_CDP = "02240"
ASKEWVILLE_TOWN = "02320"
ATKINSON_TOWN = "02460"
ATLANTIC_BEACH_TOWN = "02500"
ATLANTIC_CDP = "02480"
AULANDER_TOWN = "02580"
AURORA_TOWN = "02620"
AUTRYVILLE_TOWN = "02700"
AVERY_CREEK_CDP = "02760"
AVON_CDP = "02780"
AYDEN_TOWN = "02840"
BADIN_TOWN = "02960"
BAILEY_TOWN = "03020"
BAKERSVILLE_TOWN = "03100"
BALD_HEAD_ISLAND_VILLAGE = "03150"
BALFOUR_CDP = "03220"
BANNER_ELK_TOWN = "03500"
BARKER_HEIGHTS_CDP = "03640"
BARKER_TEN_MILE_CDP = "03665"
BARNARDSVILLE_CDP = "03720"
BATH_TOWN = "03840"
BAYBORO_TOWN = "03960"
BAYSHORE_CDP = "04015"
BAYVIEW_CDP = "04040"
BEAR_GRASS_TOWN = "04180"
BEAUFORT_TOWN = "04260"
BEECH_MOUNTAIN_TOWN = "04510"
BELHAVEN_TOWN = "04640"
BELL_ARTHUR_CDP = "04680"
BELMONT_CITY = "04840"
BELVILLE_TOWN = "04950"
BELVOIR_CDP = "04955"
BELWOOD_TOWN = "04960"
BENNETT_CDP = "05020"
BENSON_TOWN = "05040"
BENT_CREEK_CDP = "05049"
BERMUDA_RUN_TOWN = "05135"
BESSEMER_CITY_CITY = "05220"
BETHANIA_TOWN = "05340"
BETHEL_TOWN = "05460"
BETHLEHEM_CDP = "05530"
BEULAVILLE_TOWN = "05660"
BILTMORE_FOREST_TOWN = "05880"
BISCOE_TOWN = "06000"
BLACK_CREEK_TOWN = "06080"
BLACK_MOUNTAIN_TOWN = "06140"
BLADENBORO_TOWN = "06240"
BLOWING_ROCK_TOWN = "06500"
BLUE_CLAY_FARMS_CDP = "06510"
BOARDMAN_TOWN = "06660"
BOGUE_TOWN = "06740"
BOILING_SPRING_LAKES_CITY = "06760"
BOILING_SPRINGS_TOWN = "06800"
BOLIVIA_TOWN = "06820"
BOLTON_TOWN = "06860"
BONNETSVILLE_CDP = "06980"
BOONE_TOWN = "07080"
BOONVILLE_TOWN = "07140"
BOSTIC_TOWN = "07220"
BOWDENS_CDP = "07340"
BOWMORE_CDP = "07400"
BRANDYWINE_BAY_CDP = "07588"
BREVARD_CITY = "07720"
BRIAR_CHAPEL_CDP = "07748"
BRICES_CREEK_CDP = "07765"
BRIDGETON_TOWN = "07860"
BROAD_CREEK_CDP = "08040"
BROADWAY_TOWN = "08080"
BROGDEN_CDP = "08110"
BROOKFORD_TOWN = "08140"
BRUNSWICK_TOWN = "08420"
BRYSON_CITY_TOWN = "08480"
BUIES_CREEK_CDP = "08760"
BUNN_TOWN = "08860"
BUNNLEVEL_CDP = "08880"
BURGAW_TOWN = "08960"
BURLINGTON_CITY = "09060"
BURNSVILLE_TOWN = "09140"
BUTNER_TOWN = "09360"
BUTTERS_CDP = "09380"
BUXTON_CDP = "09400"
CAJAHS_MOUNTAIN_TOWN = "09530"
CALABASH_TOWN = "09540"
CALYPSO_TOWN = "09760"
CAMDEN_CDP = "09780"
CAMERON_TOWN = "09800"
CANDOR_TOWN = "10120"
CANTON_TOWN = "10240"
CAPE_CARTERET_TOWN = "10260"
CAPE_COLONY_CDP = "10264"
CAROLEEN_CDP = "10460"
CAROLINA_BEACH_TOWN = "10500"
CAROLINA_MEADOWS_CDP = "10532"
CAROLINA_SHORES_TOWN = "10550"
CARRBORO_TOWN = "10620"
CARTHAGE_TOWN = "10680"
CARY_TOWN = "10740"
CASAR_TOWN = "10760"
CASHIERS_CDP = "10800"
CASTALIA_TOWN = "10860"
CASTLE_HAYNE_CDP = "10880"
CASWELL_BEACH_TOWN = "10960"
CATAWBA_TOWN = "10980"
CEDAR_POINT_TOWN = "11340"
CEDAR_ROCK_VILLAGE = "11352"
CENTERVILLE_CDP = "11560"
CERRO_GORDO_TOWN = "11620"
CHADBOURN_TOWN = "11640"
CHAPEL_HILL_TOWN = "11800"
CHARLOTTE_CITY = "12000"
CHEROKEE_CDP = "12140"
CHERRY_BRANCH_CDP = "12186"
CHERRYVILLE_CITY = "12340"
CHIMNEY_ROCK_VILLAGE_VILLAGE = "12460"
CHINA_GROVE_TOWN = "12480"
CHINQUAPIN_CDP = "12520"
CHOCOWINITY_TOWN = "12580"
CHOWAN_BEACH_CDP = "12590"
CLAREMONT_CITY = "12720"
CLARKTON_TOWN = "12780"
CLAYTON_TOWN = "12860"
CLEMMONS_VILLAGE = "12960"
CLEVELAND_TOWN = "13000"
CLIFFSIDE_CDP = "13100"
CLINTON_CITY = "13240"
CLYDE_TOWN = "13280"
COATS_TOWN = "13360"
COFIELD_VILLAGE = "13460"
COINJOCK_CDP = "13500"
COLERAIN_TOWN = "13560"
COLUMBIA_TOWN = "13940"
COLUMBUS_TOWN = "13980"
COMO_TOWN = "14060"
CONCORD_CITY = "14100"
CONETOE_TOWN = "14200"
CONNELLY_SPRINGS_TOWN = "14280"
CONOVER_CITY = "14340"
CONWAY_TOWN = "14400"
COOLEEMEE_TOWN = "14460"
CORDOVA_CDP = "14600"
CORNELIUS_TOWN = "14700"
COVE_CITY_TOWN = "15020"
COVE_CREEK_CDP = "15040"
CRAMERTON_TOWN = "15260"
CREEDMOOR_CITY = "15320"
CRESWELL_TOWN = "15420"
CRICKET_CDP = "15440"
CROSSNORE_TOWN = "15580"
CROUSE_CDP = "15640"
CULLOWHEE_CDP = "15880"
CYPRESS_LANDING_CDP = "16084"
DALLAS_TOWN = "16180"
DANA_CDP = "16220"
DANBURY_TOWN = "16240"
DAVIDSON_TOWN = "16400"
DAVIS_CDP = "16480"
DEEP_RUN_CDP = "16720"
DEERCROFT_CDP = "16730"
DELCO_CDP = "16780"
DELLVIEW_TOWN = "16820"
DELWAY_CDP = "16860"
DENTON_TOWN = "16980"
DENVER_CDP = "17000"
DILLSBORO_TOWN = "17180"
DOBBINS_HEIGHTS_TOWN = "17325"
DOBSON_TOWN = "17340"
DORTCHES_TOWN = "17520"
DOVER_TOWN = "17660"
DREXEL_TOWN = "17860"
DUBLIN_TOWN = "18040"
DUCK_TOWN = "18060"
DUDLEY_CDP = "18080"
DUNDARRACH_CDP = "18300"
DUNN_CITY = "18320"
DURHAM_CITY = "19000"
EARL_TOWN = "19140"
EAST_ARCADIA_TOWN = "19300"
EAST_BEND_TOWN = "19320"
EAST_FLAT_ROCK_CDP = "19420"
EAST_LAURINBURG_TOWN = "19620"
EAST_ROCKINGHAM_CDP = "19800"
EAST_SPENCER_TOWN = "19860"
EASTOVER_TOWN = "19740"
EDEN_CITY = "20080"
EDENTON_TOWN = "20120"
EDNEYVILLE_CDP = "20280"
EFLAND_CDP = "20420"
ELIZABETH_CITY_CITY = "20580"
ELIZABETHTOWN_TOWN = "20600"
ELK_PARK_TOWN = "20700"
ELKIN_TOWN = "20620"
ELLENBORO_TOWN = "20780"
ELLERBE_TOWN = "20840"
ELM_CITY_TOWN = "20980"
ELON_TOWN = "21095"
ELROD_CDP = "21120"
ELROY_CDP = "21130"
EMERALD_ISLE_TOWN = "21160"
EMMA_CDP = "21260"
ENFIELD_TOWN = "21360"
ENGELHARD_CDP = "21380"
ENOCHVILLE_CDP = "21500"
ERWIN_TOWN = "21740"
ETOWAH_CDP = "21880"
EUREKA_TOWN = "21960"
EVERETTS_TOWN = "22040"
EVERGREEN_CDP = "22080"
FAIR_BLUFF_TOWN = "22240"
FAIRFIELD_CDP = "22280"
FAIRFIELD_HARBOUR_CDP = "22305"
FAIRMONT_TOWN = "22360"
FAIRPLAINS_CDP = "22380"
FAIRVIEW_CDP = "22440"
FAIRVIEW_TOWN = "22500"
FAISON_TOWN = "22560"
FAITH_TOWN = "22600"
FALCON_TOWN = "22620"
FALKLAND_TOWN = "22640"
FALLSTON_TOWN = "22720"
FARMINGTON_CDP = "22800"
FARMVILLE_TOWN = "22820"
FAYETTEVILLE_CITY = "22920"
FEARRINGTON_VILLAGE_CDP = "22982"
FIVE_POINTS_CDP = "23520"
FLAT_ROCK_CDP = "23640"
FLAT_ROCK_VILLAGE = "23600"
FLETCHER_TOWN = "23760"
FONTANA_DAM_TOWN = "23980"
FOREST_CITY_TOWN = "24080"
FOREST_HILLS_VILLAGE = "24170"
FOREST_OAKS_CDP = "24198"
FOSCOE_CDP = "24380"
FOUNTAIN_TOWN = "24440"
FOUR_OAKS_TOWN = "24520"
FOXFIRE_VILLAGE = "24570"
FRANKLIN_TOWN = "24640"
FRANKLINTON_TOWN = "24720"
FRANKLINVILLE_TOWN = "24740"
FREMONT_TOWN = "24900"
FRISCO_CDP = "25020"
FRUITLAND_CDP = "25160"
FUQUAY_VARINA_TOWN = "25300"
GAMEWELL_TOWN = "25380"
GARLAND_TOWN = "25460"
GARNER_TOWN = "25480"
GARYSBURG_TOWN = "25540"
GASTON_TOWN = "25560"
GASTONIA_CITY = "25580"
GATESVILLE_TOWN = "25680"
GERMANTON_CDP = "25880"
GERTON_CDP = "25900"
GIBSON_TOWN = "25940"
GIBSONVILLE_TOWN = "25980"
GLEN_ALPINE_TOWN = "26200"
GLEN_RAVEN_CDP = "26460"
GLENVILLE_CDP = "26520"
GLENWOOD_CDP = "26560"
GLOUCESTER_CDP = "26680"
GODWIN_TOWN = "26740"
GOLD_HILL_CDP = "26800"
GOLDSBORO_CITY = "26880"
GOLDSTON_TOWN = "26920"
GORMAN_CDP = "27120"
GOVERNORS_CLUB_CDP = "27180"
GOVERNORS_VILLAGE_CDP = "27182"
GRAHAM_CITY = "27280"
GRAINGERS_CDP = "27300"
GRANDFATHER_VILLAGE_VILLAGE = "27324"
GRANDY_CDP = "27400"
GRANITE_FALLS_TOWN = "27420"
GRANITE_QUARRY_TOWN = "27440"
GRANTSBORO_TOWN = "27520"
GREEN_LEVEL_TOWN = "27870"
GREENEVERS_TOWN = "27780"
GREENSBORO_CITY = "28000"
GREENVILLE_CITY = "28080"
GRIFTON_TOWN = "28200"
GRIMESLAND_TOWN = "28240"
GROVER_TOWN = "28400"
GULF_CDP = "28600"
HALF_MOON_CDP = "28900"
HALIFAX_TOWN = "28920"
HALLSBORO_CDP = "29000"
HAMILTON_TOWN = "29120"
HAMLET_CITY = "29160"
HAMPSTEAD_CDP = "29180"
HARKERS_ISLAND_CDP = "29560"
HARMONY_TOWN = "29640"
HARRELLS_TOWN = "29680"
HARRELLSVILLE_TOWN = "29720"
HARRISBURG_TOWN = "29800"
HASSELL_TOWN = "30040"
HATTERAS_CDP = "30100"
HAVELOCK_CITY = "30120"
HAW_RIVER_TOWN = "30260"
HAYESVILLE_TOWN = "30280"
HAYS_CDP = "30340"
HEMBY_BRIDGE_TOWN = "30620"
HENDERSON_CITY = "30660"
HENDERSONVILLE_CITY = "30720"
HENRIETTA_CDP = "30800"
HERTFORD_TOWN = "30900"
HICKORY_CITY = "31060"
HIDDENITE_CDP = "31260"
HIGH_POINT_CITY = "31400"
HIGH_SHOALS_CITY = "31440"
HIGHLANDS_TOWN = "31360"
HIGHTSVILLE_CDP = "31490"
HILDEBRAN_TOWN = "31500"
HILLSBOROUGH_TOWN = "31620"
HOBGOOD_TOWN = "31860"
HOBUCKEN_CDP = "31880"
HOFFMAN_TOWN = "31920"
HOLDEN_BEACH_TOWN = "31960"
HOLLISTER_CDP = "32100"
HOLLY_RIDGE_TOWN = "32180"
HOLLY_SPRINGS_TOWN = "32260"
HOOKERTON_TOWN = "32540"
HOOPERS_CREEK_CDP = "32580"
HOPE_MILLS_TOWN = "32640"
HORSE_SHOE_CDP = "32740"
HOT_SPRINGS_TOWN = "32840"
HUDSON_TOWN = "32980"
HUNTERSVILLE_TOWN = "33120"
ICARD_CDP = "33320"
INDIAN_BEACH_TOWN = "33460"
INDIAN_TRAIL_TOWN = "33560"
INGOLD_CDP = "33640"
IRON_STATION_CDP = "33820"
IVANHOE_CDP = "33940"
JAARS_CDP = "33993"
JACKSON_HEIGHTS_CDP = "34038"
JACKSON_SPRINGS_CDP = "34160"
JACKSON_TOWN = "34000"
JACKSONVILLE_CITY = "34200"
JAMES_CITY_CDP = "34260"
JAMESTOWN_TOWN = "34300"
JAMESVILLE_TOWN = "34320"
JEFFERSON_TOWN = "34440"
JONESVILLE_TOWN = "34840"
KANNAPOLIS_CITY = "35200"
KEENER_CDP = "35340"
KELFORD_TOWN = "35360"
KELLY_CDP = "35440"
KENANSVILLE_TOWN = "35460"
KENLY_TOWN = "35540"
KERNERSVILLE_TOWN = "35600"
KILL_DEVIL_HILLS_TOWN = "35720"
KING_CITY = "35760"
KINGS_GRANT_CDP = "35870"
KINGS_MOUNTAIN_CITY = "35880"
KINGSTOWN_TOWN = "35890"
KINSTON_CITY = "35920"
KITTRELL_TOWN = "36020"
KITTY_HAWK_TOWN = "36060"
KNIGHTDALE_TOWN = "36080"
KURE_BEACH_TOWN = "36220"
LA_GRANGE_TOWN = "36400"
LAKE_JUNALUSKA_CDP = "36480"
LAKE_LURE_TOWN = "36500"
LAKE_NORMAN_OF_CATAWBA_CDP = "36510"
LAKE_NORMAN_OF_IREDELL_CDP = "36511"
LAKE_PARK_VILLAGE = "36512"
LAKE_ROYALE_CDP = "36513"
LAKE_SANTEETLAH_TOWN = "36514"
LAKE_WACCAMAW_TOWN = "36640"
LANDIS_TOWN = "36860"
LANSING_TOWN = "36960"
LASKER_TOWN = "37000"
LATTIMORE_TOWN = "37040"
LAUREL_HILL_CDP = "37120"
LAUREL_PARK_TOWN = "37160"
LAURINBURG_CITY = "37220"
LAWNDALE_TOWN = "37260"
LEGGETT_TOWN = "37640"
LELAND_TOWN = "37680"
LENOIR_CITY = "37760"
LEWISTON_WOODVILLE_TOWN = "38030"
LEWISVILLE_TOWN = "38040"
LEXINGTON_CITY = "38060"
LIBERTY_TOWN = "38100"
LIGHT_OAK_CDP = "38170"
LILESVILLE_TOWN = "38200"
LILLINGTON_TOWN = "38220"
LINCOLNTON_CITY = "38320"
LINDEN_TOWN = "38360"
LINVILLE_CDP = "38420"
LITTLETON_TOWN = "38680"
LOCUST_CITY = "38860"
LONG_CREEK_CDP = "39060"
LONG_VIEW_TOWN = "39280"
LOUISBURG_TOWN = "39360"
LOVE_VALLEY_TOWN = "39420"
LOWELL_CITY = "39480"
LOWESVILLE_CDP = "39520"
LOWGAP_CDP = "39540"
LUCAMA_TOWN = "39600"
LUMBER_BRIDGE_TOWN = "39680"
LUMBERTON_CITY = "39700"
MACCLESFIELD_TOWN = "39960"
MACON_TOWN = "40540"
MADISON_TOWN = "40560"
MAGGIE_VALLEY_TOWN = "40600"
MAGNOLIA_TOWN = "40640"
MAIDEN_TOWN = "40660"
MAMERS_CDP = "40860"
MANNS_HARBOR_CDP = "40980"
MANTEO_TOWN = "41060"
MAR_MAC_CDP = "41540"
MARBLE_CDP = "41220"
MARIETTA_TOWN = "41380"
MARION_CITY = "41420"
MARS_HILL_TOWN = "41620"
MARSHALL_TOWN = "41580"
MARSHALLBERG_CDP = "41600"
MARSHVILLE_TOWN = "41640"
MARVIN_VILLAGE = "41720"
MATTHEWS_TOWN = "41960"
MAURY_CDP = "42000"
MAXTON_TOWN = "42020"
MAYODAN_TOWN = "42060"
MAYSVILLE_TOWN = "42100"
MCADENVILLE_TOWN = "39880"
MCDONALD_TOWN = "40140"
MCFARLAN_TOWN = "40240"
MCLEANSVILLE_CDP = "40460"
MEBANE_CITY = "42240"
MESIC_TOWN = "42480"
MICRO_TOWN = "42620"
MIDDLEBURG_TOWN = "42640"
MIDDLESEX_TOWN = "42700"
MIDLAND_TOWN = "42760"
MIDWAY_TOWN = "42860"
MILLERS_CREEK_CDP = "43160"
MILLINGPORT_CDP = "43200"
MILLS_RIVER_TOWN = "43260"
MILTON_TOWN = "43300"
MILWAUKEE_CDP = "43320"
MINERAL_SPRINGS_TOWN = "43360"
MINNESOTT_BEACH_TOWN = "43440"
MINT_HILL_TOWN = "43480"
MISENHEIMER_VILLAGE = "43580"
MOCKSVILLE_TOWN = "43720"
MOMEYER_TOWN = "43860"
MONCURE_CDP = "43880"
MONROE_CITY = "43920"
MONTREAT_TOWN = "44100"
MOORESBORO_TOWN = "44160"
MOORESVILLE_TOWN = "44220"
MORAVIAN_FALLS_CDP = "44280"
MOREHEAD_CITY_TOWN = "44320"
MORGANTON_CITY = "44400"
MORRISVILLE_TOWN = "44520"
MORVEN_TOWN = "44560"
MOUNT_AIRY_CITY = "44800"
MOUNT_GILEAD_TOWN = "44900"
MOUNT_HOLLY_CITY = "44960"
MOUNT_OLIVE_TOWN = "45100"
MOUNT_PLEASANT_TOWN = "45140"
MOUNTAIN_HOME_CDP = "44700"
MOUNTAIN_VIEW_CDP = "44770"
MOYOCK_CDP = "45460"
MULBERRY_CDP = "45560"
MURFREESBORO_TOWN = "45640"
MURPHY_TOWN = "45660"
MURRAYSVILLE_CDP = "45720"
MYRTLE_GROVE_CDP = "45840"
NAGS_HEAD_TOWN = "45880"
NASHVILLE_TOWN = "46000"
NAVASSA_TOWN = "46060"
NEBO_CDP = "46100"
NEUSE_FOREST_CDP = "46280"
NEW_BERN_CITY = "46340"
NEW_HOPE_CDP = "46650"
NEW_LONDON_TOWN = "46820"
NEWLAND_TOWN = "46740"
NEWPORT_TOWN = "46860"
NEWTON_GROVE_TOWN = "47020"
NEWTON_CITY = "47000"
NORLINA_TOWN = "47240"
NORMAN_TOWN = "47260"
NORTH_TOPSAIL_BEACH_TOWN = "47845"
NORTH_WILKESBORO_TOWN = "47880"
NORTHCHASE_CDP = "47485"
NORTHLAKES_CDP = "47695"
NORTHWEST_CITY = "47860"
NORWOOD_TOWN = "47980"
OAK_CITY_TOWN = "48060"
OAK_ISLAND_TOWN = "48345"
OAK_RIDGE_TOWN = "48480"
OAKBORO_TOWN = "48040"
OCEAN_ISLE_BEACH_TOWN = "48700"
OCRACOKE_CDP = "48740"
OGDEN_CDP = "48790"
OLD_FORT_TOWN = "48920"
OLD_HUNDRED_CDP = "48940"
ORIENTAL_TOWN = "49380"
ORRUM_TOWN = "49460"
OSSIPEE_TOWN = "49600"
OXFORD_CITY = "49800"
PANTEGO_TOWN = "50080"
PARKTON_TOWN = "50340"
PARMELE_TOWN = "50540"
PATTERSON_SPRINGS_TOWN = "50700"
PEACHLAND_TOWN = "50820"
PELETIER_TOWN = "51040"
PEMBROKE_TOWN = "51080"
PIKEVILLE_TOWN = "51780"
PILOT_MOUNTAIN_TOWN = "51820"
PINE_KNOLL_SHORES_TOWN = "52000"
PINE_LEVEL_TOWN = "52020"
PINEBLUFF_TOWN = "51840"
PINEHURST_VILLAGE = "51940"
PINETOPS_TOWN = "52140"
PINETOWN_CDP = "52160"
PINEVILLE_TOWN = "52220"
PINEY_GREEN_CDP = "52260"
PINK_HILL_TOWN = "52400"
PINNACLE_CDP = "52500"
PITTSBORO_TOWN = "52660"
PLAIN_VIEW_CDP = "52685"
PLEASANT_GARDEN_TOWN = "52760"
PLEASANT_HILL_CDP = "52920"
PLYMOUTH_TOWN = "53040"
POLKTON_TOWN = "53140"
POLKVILLE_CITY = "53160"
POLLOCKSVILLE_TOWN = "53200"
PORTERS_NECK_CDP = "53475"
POTTERS_HILL_CDP = "53580"
POWELLSVILLE_TOWN = "53680"
PRINCETON_TOWN = "53820"
PRINCEVILLE_TOWN = "53840"
PROCTORVILLE_TOWN = "53900"
PROSPECT_CDP = "53950"
PUMPKIN_CENTER_CDP = "54160"
RAEFORD_CITY = "54580"
RAEMON_CDP = "54600"
RALEIGH_CITY = "55000"
RAMSEUR_TOWN = "55040"
RANDLEMAN_CITY = "55080"
RANLO_TOWN = "55260"
RAYNHAM_TOWN = "55340"
RED_CROSS_TOWN = "55460"
RED_OAK_TOWN = "55640"
RED_SPRINGS_TOWN = "55660"
REIDSVILLE_CITY = "55900"
RENNERT_TOWN = "55940"
REX_CDP = "56100"
RHODHISS_TOWN = "56240"
RICH_SQUARE_TOWN = "56440"
RICHFIELD_TOWN = "56340"
RICHLANDS_TOWN = "56360"
RIEGELWOOD_CDP = "56600"
RIVER_BEND_TOWN = "56710"
RIVER_ROAD_CDP = "56815"
ROANOKE_RAPIDS_CITY = "56900"
ROBBINS_TOWN = "57000"
ROBBINSVILLE_TOWN = "57020"
ROBERDEL_CDP = "57039"
ROBERSONVILLE_TOWN = "57100"
ROCKFISH_CDP = "57200"
ROCKINGHAM_CITY = "57260"
ROCKWELL_TOWN = "57340"
ROCKY_MOUNT_CITY = "57500"
ROCKY_POINT_CDP = "57540"
RODANTHE_CDP = "57580"
ROLESVILLE_TOWN = "57640"
RONDA_TOWN = "57700"
ROPER_TOWN = "57740"
ROSE_HILL_TOWN = "57860"
ROSEBORO_TOWN = "57800"
ROSMAN_TOWN = "58020"
ROUGEMONT_CDP = "58040"
ROWLAND_TOWN = "58140"
ROXBORO_CITY = "58160"
ROXOBEL_TOWN = "58180"
ROYAL_PINES_CDP = "58260"
RUFFIN_CDP = "58340"
RURAL_HALL_TOWN = "58360"
RUTH_TOWN = "58420"
RUTHERFORD_COLLEGE_TOWN = "58440"
RUTHERFORDTON_TOWN = "58460"
SALEM_CDP = "58740"
SALEMBURG_TOWN = "58840"
SALISBURY_CITY = "58860"
SALUDA_CITY = "58920"
SALVO_CDP = "58940"
SANDY_CREEK_TOWN = "59090"
SANDYFIELD_TOWN = "59135"
SANFORD_CITY = "59280"
SARATOGA_TOWN = "59340"
SAWMILLS_TOWN = "59540"
SAXAPAHAW_CDP = "59580"
SCOTCH_MEADOWS_CDP = "59765"
SCOTLAND_NECK_TOWN = "59780"
SEA_BREEZE_CDP = "60000"
SEABOARD_TOWN = "59980"
SEAGROVE_TOWN = "60080"
SEDALIA_TOWN = "60180"
SELMA_TOWN = "60320"
SEVEN_DEVILS_TOWN = "60505"
SEVEN_LAKES_CDP = "60515"
SEVEN_SPRINGS_TOWN = "60540"
SEVERN_TOWN = "60560"
SHALLOTTE_TOWN = "60800"
SHANNON_CDP = "60940"
SHARPSBURG_TOWN = "61060"
SHELBY_CITY = "61200"
SILER_CITY_TOWN = "61860"
SILVER_CITY_CDP = "61920"
SILVER_LAKE_CDP = "61950"
SIMPSON_VILLAGE = "62040"
SIMS_TOWN = "62060"
SKIPPERS_CORNER_CDP = "62190"
SMITHFIELD_TOWN = "62520"
SMITHTOWN_CDP = "62580"
SNEADS_FERRY_CDP = "62680"
SNOW_HILL_TOWN = "62760"
SOUTH_HENDERSON_CDP = "63240"
SOUTH_MILLS_CDP = "63340"
SOUTH_ROSEMARY_CDP = "63470"
SOUTH_WELDON_CDP = "63560"
SOUTHERN_PINES_TOWN = "63120"
SOUTHERN_SHORES_TOWN = "63130"
SOUTHMONT_CDP = "63360"
SOUTHPORT_CITY = "63400"
SPARTA_TOWN = "63680"
SPEED_TOWN = "63720"
SPENCER_MOUNTAIN_TOWN = "63780"
SPENCER_TOWN = "63760"
SPINDALE_TOWN = "63880"
SPIVEYS_CORNER_CDP = "63920"
SPOUT_SPRINGS_CDP = "64000"
SPRING_HOPE_TOWN = "64160"
SPRING_LAKE_TOWN = "64180"
SPRINGDALE_CDP = "64050"
SPRUCE_PINE_TOWN = "64260"
ST_HELENA_VILLAGE = "58620"
ST_JAMES_TOWN = "58630"
ST_PAULS_TOWN = "58720"
ST_STEPHENS_CDP = "58730"
STALEY_TOWN = "64380"
STALLINGS_TOWN = "64420"
STANFIELD_TOWN = "64460"
STANLEY_TOWN = "64500"
STANTONSBURG_TOWN = "64560"
STAR_TOWN = "64580"
STATESVILLE_CITY = "64740"
STEDMAN_TOWN = "64840"
STEM_TOWN = "64940"
STOKES_CDP = "65020"
STOKESDALE_TOWN = "65040"
STONEVILLE_TOWN = "65100"
STONEWALL_TOWN = "65120"
STONY_POINT_CDP = "65260"
STOVALL_TOWN = "65320"
SUGAR_MOUNTAIN_VILLAGE = "65530"
SUMMERFIELD_TOWN = "65580"
SUNBURY_CDP = "65700"
SUNSET_BEACH_TOWN = "65900"
SURF_CITY_TOWN = "66040"
SWAN_QUARTER_CDP = "66340"
SWANNANOA_CDP = "66280"
SWANSBORO_TOWN = "66360"
SWEPSONVILLE_TOWN = "66460"
SYLVA_TOWN = "66500"
TABOR_CITY_TOWN = "66520"
TAR_HEEL_TOWN = "66740"
TARBORO_TOWN = "66700"
TAYLORSVILLE_TOWN = "66960"
TAYLORTOWN_TOWN = "66980"
TEACHEY_TOWN = "67000"
THOMASVILLE_CITY = "67420"
TOAST_CDP = "67700"
TOBACCOVILLE_VILLAGE = "67720"
TOPSAIL_BEACH_TOWN = "68040"
TRENT_WOODS_TOWN = "68340"
TRENTON_TOWN = "68320"
TRINITY_CITY = "68400"
TROUTMAN_TOWN = "68500"
TROY_TOWN = "68520"
TRYON_TOWN = "68580"
TURKEY_TOWN = "68740"
TYRO_CDP = "69020"
UNIONVILLE_TOWN = "69260"
VALDESE_TOWN = "69520"
VALLE_CRUCIS_CDP = "69600"
VALLEY_HILL_CDP = "69640"
VANCEBORO_TOWN = "69680"
VANDEMERE_TOWN = "69720"
VANDER_CDP = "69740"
VANN_CROSSROADS_CDP = "69755"
VARNAMTOWN_TOWN = "69795"
VASS_TOWN = "69840"
WACO_TOWN = "70320"
WADE_TOWN = "70340"
WADESBORO_TOWN = "70380"
WAGRAM_TOWN = "70480"
WAKE_FOREST_TOWN = "70540"
WAKULLA_CDP = "70580"
WALKERTOWN_TOWN = "70660"
WALLACE_TOWN = "70720"
WALLBURG_TOWN = "70740"
WALNUT_COVE_TOWN = "70780"
WALNUT_CREEK_VILLAGE = "70820"
WALSTONBURG_TOWN = "70860"
WANCHESE_CDP = "70920"
WARRENTON_TOWN = "71100"
WARSAW_TOWN = "71160"
WASHINGTON_PARK_TOWN = "71240"
WASHINGTON_CITY = "71220"
WATHA_TOWN = "71320"
WAVES_CDP = "71440"
WAXHAW_TOWN = "71460"
WAYNESVILLE_TOWN = "71500"
WEAVERVILLE_TOWN = "71560"
WEBSTER_TOWN = "71600"
WEDDINGTON_TOWN = "71680"
WELCOME_CDP = "71760"
WELDON_TOWN = "71780"
WENDELL_TOWN = "71860"
WENTWORTH_TOWN = "71900"
WESLEY_CHAPEL_VILLAGE = "71940"
WEST_CANTON_CDP = "72150"
WEST_JEFFERSON_TOWN = "72540"
WEST_MARION_CDP = "72600"
WESTPORT_CDP = "72755"
WHISPERING_PINES_VILLAGE = "73140"
WHITAKERS_TOWN = "73160"
WHITE_LAKE_TOWN = "73300"
WHITE_OAK_CDP = "73320"
WHITE_PLAINS_CDP = "73460"
WHITEVILLE_CITY = "73660"
WHITSETT_TOWN = "73760"
WHITTIER_CDP = "73780"
WILKESBORO_TOWN = "74020"
WILLIAMSTON_TOWN = "74220"
WILMINGTON_CITY = "74440"
WILSON_CITY = "74540"
WILSONS_MILLS_TOWN = "74580"
WINDSOR_TOWN = "74680"
WINFALL_TOWN = "74720"
WINGATE_TOWN = "74760"
WINSTON_SALEM_CITY = "75000"
WINTERVILLE_TOWN = "75060"
WINTON_TOWN = "75080"
WOODFIN_TOWN = "75280"
WOODLAND_TOWN = "75340"
WOODLAWN_CDP = "75375"
WRIGHTSBORO_CDP = "75780"
WRIGHTSVILLE_BEACH_TOWN = "75820"
YADKIN_COLLEGE_CDP = "75880"
YADKINVILLE_TOWN = "75960"
YANCEYVILLE_TOWN = "76000"
YOUNGSVILLE_TOWN = "76200"
ZEBULON_TOWN = "76220"
