# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in West Virginia."""


BARBOUR = "001"
BERKELEY = "003"
BOONE = "005"
BRAXTON = "007"
BROOKE = "009"
CABELL = "011"
CALHOUN = "013"
CLAY = "015"
DODDRIDGE = "017"
FAYETTE = "019"
GILMER = "021"
GRANT = "023"
GREENBRIER = "025"
HAMPSHIRE = "027"
HANCOCK = "029"
HARDY = "031"
HARRISON = "033"
JACKSON = "035"
JEFFERSON = "037"
KANAWHA = "039"
LEWIS = "041"
LINCOLN = "043"
LOGAN = "045"
MARION = "049"
MARSHALL = "051"
MASON = "053"
MCDOWELL = "047"
MERCER = "055"
MINERAL = "057"
MINGO = "059"
MONONGALIA = "061"
MONROE = "063"
MORGAN = "065"
NICHOLAS = "067"
OHIO = "069"
PENDLETON = "071"
PLEASANTS = "073"
POCAHONTAS = "075"
PRESTON = "077"
PUTNAM = "079"
RALEIGH = "081"
RANDOLPH = "083"
RITCHIE = "085"
ROANE = "087"
SUMMERS = "089"
TAYLOR = "091"
TUCKER = "093"
TYLER = "095"
UPSHUR = "097"
WAYNE = "099"
WEBSTER = "101"
WETZEL = "103"
WIRT = "105"
WOOD = "107"
WYOMING = "109"
