# Copyright (c) 2023 Darren Erik Vengroff
"""Places in New Jersey."""


ABSECON_HIGHLANDS_CDP = "00160"
ABSECON_CITY = "00100"
ALLAMUCHY_CDP = "00640"
ALLENDALE_BOROUGH = "00700"
ALLENHURST_BOROUGH = "00730"
ALLENTOWN_BOROUGH = "00760"
ALLENWOOD_CDP = "00790"
ALLOWAY_CDP = "00850"
ALPHA_BOROUGH = "01030"
ALPINE_BOROUGH = "01090"
AMPERE_NORTH_CDP = "01184"
ANDERSON_CDP = "01300"
ANDOVER_BOROUGH = "01330"
ANNANDALE_CDP = "01480"
ARROWHEAD_LAKE_CDP = "01825"
ASBURY_CDP = "01900"
ASBURY_PARK_CITY = "01960"
ASHLAND_CDP = "01990"
ATCO_CDP = "02020"
ATLANTIC_CITY_CITY = "02080"
ATLANTIC_HIGHLANDS_BOROUGH = "02110"
AUBURN_CDP = "02170"
AUDUBON_PARK_BOROUGH = "02230"
AUDUBON_BOROUGH = "02200"
AVALON_BOROUGH = "02320"
AVENEL_CDP = "02350"
AVON_BY_THE_SEA_BOROUGH = "02440"
BARCLAY_CDP = "02880"
BARGAINTOWN_CDP = "02920"
BARNEGAT_CDP = "03040"
BARNEGAT_LIGHT_BOROUGH = "03130"
BARRINGTON_BOROUGH = "03250"
BASKING_RIDGE_CDP = "03340"
BAY_HEAD_BOROUGH = "03520"
BAYONNE_CITY = "03580"
BEACH_HAVEN_WEST_CDP = "04120"
BEACH_HAVEN_BOROUGH = "03940"
BEACHWOOD_BOROUGH = "04180"
BEATTYSTOWN_CDP = "04252"
BECKETT_CDP = "04400"
BEDMINSTER_CDP = "04420"
BEESLEYS_POINT_CDP = "04540"
BELFORD_CDP = "04600"
BELLE_MEAD_CDP = "04630"
BELLEPLAIN_CDP = "04660"
BELLMAWR_BOROUGH = "04750"
BELMAR_BOROUGH = "04930"
BELVIDERE_TOWN = "04990"
BERGENFIELD_BOROUGH = "05170"
BERLIN_BOROUGH = "05440"
BERNARDSVILLE_BOROUGH = "05590"
BEVERLY_CITY = "05740"
BLACKWELLS_MILLS_CDP = "06025"
BLACKWOOD_CDP = "06040"
BLAIRSTOWN_CDP = "06130"
BLAWENBURG_CDP = "06190"
BLOOMINGDALE_BOROUGH = "06340"
BLOOMSBURY_BOROUGH = "06370"
BOGOTA_BOROUGH = "06490"
BOONTON_TOWN = "06610"
BORDENTOWN_CITY = "06670"
BOUND_BROOK_BOROUGH = "06790"
BRADLEY_BEACH_BOROUGH = "06970"
BRADLEY_GARDENS_CDP = "07000"
BRAINARDS_CDP = "07120"
BRANCHVILLE_BOROUGH = "07300"
BRASS_CASTLE_CDP = "07360"
BRIDGEPORT_CDP = "07570"
BRIDGETON_CITY = "07600"
BRIDGEVILLE_CDP = "07660"
BRIDGEWATER_CENTER_CDP = "07728"
BRIELLE_BOROUGH = "07750"
BRIGANTINE_CITY = "07810"
BROADWAY_CDP = "08020"
BROOKDALE_CDP = "08110"
BROOKFIELD_CDP = "08140"
BROOKLAWN_BOROUGH = "08170"
BROOKSIDE_CDP = "08260"
BROWNS_MILLS_CDP = "08455"
BROWNVILLE_CDP = "08492"
BUDD_LAKE_CDP = "08620"
BUENA_BOROUGH = "08680"
BURLEIGH_CDP = "08890"
BURLINGTON_CITY = "08920"
BUTLER_BOROUGH = "09040"
BUTTZVILLE_CDP = "09100"
BYRAM_CENTER_CDP = "09170"
CALDWELL_BOROUGH = "09250"
CALIFON_BOROUGH = "09280"
CAMDEN_CITY = "10000"
CAPE_MAY_COURT_HOUSE_CDP = "10300"
CAPE_MAY_POINT_BOROUGH = "10330"
CAPE_MAY_CITY = "10270"
CARLLS_CORNER_CDP = "10450"
CARLSTADT_BOROUGH = "10480"
CARNEYS_POINT_CDP = "10600"
CARTERET_BOROUGH = "10750"
CEDAR_GLEN_LAKES_CDP = "11140"
CEDAR_GLEN_WEST_CDP = "11155"
CEDAR_KNOLLS_CDP = "11290"
CEDARVILLE_CDP = "11410"
CENTRE_GROVE_CDP = "11770"
CHATHAM_BOROUGH = "12100"
CHERRY_HILL_MALL_CDP = "12385"
CHESILHURST_BOROUGH = "12550"
CHESTER_BOROUGH = "12580"
CLAYTON_BOROUGH = "13360"
CLEARBROOK_CDP = "13395"
CLEMENTON_BOROUGH = "13420"
CLIFFSIDE_PARK_BOROUGH = "13570"
CLIFFWOOD_BEACH_CDP = "13630"
CLIFTON_CITY = "13690"
CLINTON_TOWN = "13720"
CLOSTER_BOROUGH = "13810"
CLYDE_CDP = "13990"
COLLINGS_LAKES_CDP = "14230"
COLLINGSWOOD_BOROUGH = "14260"
COLOGNE_CDP = "14350"
COLONIA_CDP = "14380"
COLUMBIA_CDP = "14590"
CONCORDIA_CDP = "14758"
CONNECTICUT_FARMS_CDP = "14815"
COOKSTOWN_CDP = "14980"
CORBIN_CITY_CITY = "15160"
COUNTRY_LAKE_ESTATES_CDP = "15250"
CRANBURY_CDP = "15520"
CRANDON_LAKES_CDP = "15610"
CRANFORD_CDP = "15638"
CREAM_RIDGE_CDP = "15730"
CRESSKILL_BOROUGH = "15820"
CRESTWOOD_VILLAGE_CDP = "15910"
CROSSWICKS_CDP = "16060"
CUMBERLAND_HESSTOWN_CDP = "16278"
DAYTON_CDP = "16630"
DEAL_BOROUGH = "16660"
DEANS_CDP = "16720"
DEERFIELD_STREET_CDP = "16960"
DELAWARE_CDP = "17200"
DELAWARE_PARK_CDP = "17260"
DELMONT_CDP = "17410"
DEMAREST_BOROUGH = "17530"
DENNISVILLE_CDP = "17590"
DIAMOND_BEACH_CDP = "17815"
DIVIDING_CREEK_CDP = "17890"
DORCHESTER_CDP = "18010"
DOROTHY_CDP = "18040"
DOVER_BEACHES_NORTH_CDP = "18148"
DOVER_BEACHES_SOUTH_CDP = "18151"
DOVER_TOWN = "18070"
DUMONT_BOROUGH = "18400"
DUNELLEN_BOROUGH = "18490"
DUTCH_NECK_CDP = "18632"
EAST_FRANKLIN_CDP = "19130"
EAST_FREEHOLD_CDP = "19150"
EAST_MILLSTONE_CDP = "19330"
EAST_NEWARK_BOROUGH = "19360"
EAST_ORANGE_CITY = "19390"
EAST_ROCKY_HILL_CDP = "19490"
EAST_RUTHERFORD_BOROUGH = "19510"
EAST_VINELAND_CDP = "19690"
EATONTOWN_BOROUGH = "19840"
ECHELON_CDP = "19900"
EDGEWATER_BOROUGH = "20020"
EGG_HARBOR_CITY_CITY = "20350"
ELIZABETH_CITY = "21000"
ELLISBURG_CDP = "21120"
ELMER_BOROUGH = "21240"
ELMWOOD_PARK_BOROUGH = "21300"
ELWOOD_CDP = "21420"
EMERSON_BOROUGH = "21450"
ENCORE_AT_MONROE_CDP = "21473"
ENGLEWOOD_CLIFFS_BOROUGH = "21510"
ENGLEWOOD_CITY = "21480"
ENGLISH_CREEK_CDP = "21540"
ENGLISHTOWN_BOROUGH = "21570"
ERMA_CDP = "21660"
ESSEX_FELLS_BOROUGH = "21840"
ESTELL_MANOR_CITY = "21870"
FAIR_HAVEN_BOROUGH = "22440"
FAIR_LAWN_BOROUGH = "22470"
FAIRTON_CDP = "22530"
FAIRVIEW_CDP = "22740"
FAIRVIEW_BOROUGH = "22560"
FANWOOD_BOROUGH = "22860"
FAR_HILLS_BOROUGH = "22890"
FARMINGDALE_BOROUGH = "22950"
FIELDSBORO_BOROUGH = "23250"
FINDERNE_CDP = "23310"
FINESVILLE_CDP = "23340"
FLAGTOWN_CDP = "23610"
FLANDERS_CDP = "23640"
FLEMINGTON_BOROUGH = "23700"
FLORENCE_CDP = "23820"
FLORHAM_PARK_BOROUGH = "23910"
FOLSOM_BOROUGH = "23940"
FORDS_CDP = "24030"
FORKED_RIVER_CDP = "24180"
FORSGATE_CDP = "24285"
FORT_DIX_CDP = "24300"
FORT_LEE_BOROUGH = "24420"
FORTESCUE_CDP = "24360"
FRANKLIN_CENTER_CDP = "24965"
FRANKLIN_LAKES_BOROUGH = "24990"
FRANKLIN_PARK_CDP = "25020"
FRANKLIN_BOROUGH = "24930"
FRANKLINVILLE_CDP = "25050"
FREEHOLD_BOROUGH = "25200"
FRENCHTOWN_BOROUGH = "25350"
GANDYS_BEACH_CDP = "25590"
GARFIELD_CITY = "25770"
GARWOOD_BOROUGH = "25800"
GERMANIA_CDP = "26010"
GIBBSBORO_BOROUGH = "26070"
GIBBSTOWN_CDP = "26100"
GILLETTE_CDP = "26220"
GLASSBORO_BOROUGH = "26340"
GLEN_GARDNER_BOROUGH = "26550"
GLEN_RIDGE_BOROUGH = "26610"
GLEN_ROCK_BOROUGH = "26640"
GLENDORA_CDP = "26520"
GLOUCESTER_CITY_CITY = "26820"
GOLDEN_TRIANGLE_CDP = "26902"
GOSHEN_CDP = "27030"
GOULDTOWN_CDP = "27060"
GREAT_MEADOWS_CDP = "27360"
GREAT_NOTCH_CDP = "27390"
GREEN_KNOLL_CDP = "27840"
GREEN_VILLAGE_CDP = "28020"
GREENTREE_CDP = "27995"
GREENWICH_CDP_CUMBERLAND_COUNTY = "28140"
GREENWICH_CDP_WARREN_COUNTY = "28250"
GRENLOCH_CDP = "28380"
GRIGGSTOWN_CDP = "28470"
GROVEVILLE_CDP = "28620"
GUTTENBERG_TOWN = "28650"
HACKENSACK_CITY = "28680"
HACKETTSTOWN_TOWN = "28710"
HADDON_HEIGHTS_BOROUGH = "28800"
HADDONFIELD_BOROUGH = "28770"
HAINESBURG_CDP = "28920"
HALEDON_BOROUGH = "29070"
HAMBURG_BOROUGH = "29220"
HAMILTON_SQUARE_CDP = "29370"
HAMMONTON_TOWN = "29430"
HAMPTON_BOROUGH = "29460"
HANCOCKS_BRIDGE_CDP = "29520"
HARLINGEN_CDP = "29940"
HARMONY_CDP = "30060"
HARRINGTON_PARK_BOROUGH = "30150"
HARRISON_TOWN = "30210"
HARRISONVILLE_CDP = "30270"
HARVEY_CEDARS_BOROUGH = "30390"
HASBROUCK_HEIGHTS_BOROUGH = "30420"
HAWORTH_BOROUGH = "30540"
HAWTHORNE_BOROUGH = "30570"
HEATHCOTE_CDP = "30738"
HEISLERVILLE_CDP = "30810"
HELMETTA_BOROUGH = "30840"
HEWITT_CDP = "31110"
HI_NELLA_BOROUGH = "32220"
HIBERNIA_CDP = "31170"
HIGH_BRIDGE_BOROUGH = "31320"
HIGHLAND_LAKES_CDP = "31410"
HIGHLAND_PARK_BOROUGH = "31470"
HIGHLANDS_BOROUGH = "31500"
HIGHTSTOWN_BOROUGH = "31620"
HILLSBOROUGH_CDP = "31880"
HILLSDALE_BOROUGH = "31920"
HO_HO_KUS_BOROUGH = "32310"
HOBOKEN_CITY = "32250"
HOLIDAY_CITY_SOUTH_CDP = "32418"
HOLIDAY_CITY_BERKELEY_CDP = "32415"
HOLIDAY_HEIGHTS_CDP = "32424"
HOPATCONG_BOROUGH = "32910"
HOPE_CDP = "33030"
HOPELAWN_CDP = "33090"
HOPEWELL_BOROUGH = "33150"
HUTCHINSON_CDP = "33690"
INTERLAKEN_BOROUGH = "34200"
ISELIN_CDP = "34470"
ISLAND_HEIGHTS_BOROUGH = "34530"
JAMESBURG_BOROUGH = "34890"
JERSEY_CITY_CITY = "36000"
JOBSTOWN_CDP = "36120"
JOHNSONBURG_CDP = "36150"
JULIUSTOWN_CDP = "36300"
KEAN_UNIVERSITY_CDP = "36484"
KEANSBURG_BOROUGH = "36480"
KEARNY_TOWN = "36510"
KEASBEY_CDP = "36570"
KENDALL_PARK_CDP = "36660"
KENILWORTH_BOROUGH = "36690"
KENVIL_CDP = "36720"
KEYPORT_BOROUGH = "36810"
KINGSTON_CDP = "36930"
KINGSTON_ESTATES_CDP = "36960"
KINNELON_BOROUGH = "37110"
LAKE_COMO_BOROUGH = "37560"
LAKE_HIAWATHA_CDP = "37680"
LAKE_HOPATCONG_CDP = "37710"
LAKE_MOHAWK_CDP = "38040"
LAKE_TELEMARK_CDP = "38430"
LAKEHURST_BOROUGH = "37770"
LAKESIDE_BEEBE_RUN_CDP = "38296"
LAKEWOOD_CDP = "38580"
LAMBERTVILLE_CITY = "38610"
LAMINGTON_CDP = "38670"
LANDING_CDP = "38700"
LAUREL_HEIGHTS_CDP = "39045"
LAUREL_LAKE_CDP = "39120"
LAUREL_SPRINGS_BOROUGH = "39210"
LAURENCE_HARBOR_CDP = "39360"
LAVALLETTE_BOROUGH = "39390"
LAWNSIDE_BOROUGH = "39420"
LAWRENCEVILLE_CDP = "39570"
LAYTON_CDP = "39600"
LEBANON_BOROUGH = "39630"
LEDGEWOOD_CDP = "39750"
LEEDS_POINT_CDP = "39810"
LEESBURG_CDP = "39870"
LEISURE_KNOLL_CDP = "39883"
LEISURE_VILLAGE_CDP = "39900"
LEISURE_VILLAGE_EAST_CDP = "39910"
LEISURE_VILLAGE_WEST_CDP = "39916"
LEISURETOWNE_CDP = "39885"
LEONARDO_CDP = "39990"
LEONIA_BOROUGH = "40020"
LIBERTY_CORNER_CDP = "40140"
LINCOLN_PARK_BOROUGH = "40290"
LINCROFT_CDP = "40320"
LINDEN_CITY = "40350"
LINDENWOLD_BOROUGH = "40440"
LINWOOD_CITY = "40530"
LITTLE_FERRY_BOROUGH = "40680"
LITTLE_SILVER_BOROUGH = "40770"
LLEWELLYN_PARK_CDP = "40990"
LOCH_ARBOUR_VILLAGE = "41010"
LODI_BOROUGH = "41100"
LONG_BRANCH_CITY = "41310"
LONG_VALLEY_CDP = "41400"
LONGPORT_BOROUGH = "41370"
LOPATCONG_OVERLOOK_CDP = "41495"
LOWER_BERKSHIRE_VALLEY_CDP = "41700"
LYONS_CDP = "42180"
MACOPIN_CDP = "42450"
MADISON_PARK_CDP = "42540"
MADISON_BOROUGH = "42510"
MAGNOLIA_BOROUGH = "42630"
MALAGA_CDP = "42840"
MANAHAWKIN_CDP = "42930"
MANASQUAN_BOROUGH = "43050"
MANTOLOKING_BOROUGH = "43380"
MANVILLE_BOROUGH = "43620"
MARGATE_CITY_CITY = "43890"
MARKSBORO_CDP = "43980"
MARLBORO_CDP = "44010"
MARLTON_CDP = "44100"
MARMORA_CDP = "44280"
MARSHALLVILLE_CDP = "44345"
MARTINSVILLE_CDP = "44430"
MATAWAN_BOROUGH = "44520"
MAURICETOWN_CDP = "44670"
MAYS_LANDING_CDP = "44820"
MAYWOOD_BOROUGH = "44880"
MCGUIRE_AFB_CDP = "42390"
MCKEE_CITY_CDP = "42420"
MEDFORD_LAKES_BOROUGH = "45210"
MENDHAM_BOROUGH = "45330"
MENLO_PARK_TERRACE_CDP = "45450"
MERCERVILLE_CDP = "45480"
MERCHANTVILLE_BOROUGH = "45510"
METUCHEN_BOROUGH = "45690"
MICKLETON_CDP = "45780"
MIDDLEBUSH_CDP = "45870"
MIDDLESEX_BOROUGH = "45900"
MIDLAND_PARK_BOROUGH = "46110"
MILFORD_BOROUGH = "46260"
MILLINGTON_CDP = "46470"
MILLSTONE_BOROUGH = "46590"
MILLTOWN_BOROUGH = "46620"
MILLVILLE_CITY = "46680"
MILMAY_CDP = "46710"
MIZPAH_CDP = "46980"
MONEY_ISLAND_CDP = "47006"
MONMOUTH_BEACH_BOROUGH = "47130"
MONMOUTH_JUNCTION_CDP = "47190"
MONROE_MANOR_CDP = "47380"
MONTCLAIR_STATE_UNIVERSITY_CDP = "47524"
MONTVALE_BOROUGH = "47610"
MOONACHIE_BOROUGH = "47700"
MOORESTOWN_LENOLA_CDP = "47895"
MORGANVILLE_CDP = "48030"
MORRIS_PLAINS_BOROUGH = "48210"
MORRISTOWN_TOWN = "48300"
MOUNT_ARLINGTON_BOROUGH = "48690"
MOUNT_EPHRAIM_BOROUGH = "48750"
MOUNT_HERMON_CDP = "48840"
MOUNT_HOPE_CDP = "48930"
MOUNT_ROYAL_CDP = "49200"
MOUNT_TABOR_CDP = "49290"
MOUNTAIN_LAKE_CDP = "48450"
MOUNTAIN_LAKES_BOROUGH = "48480"
MOUNTAINSIDE_BOROUGH = "48510"
MULLICA_HILL_CDP = "49440"
MYSTIC_ISLAND_CDP = "49560"
NATIONAL_PARK_BOROUGH = "49680"
NAVESINK_CDP = "49740"
NEPTUNE_CITY_BOROUGH = "49920"
NESCO_CDP = "50010"
NESHANIC_CDP = "50040"
NESHANIC_STATION_CDP = "50100"
NETCONG_BOROUGH = "50130"
NEW_BRUNSWICK_CITY = "51210"
NEW_EGYPT_CDP = "51360"
NEW_GRETNA_CDP = "51450"
NEW_MILFORD_BOROUGH = "51660"
NEW_PROVIDENCE_BOROUGH = "51810"
NEW_VERNON_CDP = "52020"
NEW_VILLAGE_CDP = "52050"
NEWARK_CITY = "51000"
NEWFIELD_BOROUGH = "51390"
NEWFOUNDLAND_CDP = "51420"
NEWPORT_CDP = "51750"
NEWTON_TOWN = "51930"
NEWTONVILLE_CDP = "51990"
NORTH_ARLINGTON_BOROUGH = "52320"
NORTH_BEACH_HAVEN_CDP = "52410"
NORTH_CALDWELL_BOROUGH = "52620"
NORTH_CAPE_MAY_CDP = "52650"
NORTH_HALEDON_BOROUGH = "53040"
NORTH_MIDDLETOWN_CDP = "53205"
NORTH_PLAINFIELD_BOROUGH = "53280"
NORTH_WILDWOOD_CITY = "53490"
NORTHFIELD_CITY = "52950"
NORTHVALE_BOROUGH = "53430"
NORWOOD_BOROUGH = "53610"
OAK_RIDGE_CDP = "53910"
OAK_VALLEY_CDP = "54060"
OAKHURST_CDP = "53790"
OAKLAND_BOROUGH = "53850"
OAKLYN_BOROUGH = "53880"
OCEAN_ACRES_CDP = "54315"
OCEAN_CITY_CITY = "54360"
OCEAN_GATE_BOROUGH = "54450"
OCEAN_GROVE_CDP = "54480"
OCEAN_VIEW_CDP = "54600"
OCEANPORT_BOROUGH = "54570"
OCEANVILLE_CDP = "54630"
OGDENSBURG_BOROUGH = "54660"
OLD_BRIDGE_CDP = "54690"
OLD_TAPPAN_BOROUGH = "54870"
OLDWICK_CDP = "54900"
OLIVET_CDP = "54960"
ORADELL_BOROUGH = "54990"
OTHELLO_CDP = "55320"
OXFORD_CDP = "55500"
PACKANACK_LAKE_CDP = "55620"
PALERMO_CDP = "55710"
PALISADES_PARK_BOROUGH = "55770"
PALMYRA_BOROUGH = "55800"
PANTHER_VALLEY_CDP = "55895"
PARAMUS_BOROUGH = "55950"
PARK_RIDGE_BOROUGH = "56130"
PARSIPPANY_CDP = "56430"
PASSAIC_CITY = "56550"
PATERSON_CITY = "57000"
PAULSBORO_BOROUGH = "57150"
PEAPACK_AND_GLADSTONE_BOROUGH = "57300"
PEDRICKTOWN_CDP = "57360"
PEMBERTON_HEIGHTS_CDP = "57540"
PEMBERTON_BOROUGH = "57480"
PENNINGTON_BOROUGH = "57600"
PENNS_GROVE_BOROUGH = "57750"
PENNSVILLE_CDP = "57840"
PERTH_AMBOY_CITY = "58200"
PHILLIPSBURG_TOWN = "58350"
PINE_BEACH_BOROUGH = "58590"
PINE_BROOK_CDP = "58650"
PINE_HILL_BOROUGH = "58770"
PINE_LAKE_PARK_CDP = "58830"
PINE_RIDGE_AT_CRESTWOOD_CDP = "58852"
PINES_LAKE_CDP = "58860"
PITMAN_BOROUGH = "59070"
PLAINFIELD_CITY = "59190"
PLAINSBORO_CENTER_CDP = "59285"
PLEASANT_PLAINS_CDP = "59500"
PLEASANTDALE_CDP = "59385"
PLEASANTVILLE_CITY = "59640"
PLUCKEMIN_CDP = "59730"
POINT_PLEASANT_BEACH_BOROUGH = "59910"
POINT_PLEASANT_BOROUGH = "59880"
POMONA_CDP = "60030"
POMPTON_LAKES_BOROUGH = "60090"
POMPTON_PLAINS_CDP = "60120"
PORT_COLDEN_CDP = "60210"
PORT_ELIZABETH_CDP = "60240"
PORT_MONMOUTH_CDP = "60360"
PORT_MORRIS_CDP = "60390"
PORT_MURRAY_CDP = "60450"
PORT_NORRIS_CDP = "60510"
PORT_READING_CDP = "60540"
PORT_REPUBLIC_CITY = "60600"
POTTERSVILLE_CDP = "60750"
PREAKNESS_CDP = "60810"
PRESIDENTIAL_LAKES_ESTATES_CDP = "60840"
PRINCETON_JUNCTION_CDP = "60960"
PRINCETON_MEADOWS_CDP = "60975"
PRINCETON = "60900"
PROSPECT_PARK_BOROUGH = "61170"
QUINTON_CDP = "61440"
RAHWAY_CITY = "61530"
RAINBOW_LAKES_CDP = "61560"
RAMAPO_COLLEGE_OF_NEW_JERSEY_CDP = "61632"
RAMBLEWOOD_CDP = "61650"
RAMSEY_BOROUGH = "61680"
RAMTOWN_CDP = "61725"
RARITAN_BOROUGH = "61980"
RED_BANK_BOROUGH = "62430"
REGENCY_AT_MONROE_CDP = "62585"
RENAISSANCE_AT_MONROE_CDP = "62605"
RICHLAND_CDP = "62790"
RICHWOOD_CDP = "62820"
RIDGEFIELD_PARK_VILLAGE = "62940"
RIDGEFIELD_BOROUGH = "62910"
RIDGEWOOD_VILLAGE = "63000"
RINGOES_CDP = "63120"
RINGWOOD_BOROUGH = "63150"
RIO_GRANDE_CDP = "63180"
RIVER_EDGE_BOROUGH = "63360"
RIVERDALE_BOROUGH = "63300"
RIVERTON_BOROUGH = "63660"
ROADSTOWN_CDP = "63810"
ROBBINSVILLE_CENTER_CDP = "63858"
ROBERTSVILLE_CDP = "63900"
ROCKAWAY_BOROUGH = "64050"
ROCKLEIGH_BOROUGH = "64170"
ROCKY_HILL_BOROUGH = "64320"
ROEBLING_CDP = "64350"
ROOSEVELT_BOROUGH = "64410"
ROSELAND_BOROUGH = "64590"
ROSELLE_PARK_BOROUGH = "64650"
ROSELLE_BOROUGH = "64620"
ROSENHAYN_CDP = "64740"
ROSS_CORNER_CDP = "64860"
ROSSMOOR_CDP = "64865"
RUMSON_BOROUGH = "65130"
RUNNEMEDE_BOROUGH = "65160"
RUTGERS_UNIVERSITY_BUSCH_CAMPUS_CDP = "65249"
RUTGERS_UNIVERSITY_LIVINGSTON_CAMPUS_CDP = "65260"
RUTHERFORD_BOROUGH = "65280"
SADDLE_RIVER_BOROUGH = "65400"
SALEM_CITY = "65490"
SAYREVILLE_BOROUGH = "65790"
SEA_BRIGHT_BOROUGH = "66240"
SEA_GIRT_BOROUGH = "66330"
SEA_ISLE_CITY_CITY = "66390"
SEABROOK_FARMS_CDP = "66300"
SEASIDE_HEIGHTS_BOROUGH = "66450"
SEASIDE_PARK_BOROUGH = "66480"
SEAVILLE_CDP = "66540"
SECAUCUS_TOWN = "66570"
SEELEY_CDP = "66615"
SEWAREN_CDP = "66720"
SEWELL_CDP = "66750"
SHARK_RIVER_HILLS_CDP = "66840"
SHEPPARDS_MILL_CDP = "66970"
SHILOH_BOROUGH = "67020"
SHIP_BOTTOM_BOROUGH = "67110"
SHORT_HILLS_CDP = "67320"
SHREWSBURY_BOROUGH = "67350"
SICKLERVILLE_CDP = "67470"
SILVER_LAKE_CDP_CUMBERLAND_COUNTY = "67583"
SILVER_LAKE_CDP_ESSEX_COUNTY = "67590"
SILVER_LAKE_CDP_WARREN_COUNTY = "67650"
SILVER_RIDGE_CDP = "67665"
SINGAC_CDP = "67770"
SIX_MILE_RUN_CDP = "67820"
SKILLMAN_CDP = "67860"
SMITHVILLE_CDP = "68190"
SOMERDALE_BOROUGH = "68340"
SOMERS_POINT_CITY = "68430"
SOMERSET_CDP = "68370"
SOMERVILLE_BOROUGH = "68460"
SOUTH_AMBOY_CITY = "68550"
SOUTH_BOUND_BROOK_BOROUGH = "68730"
SOUTH_DENNIS_CDP = "68850"
SOUTH_PLAINFIELD_BOROUGH = "69390"
SOUTH_RIVER_BOROUGH = "69420"
SOUTH_SEAVILLE_CDP = "69480"
SOUTH_TOMS_RIVER_BOROUGH = "69510"
SPOTSWOOD_BOROUGH = "69810"
SPRING_LAKE_HEIGHTS_BOROUGH = "70140"
SPRING_LAKE_BOROUGH = "70110"
SPRINGDALE_CDP = "69900"
SPRINGFIELD_CDP = "70018"
STANHOPE_BOROUGH = "70380"
STEWARTSVILLE_CDP = "70800"
STIRLING_CDP = "70920"
STOCKTON_UNIVERSITY_CDP = "70984"
STOCKTON_BOROUGH = "70980"
STONE_HARBOR_BOROUGH = "71010"
STONEBRIDGE_CDP = "70987"
STRATFORD_BOROUGH = "71220"
STRATHMERE_CDP = "71250"
STRATHMORE_CDP = "71280"
SUCCASUNNA_CDP = "71370"
SUMMIT_CITY = "71430"
SUNSET_LAKE_CDP = "71628"
SURF_CITY_BOROUGH = "71640"
SUSSEX_BOROUGH = "71670"
SWEDESBORO_BOROUGH = "71850"
SWEETWATER_CDP = "71880"
TAVISTOCK_BOROUGH = "72240"
TEN_MILE_RUN_CDP = "72435"
TENAFLY_BOROUGH = "72420"
TETERBORO_BOROUGH = "72480"
THE_COLLEGE_OF_NEW_JERSEY_CDP = "72580"
THE_HILLS_CDP = "72635"
THE_PONDS_CDP = "72726"
THOROFARE_CDP = "72810"
THREE_BRIDGES_CDP = "72870"
TINTON_FALLS_BOROUGH = "73020"
TITUSVILLE_CDP = "73050"
TOMS_RIVER_CDP = "73110"
TOTOWA_BOROUGH = "73140"
TOWACO_CDP = "73170"
TRENTON_CITY = "74000"
TROY_HILLS_CDP = "74150"
TUCKAHOE_CDP = "74180"
TUCKERTON_BOROUGH = "74210"
TURNERSVILLE_CDP = "74270"
TWIN_RIVERS_CDP = "74330"
UNION_BEACH_BOROUGH = "74540"
UNION_CDP = "74478"
UNION_CITY_CITY = "74630"
UPPER_GREENWOOD_LAKE_CDP = "74930"
UPPER_MONTCLAIR_CDP = "75020"
UPPER_POHATCONG_CDP = "75120"
UPPER_SADDLE_RIVER_BOROUGH = "75140"
UPPER_STEWARTSVILLE_CDP = "75145"
VAUXHALL_CDP = "75590"
VENTNOR_CITY_CITY = "75620"
VERNON_CENTER_CDP = "75745"
VERNON_VALLEY_CDP = "75750"
VICTORY_GARDENS_BOROUGH = "75890"
VICTORY_LAKES_CDP = "75920"
VIENNA_CDP = "75950"
VILLAS_CDP = "76010"
VINCENTOWN_CDP = "76040"
VINELAND_CITY = "76070"
VISTA_CENTER_CDP = "76107"
VOORHEES_CDP = "76250"
WALDWICK_BOROUGH = "76400"
WALLINGTON_BOROUGH = "76490"
WANAMASSA_CDP = "76700"
WANAQUE_BOROUGH = "76730"
WARETOWN_CDP = "76820"
WASHINGTON_CROSSING_CDP = "77330"
WASHINGTON_BOROUGH = "77270"
WATCHUNG_BOROUGH = "77600"
WATSESSING_CDP = "77750"
WENONAH_BOROUGH = "78110"
WEST_BELMAR_CDP = "78350"
WEST_BERLIN_CDP = "78410"
WEST_CAPE_MAY_BOROUGH = "78530"
WEST_FREEHOLD_CDP = "79100"
WEST_LONG_BRANCH_BOROUGH = "79310"
WEST_NEW_YORK_TOWN = "79610"
WEST_PARK_CDP = "79810"
WEST_WILDWOOD_BOROUGH = "80210"
WESTFIELD_TOWN = "79040"
WESTMONT_CDP = "79520"
WESTON_CDP = "79715"
WESTVILLE_BOROUGH = "80120"
WESTWOOD_BOROUGH = "80270"
WHARTON_BOROUGH = "80390"
WHIPPANY_CDP = "80540"
WHITE_HORSE_CDP = "80630"
WHITE_HOUSE_STATION_CDP = "80720"
WHITE_MEADOW_LAKE_CDP = "80750"
WHITESBORO_CDP = "80840"
WHITTINGHAM_CDP = "81042"
WILDWOOD_CREST_BOROUGH = "81200"
WILDWOOD_CITY = "81170"
WILLIAM_PATERSON_UNIVERSITY_OF_NEW_JERSEY_CDP = "81365"
WILLIAMSTOWN_CDP = "81380"
WINDSOR_CDP = "81620"
WOOD_RIDGE_BOROUGH = "82570"
WOODBINE_BOROUGH = "81890"
WOODBRIDGE_CDP = "81950"
WOODBURY_HEIGHTS_BOROUGH = "82180"
WOODBURY_CITY = "82120"
WOODCLIFF_LAKE_BOROUGH = "82300"
WOODLAND_PARK_BOROUGH = "82423"
WOODLYNNE_BOROUGH = "82450"
WOODSTOWN_BOROUGH = "82720"
WRIGHTSTOWN_BOROUGH = "82960"
YARDVILLE_CDP = "83170"
YORKETOWN_CDP = "83245"
ZAREPHATH_CDP = "83290"
