# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Alabama."""


AUTAUGA = "001"
BALDWIN = "003"
BARBOUR = "005"
BIBB = "007"
BLOUNT = "009"
BULLOCK = "011"
BUTLER = "013"
CALHOUN = "015"
CHAMBERS = "017"
CHEROKEE = "019"
CHILTON = "021"
CHOCTAW = "023"
CLARKE = "025"
CLAY = "027"
CLEBURNE = "029"
COFFEE = "031"
COLBERT = "033"
CONECUH = "035"
COOSA = "037"
COVINGTON = "039"
CRENSHAW = "041"
CULLMAN = "043"
DALE = "045"
DALLAS = "047"
DEKALB = "049"
ELMORE = "051"
ESCAMBIA = "053"
ETOWAH = "055"
FAYETTE = "057"
FRANKLIN = "059"
GENEVA = "061"
GREENE = "063"
HALE = "065"
HENRY = "067"
HOUSTON = "069"
JACKSON = "071"
JEFFERSON = "073"
LAMAR = "075"
LAUDERDALE = "077"
LAWRENCE = "079"
LEE = "081"
LIMESTONE = "083"
LOWNDES = "085"
MACON = "087"
MADISON = "089"
MARENGO = "091"
MARION = "093"
MARSHALL = "095"
MOBILE = "097"
MONROE = "099"
MONTGOMERY = "101"
MORGAN = "103"
PERRY = "105"
PICKENS = "107"
PIKE = "109"
RANDOLPH = "111"
RUSSELL = "113"
SHELBY = "117"
ST_CLAIR = "115"
SUMTER = "119"
TALLADEGA = "121"
TALLAPOOSA = "123"
TUSCALOOSA = "125"
WALKER = "127"
WASHINGTON = "129"
WILCOX = "131"
WINSTON = "133"
