# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in South Dakota."""


AURORA = "003"
BEADLE = "005"
BENNETT = "007"
BON_HOMME = "009"
BROOKINGS = "011"
BROWN = "013"
BRULE = "015"
BUFFALO = "017"
BUTTE = "019"
CAMPBELL = "021"
CHARLES_MIX = "023"
CLARK = "025"
CLAY = "027"
CODINGTON = "029"
CORSON = "031"
CUSTER = "033"
DAVISON = "035"
DAY = "037"
DEUEL = "039"
DEWEY = "041"
DOUGLAS = "043"
EDMUNDS = "045"
FALL_RIVER = "047"
FAULK = "049"
GRANT = "051"
GREGORY = "053"
HAAKON = "055"
HAMLIN = "057"
HAND = "059"
HANSON = "061"
HARDING = "063"
HUGHES = "065"
HUTCHINSON = "067"
HYDE = "069"
JACKSON = "071"
JERAULD = "073"
JONES = "075"
KINGSBURY = "077"
LAKE = "079"
LAWRENCE = "081"
LINCOLN = "083"
LYMAN = "085"
MARSHALL = "091"
MCCOOK = "087"
MCPHERSON = "089"
MEADE = "093"
MELLETTE = "095"
MINER = "097"
MINNEHAHA = "099"
MOODY = "101"
OGLALA_LAKOTA = "102"
PENNINGTON = "103"
PERKINS = "105"
POTTER = "107"
ROBERTS = "109"
SANBORN = "111"
SPINK = "115"
STANLEY = "117"
SULLY = "119"
TODD = "121"
TRIPP = "123"
TURNER = "125"
UNION = "127"
WALWORTH = "129"
YANKTON = "135"
ZIEBACH = "137"
