# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Idaho."""


ABERDEEN_CITY = "00100"
ACEQUIA_CITY = "00280"
ALBION_CITY = "01000"
AMERICAN_FALLS_CITY = "01900"
AMMON_CITY = "01990"
ARBON_VALLEY_CDP = "02935"
ARCO_CITY = "03160"
ARIMO_CITY = "03340"
ASHTON_CITY = "03610"
ATHOL_CITY = "03700"
ATOMIC_CITY_CITY = "03970"
AVIMOR_CDP = "04105"
BANCROFT_CITY = "04420"
BANKS_CDP = "04600"
BASALT_CITY = "05230"
BELLEVUE_CITY = "06220"
BENNINGTON_CDP = "06670"
BLACKFOOT_CITY = "07840"
BLANCHARD_CDP = "08290"
BLISS_CITY = "08470"
BLOOMINGTON_CITY = "08560"
BOISE_CITY_CITY = "08830"
BONNERS_FERRY_CITY = "09370"
BOVILL_CITY = "09730"
BRUNEAU_CDP = "10450"
BUHL_CITY = "10810"
BURLEY_CITY = "11260"
BUTTE_CITY_CITY = "11710"
CALDWELL_CITY = "12250"
CAMBRIDGE_CITY = "12520"
CAREY_CITY = "12790"
CASCADE_CITY = "13150"
CASTLEFORD_CITY = "13240"
CHALLIS_CITY = "13780"
CHUBBUCK_CITY = "14680"
CLARK_FORK_CITY = "14950"
CLAYTON_CITY = "15490"
CLIFTON_CITY = "16120"
COEUR_DALENE_CITY = "16750"
CONKLING_PARK_CDP = "17830"
COOLIN_CDP = "18010"
COTTONWOOD_CITY = "18640"
COUNCIL_CITY = "18820"
CRAIGMONT_CITY = "19270"
CROUCH_CITY = "19720"
CULDESAC_CITY = "19900"
DALTON_GARDENS_CITY = "20350"
DAYTON_CITY = "20710"
DE_SMET_CDP = "21520"
DEARY_CITY = "20890"
DECLO_CITY = "20980"
DIETRICH_CITY = "21790"
DONNELLY_CITY = "22330"
DOVER_CITY = "22510"
DOWNEY_CITY = "22600"
DRIGGS_CITY = "22690"
DRUMMOND_CITY = "22780"
DUBOIS_CITY = "22960"
EAGLE_CITY = "23410"
EAST_HOPE_CITY = "23680"
EDEN_CITY = "24310"
ELK_CITY_CDP = "25030"
ELK_RIVER_CITY = "25120"
EMMETT_CITY = "25570"
FAIRFIELD_CITY = "26290"
FERDINAND_CITY = "27460"
FERNAN_LAKE_VILLAGE_CITY = "27550"
FERNWOOD_CDP = "27640"
FILER_CITY = "27730"
FIRTH_CITY = "27910"
FORT_HALL_CDP = "28360"
FRANKLIN_CITY = "28810"
FRUITLAND_CITY = "28990"
GANNETT_CDP = "29440"
GARDEN_CITY_CITY = "29620"
GARDEN_VALLEY_CDP = "29710"
GENESEE_CITY = "30160"
GEORGETOWN_CITY = "30340"
GLENNS_FERRY_CITY = "31690"
GOODING_CITY = "32140"
GRACE_CITY = "32500"
GRAND_VIEW_CITY = "32770"
GRANGEVILLE_CITY = "32950"
GREENLEAF_CITY = "33490"
GROVELAND_CDP = "34030"
HAGERMAN_CITY = "34300"
HAILEY_CITY = "34390"
HAMER_CITY = "34570"
HAMMETT_CDP = "34750"
HANSEN_CITY = "34930"
HARRISON_CITY = "35200"
HAUSER_CITY = "35830"
HAYDEN_LAKE_CITY = "36460"
HAYDEN_CITY = "36370"
HAZELTON_CITY = "36730"
HEYBURN_CITY = "37360"
HIDDEN_SPRINGS_CDP = "37500"
HOLLISTER_CITY = "38080"
HOMEDALE_CITY = "38170"
HOPE_CITY = "38440"
HORSESHOE_BEND_CITY = "38620"
HUETTER_CITY = "39070"
IDAHO_CITY_CITY = "39610"
IDAHO_FALLS_CITY = "39700"
INKOM_CITY = "40330"
IONA_CITY = "40420"
IRWIN_CITY = "40510"
ISLAND_PARK_CITY = "40600"
JEROME_CITY = "41320"
JULIAETTA_CITY = "42130"
KAMIAH_CITY = "42400"
KELLOGG_CITY = "42580"
KENDRICK_CITY = "42760"
KETCHUM_CITY = "43030"
KIMBERLY_CITY = "43570"
KOOSKIA_CITY = "44110"
KOOTENAI_CITY = "44200"
KUNA_CITY = "44290"
LACLEDE_CDP = "44560"
LAPWAI_CITY = "45370"
LAVA_HOT_SPRINGS_CITY = "45820"
LEADORE_CITY = "45910"
LETHA_CDP = "46450"
LEWISTON_CITY = "46540"
LEWISVILLE_CITY = "46720"
LINCOLN_CDP = "47080"
LOST_RIVER_CITY = "47890"
LOWMAN_CDP = "48250"
MACKAY_CITY = "49240"
MALAD_CITY_CITY = "50140"
MALTA_CITY = "50230"
MARSING_CITY = "50950"
MCCALL_CITY = "48790"
MCCAMMON_CITY = "48880"
MELBA_CITY = "51850"
MENAN_CITY = "52030"
MERIDIAN_CITY = "52120"
MIDDLETON_CITY = "52660"
MIDVALE_CITY = "52750"
MINIDOKA_CITY = "53110"
MONTPELIER_CITY = "53920"
MOORE_CITY = "54100"
MORELAND_CDP = "54370"
MOSCOW_CITY = "54550"
MOUNTAIN_HOME_AFB_CDP = "54820"
MOUNTAIN_HOME_CITY = "54730"
MOYIE_SPRINGS_CITY = "55270"
MUD_LAKE_CITY = "55450"
MULLAN_CITY = "55630"
MURPHY_CDP = "55720"
MURTAUGH_CITY = "55900"
NAMPA_CITY = "56260"
NEW_MEADOWS_CITY = "56890"
NEW_PLYMOUTH_CITY = "56980"
NEWDALE_CITY = "56800"
NEZPERCE_CITY = "57250"
NOTUS_CITY = "58060"
OAKLEY_CITY = "58330"
OLDTOWN_CITY = "58600"
ONAWAY_CITY = "58870"
OROFINO_CITY = "59320"
OSBURN_CITY = "59590"
OXFORD_CITY = "60040"
PARIS_CITY = "60580"
PARKER_CITY = "60760"
PARKLINE_CDP = "60880"
PARMA_CITY = "60940"
PAUL_CITY = "61210"
PAYETTE_CITY = "61300"
PECK_CITY = "61840"
PIERCE_CITY = "62740"
PINEHURST_CITY = "63100"
PLACERVILLE_CITY = "63550"
PLUMMER_CITY = "63910"
POCATELLO_CITY = "64090"
PONDERAY_CITY = "64450"
POST_FALLS_CITY = "64810"
POTLATCH_CITY = "64900"
PRESTON_CITY = "65260"
PRIEST_RIVER_CITY = "65530"
PRINCETON_CDP = "65620"
RATHDRUM_CITY = "66340"
REUBENS_CITY = "67150"
REXBURG_CITY = "67420"
RICHFIELD_CITY = "67600"
RIGBY_CITY = "67780"
RIGGINS_CITY = "67870"
RIRIE_CITY = "67960"
RIVERSIDE_CDP = "68230"
ROBERTS_CITY = "68500"
ROBIE_CREEK_CDP = "68545"
ROCKFORD_BAY_CDP = "68950"
ROCKFORD_CDP = "68860"
ROCKLAND_CITY = "69130"
RUPERT_CITY = "70660"
SALMON_CITY = "71650"
SANDPOINT_CITY = "72100"
SHELLEY_CITY = "73450"
SHOSHONE_CITY = "73900"
SILVERTON_CDP = "74440"
SMELTERVILLE_CITY = "75070"
SMITHS_FERRY_CDP = "75160"
SODA_SPRINGS_CITY = "75195"
SPENCER_CITY = "75970"
SPIRIT_LAKE_CITY = "76060"
ST_ANTHONY_CITY = "71020"
ST_CHARLES_CITY = "71110"
ST_MARIES_CITY = "71470"
STANLEY_CITY = "76780"
STAR_CITY = "76870"
STATE_LINE_CITY = "77050"
STITES_CITY = "77500"
SUGAR_CITY_CITY = "78040"
SUN_VALLEY_CITY = "78850"
SWAN_VALLEY_CITY = "79120"
SWEETWATER_CDP = "79300"
TENSED_CITY = "80200"
TETON_CITY = "80380"
TETONIA_CITY = "80470"
TROY_CITY = "82360"
TWIN_FALLS_CITY = "82810"
TYHEE_CDP = "83170"
UCON_CITY = "83350"
VICTOR_CITY = "84250"
VIOLA_CDP = "84430"
WALLACE_CITY = "84790"
WARDNER_CITY = "85240"
WARM_RIVER_CITY = "85420"
WEIPPE_CITY = "86050"
WEISER_CITY = "86140"
WENDELL_CITY = "86320"
WESTON_CITY = "87040"
WHITE_BIRD_CITY = "87310"
WILDER_CITY = "87670"
WINCHESTER_CITY = "87850"
WORLEY_CITY = "88480"
YELLOW_PINE_CDP = "88660"
