# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Wyoming."""


ALBANY = "001"
BIG_HORN = "003"
CAMPBELL = "005"
CARBON = "007"
CONVERSE = "009"
CROOK = "011"
FREMONT = "013"
GOSHEN = "015"
HOT_SPRINGS = "017"
JOHNSON = "019"
LARAMIE = "021"
LINCOLN = "023"
NATRONA = "025"
NIOBRARA = "027"
PARK = "029"
PLATTE = "031"
SHERIDAN = "033"
SUBLETTE = "035"
SWEETWATER = "037"
TETON = "039"
UINTA = "041"
WASHAKIE = "043"
WESTON = "045"
