# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in California."""


ALAMEDA = "001"
ALPINE = "003"
AMADOR = "005"
BUTTE = "007"
CALAVERAS = "009"
COLUSA = "011"
CONTRA_COSTA = "013"
DEL_NORTE = "015"
EL_DORADO = "017"
FRESNO = "019"
GLENN = "021"
HUMBOLDT = "023"
IMPERIAL = "025"
INYO = "027"
KERN = "029"
KINGS = "031"
LAKE = "033"
LASSEN = "035"
LOS_ANGELES = "037"
MADERA = "039"
MARIN = "041"
MARIPOSA = "043"
MENDOCINO = "045"
MERCED = "047"
MODOC = "049"
MONO = "051"
MONTEREY = "053"
NAPA = "055"
NEVADA = "057"
ORANGE = "059"
PLACER = "061"
PLUMAS = "063"
RIVERSIDE = "065"
SACRAMENTO = "067"
SAN_BENITO = "069"
SAN_BERNARDINO = "071"
SAN_DIEGO = "073"
SAN_FRANCISCO = "075"
SAN_JOAQUIN = "077"
SAN_LUIS_OBISPO = "079"
SAN_MATEO = "081"
SANTA_BARBARA = "083"
SANTA_CLARA = "085"
SANTA_CRUZ = "087"
SHASTA = "089"
SIERRA = "091"
SISKIYOU = "093"
SOLANO = "095"
SONOMA = "097"
STANISLAUS = "099"
SUTTER = "101"
TEHAMA = "103"
TRINITY = "105"
TULARE = "107"
TUOLUMNE = "109"
VENTURA = "111"
YOLO = "113"
YUBA = "115"
