# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Oregon."""


ADAIR_VILLAGE_CITY = "00275"
ADAMS_CITY = "00350"
ADRIAN_CITY = "00500"
ALBANY_CITY = "01000"
ALOHA_CDP = "01650"
ALPINE_CDP = "01700"
ALSEA_CDP = "01800"
ALTAMONT_CDP = "01850"
AMITY_CITY = "02000"
ANNEX_CDP = "02200"
ANTELOPE_CITY = "02250"
ARLINGTON_CITY = "02800"
ASHLAND_CITY = "03050"
ASTORIA_CITY = "03150"
ATHENA_CITY = "03200"
AUMSVILLE_CITY = "03250"
AURORA_CITY = "03300"
BAKER_CITY_CITY = "03650"
BANDON_CITY = "03800"
BANKS_CITY = "03850"
BARLOW_CITY = "04000"
BARNESDALE_CDP = "04125"
BARVIEW_CDP = "04400"
BAY_CITY_CITY = "04800"
BAYSHORE_CDP = "04850"
BAYSIDE_GARDENS_CDP = "04925"
BEATTY_CDP = "05150"
BEAVER_CDP = "05200"
BEAVER_MARSH_CDP = "05300"
BEAVERCREEK_CDP = "05250"
BEAVERTON_CITY = "05350"
BELLFOUNTAIN_CDP = "05700"
BEND_CITY = "05800"
BETHANY_CDP = "05950"
BIGGS_JUNCTION_CDP = "06400"
BLACK_BUTTE_RANCH_CDP = "06650"
BLODGETT_CDP = "06950"
BLY_CDP = "07150"
BOARDMAN_CITY = "07200"
BONANZA_TOWN = "07300"
BORING_CDP = "07550"
BROGAN_CDP = "08600"
BROOKINGS_CITY = "08650"
BROOKS_CDP = "08750"
BROWNSVILLE_CITY = "09050"
BULL_MOUNTAIN_CDP = "09535"
BUNKER_HILL_CDP = "09600"
BURNS_CITY = "09800"
BUTTE_FALLS_TOWN = "10050"
BUTTEVILLE_CDP = "10100"
CAMP_SHERMAN_CDP = "10550"
CANBY_CITY = "10750"
CANNON_BEACH_CITY = "10850"
CANYON_CITY_TOWN = "10950"
CANYONVILLE_CITY = "11000"
CAPE_MEARES_CDP = "11050"
CARLTON_CITY = "11150"
CASCADE_LOCKS_CITY = "11600"
CASCADIA_CDP = "11700"
CAVE_JUNCTION_CITY = "11850"
CAYUSE_CDP = "11900"
CEDAR_HILLS_CDP = "12050"
CEDAR_MILL_CDP = "12150"
CENTRAL_POINT_CITY = "12400"
CHEMULT_CDP = "12750"
CHENOWETH_CDP = "12800"
CHERRY_GROVE_CDP = "12850"
CHESHIRE_CDP = "13000"
CHILOQUIN_CITY = "13050"
CLATSKANIE_CITY = "13750"
CLOVERDALE_CDP = "14200"
COBURG_CITY = "14400"
COLUMBIA_CITY_CITY = "14750"
CONDON_CITY = "15000"
COOS_BAY_CITY = "15250"
COQUILLE_CITY = "15350"
CORNELIUS_CITY = "15550"
CORVALLIS_CITY = "15800"
COTTAGE_GROVE_CITY = "15950"
COVE_CITY = "16250"
CRABTREE_CDP = "16350"
CRANE_CDP = "16450"
CRAWFORDSVILLE_CDP = "16650"
CRESCENT_CDP = "16750"
CRESCENT_LAKE_CDP = "16800"
CRESWELL_CITY = "16950"
CROOKED_RIVER_RANCH_CDP = "16975"
CULVER_CITY = "17300"
DALLAS_CITY = "17700"
DAMASCUS_CDP = "17800"
DAYS_CREEK_CDP = "18150"
DAYTON_CITY = "18250"
DAYVILLE_TOWN = "18300"
DEER_ISLAND_CDP = "18450"
DEPOE_BAY_CITY = "18850"
DESCHUTES_RIVER_WOODS_CDP = "19020"
DETROIT_CITY = "19100"
DEXTER_CDP = "19250"
DILLARD_CDP = "19600"
DILLEY_CDP = "19650"
DONALD_CITY = "20100"
DRAIN_CITY = "20500"
DUFUR_CITY = "20900"
DUNDEE_CITY = "21050"
DUNES_CITY_CITY = "21150"
DUNTHORPE_CDP = "21215"
DURHAM_CITY = "21250"
EAGLE_CREST_CDP = "21450"
EAGLE_POINT_CITY = "21550"
ECHO_CITY = "22200"
ELGIN_CITY = "22550"
ELKTON_CITY = "22800"
ELMIRA_CDP = "23000"
ENTERPRISE_CITY = "23500"
EOLA_CDP = "23550"
ESTACADA_CITY = "23800"
EUGENE_CITY = "23850"
FAIR_OAKS_CDP = "24100"
FAIRVIEW_CDP = "24300"
FAIRVIEW_CITY = "24250"
FALCON_HEIGHTS_CDP = "24350"
FALLS_CITY_CITY = "24550"
FLORENCE_CITY = "26050"
FOOTS_CREEK_CDP = "26165"
FOREST_GROVE_CITY = "26200"
FORT_HILL_CDP = "26400"
FORT_KLAMATH_CDP = "26450"
FOSSIL_CITY = "26650"
FOUR_CORNERS_CDP = "26750"
GARDEN_HOME_WHITFORD_CDP = "27825"
GARDINER_CDP = "27850"
GARIBALDI_CITY = "28000"
GASTON_CITY = "28100"
GATES_CITY = "28200"
GEARHART_CITY = "28450"
GERVAIS_CITY = "28650"
GILCHRIST_CDP = "28800"
GLADSTONE_CITY = "29000"
GLASGOW_CDP = "29100"
GLENDALE_CITY = "29350"
GLIDE_CDP = "29750"
GOLD_BEACH_CITY = "29900"
GOLD_HILL_CITY = "29950"
GOPHER_FLATS_CDP = "30165"
GOVERNMENT_CAMP_CDP = "30250"
GRAND_RONDE_CDP = "30300"
GRANITE_CITY = "30500"
GRANTS_PASS_CITY = "30550"
GRASS_VALLEY_CITY = "30650"
GREEN_CDP = "30750"
GREEN_MEADOWS_CDP = "31115"
GREENHORN_CITY = "31050"
GRESHAM_CITY = "31250"
HAINES_CITY = "31600"
HALFWAY_CITY = "31650"
HALSEY_CITY = "31750"
HAPPY_VALLEY_CITY = "32050"
HARBOR_CDP = "32100"
HARPER_CDP = "32400"
HARRISBURG_CITY = "32550"
HAYESVILLE_CDP = "32850"
HEBO_CDP = "33100"
HECETA_BEACH_CDP = "33150"
HELIX_CITY = "33250"
HEPPNER_CITY = "33550"
HERMISTON_CITY = "33700"
HILLSBORO_CITY = "34100"
HINES_CITY = "34250"
HOLLEY_CDP = "34650"
HOOD_RIVER_CITY = "34900"
HUBBARD_CITY = "35450"
HUNTINGTON_CITY = "35700"
IDANHA_CITY = "35800"
IDAVILLE_CDP = "35850"
IMBLER_CITY = "36050"
INDEPENDENCE_CITY = "36150"
IONE_CITY = "36400"
IRRIGON_CITY = "36500"
ISLAND_CITY_CITY = "36750"
JACKSONVILLE_CITY = "37000"
JASPER_CDP = "37150"
JEFFERS_GARDENS_CDP = "37202"
JEFFERSON_CITY = "37250"
JENNINGS_LODGE_CDP = "37400"
JOHN_DAY_CITY = "37550"
JOHNSON_CITY_CITY = "37650"
JORDAN_VALLEY_CITY = "37850"
JOSEPH_CITY = "37900"
JUNCTION_CITY_CITY = "38000"
JUNIPER_CANYON_CDP = "38075"
JUNTURA_CDP = "38150"
KEIZER_CITY = "38500"
KENO_CDP = "38750"
KERBY_CDP = "38900"
KING_CITY_CITY = "39150"
KINGS_VALLEY_CDP = "39350"
KIRKPATRICK_CDP = "39566"
KLAMATH_FALLS_CITY = "39700"
KNAPPA_CDP = "39850"
LA_GRANDE_CITY = "40350"
LA_PINE_CITY = "41050"
LABISH_VILLAGE_CDP = "40050"
LACOMB_CDP = "40150"
LAFAYETTE_CITY = "40300"
LAKE_OSWEGO_CITY = "40550"
LAKESIDE_CITY = "40650"
LAKEVIEW_TOWN = "40700"
LANGLOIS_CDP = "40950"
LEBANON_CITY = "41650"
LEXINGTON_TOWN = "42200"
LINCOLN_BEACH_CDP = "42550"
LINCOLN_CITY_CITY = "42600"
LONEROCK_CITY = "43400"
LONG_CREEK_CITY = "43550"
LOOKINGGLASS_CDP = "43650"
LOSTINE_CITY = "43900"
LOWELL_CITY = "44050"
LYONS_CITY = "44300"
MADRAS_CITY = "45250"
MALIN_CITY = "45400"
MANZANITA_CITY = "45700"
MAPLETON_CDP = "45750"
MARCOLA_CDP = "45850"
MARION_CDP = "45900"
MARLENE_VILLAGE_CDP = "46100"
MAUPIN_CITY = "46500"
MAYWOOD_PARK_CITY = "46730"
MCKAY_CDP = "44625"
MCMINNVILLE_CITY = "45000"
MEACHAM_CDP = "46800"
MEDFORD_CITY = "47000"
MEHAMA_CDP = "47300"
MELROSE_CDP = "47350"
MERLIN_CDP = "47650"
MERRILL_CITY = "47700"
METOLIUS_CITY = "47750"
METZGER_CDP = "47800"
MILL_CITY_CITY = "48150"
MILLERSBURG_CITY = "48300"
MILTON_FREEWATER_CITY = "48600"
MILWAUKIE_CITY = "48650"
MISSION_CDP = "49000"
MITCHELL_CITY = "49150"
MOLALLA_CITY = "49450"
MONMOUTH_CITY = "49550"
MONROE_CITY = "49600"
MONUMENT_CITY = "49750"
MORO_CITY = "50000"
MOSIER_CITY = "50050"
MOUNT_ANGEL_CITY = "50150"
MOUNT_HOOD_CDP = "50200"
MOUNT_HOOD_VILLAGES_CDP = "50236"
MOUNT_VERNON_CITY = "50250"
MULINO_CDP = "50450"
MYRTLE_CREEK_CITY = "50950"
MYRTLE_POINT_CITY = "51050"
NEAHKAHNIE_CDP = "51450"
NEHALEM_CITY = "51700"
NEOTSU_CDP = "51900"
NESIKA_BEACH_CDP = "51950"
NESKOWIN_CDP = "52000"
NETARTS_CDP = "52050"
NEW_HOPE_CDP = "52275"
NEW_PINE_CREEK_CDP = "52400"
NEWBERG_CITY = "52100"
NEWPORT_CITY = "52450"
NORTH_BEND_CITY = "53000"
NORTH_PLAINS_CITY = "53150"
NORTH_POWDER_CITY = "53300"
NYSSA_CITY = "53750"
OBRIEN_CDP = "54350"
OAK_GROVE_CDP = "53900"
OAK_HILLS_CDP = "53988"
OAKLAND_CITY = "54000"
OAKRIDGE_CITY = "54100"
OATFIELD_CDP = "54325"
OCEANSIDE_CDP = "54450"
OCHOCO_WEST_CDP = "54527"
ODELL_CDP = "54550"
ONTARIO_CITY = "54900"
OREGON_CITY_CITY = "55200"
OREGON_SHORES_CDP = "55268"
ORIENT_CDP = "55500"
PACIFIC_CITY_CDP = "56150"
PAISLEY_CITY = "56250"
PARKDALE_CDP = "56500"
PENDLETON_CITY = "57150"
PEORIA_CDP = "57300"
PHILOMATH_CITY = "57450"
PHOENIX_CITY = "57500"
PILOT_ROCK_CITY = "57650"
PINE_GROVE_CDP = "57850"
PINE_HOLLOW_CDP = "57875"
PISTOL_RIVER_CDP = "58050"
PLEASANT_VALLEY_CDP = "58500"
PLUSH_CDP = "58550"
PORT_ORFORD_CITY = "59250"
PORTLAND_CITY = "59000"
POWERS_CITY = "59600"
PRAIRIE_CITY_CITY = "59650"
PRESCOTT_CITY = "59750"
PRINEVILLE_LAKE_ACRES_CDP = "59916"
PRINEVILLE_CITY = "59850"
PRONGHORN_CDP = "60070"
PROSPECT_CDP = "60100"
RAINIER_CITY = "60850"
RALEIGH_HILLS_CDP = "60900"
REDMOND_CITY = "61200"
REDWOOD_CDP = "61250"
REEDSPORT_CITY = "61300"
RHODODENDRON_CDP = "61550"
RICHLAND_CITY = "61700"
RICKREALL_CDP = "61800"
RIDDLE_CITY = "61850"
RIVER_POINT_CDP = "62292"
RIVER_ROAD_CDP = "62300"
RIVERGROVE_CITY = "62250"
RIVERSIDE_CDP = "62412"
ROCKAWAY_BEACH_CITY = "62900"
ROCKCREEK_CDP = "63010"
ROCKY_POINT_CDP = "63250"
ROGUE_RIVER_CITY = "63450"
ROSE_LODGE_CDP = "63800"
ROSEBURG_NORTH_CDP = "63660"
ROSEBURG_CITY = "63650"
ROWENA_CDP = "63950"
RUCH_CDP = "64150"
RUFUS_CITY = "64200"
RUNNING_Y_RANCH_CDP = "64282"
SALEM_CITY = "64900"
SAN_MARINE_CDP = "65300"
SANDY_CITY = "65250"
SANTA_CLARA_CDP = "65400"
SAUNDERS_LAKE_CDP = "65450"
SCAPPOOSE_CITY = "65500"
SCIO_CITY = "65650"
SCOTTS_MILLS_CITY = "65800"
SEASIDE_CITY = "65950"
SELMA_CDP = "66150"
SENECA_CITY = "66200"
SEVENTH_MOUNTAIN_CDP = "66385"
SHADY_COVE_CITY = "66550"
SHANIKO_CITY = "66700"
SHEDD_CDP = "66900"
SHERIDAN_CITY = "67050"
SHERWOOD_CITY = "67100"
SILETZ_CITY = "67500"
SILVER_LAKE_CDP = "67600"
SILVERTON_CITY = "67650"
SISTERS_CITY = "67950"
SODAVILLE_CITY = "68550"
SOUTH_LEBANON_CDP = "68875"
SPORTSMANS_PARK_CDP = "69387"
SPRAGUE_RIVER_CDP = "69400"
SPRAY_TOWN = "69450"
SPRINGFIELD_CITY = "69600"
ST_HELENS_CITY = "64600"
ST_PAUL_CITY = "64850"
STAFFORD_CDP = "69800"
STANFIELD_CITY = "69900"
STAYTON_CITY = "70200"
SUBLIMITY_CITY = "70700"
SUMMERVILLE_TOWN = "70850"
SUMMIT_CDP = "70870"
SUMPTER_CITY = "71000"
SUNRIVER_CDP = "71250"
SUTHERLIN_CITY = "71650"
SVENSEN_CDP = "71800"
SWEET_HOME_CITY = "71950"
TAKILMA_CDP = "72400"
TALENT_CITY = "72500"
TANGENT_CITY = "72600"
TERREBONNE_CDP = "72800"
TETHEROW_CDP = "72820"
THE_DALLES_CITY = "72950"
THREE_RIVERS_CDP = "73225"
TIGARD_CITY = "73650"
TILLAMOOK_CITY = "73700"
TOLEDO_CITY = "74000"
TRAIL_CDP = "74400"
TRENT_CDP = "74550"
TRI_CITY_CDP = "74650"
TROUTDALE_CITY = "74850"
TUALATIN_CITY = "74950"
TUMALO_CDP = "75050"
TURNER_CITY = "75150"
TUTUILLA_CDP = "75185"
TYGH_VALLEY_CDP = "75500"
UKIAH_CITY = "75550"
UMAPINE_CDP = "75600"
UMATILLA_CITY = "75650"
UNION_CITY = "75850"
UNITY_CITY = "76250"
VALE_CITY = "76600"
VENETA_CITY = "77050"
VERNONIA_CITY = "77250"
WALDPORT_CITY = "78000"
WALLOWA_LAKE_CDP = "78160"
WALLOWA_CITY = "78150"
WAMIC_CDP = "78300"
WARM_SPRINGS_CDP = "78600"
WARREN_CDP = "78800"
WARRENTON_CITY = "78900"
WASCO_CITY = "78950"
WATERLOO_TOWN = "79050"
WEDDERBURN_CDP = "79500"
WEST_HAVEN_SYLVAN_CDP = "80025"
WEST_LINN_CITY = "80150"
WEST_SCIO_CDP = "80750"
WEST_SLOPE_CDP = "80900"
WESTFIR_CITY = "79950"
WESTON_CITY = "80350"
WESTPORT_CDP = "80400"
WHEELER_CITY = "81300"
WHITE_CITY_CDP = "81450"
WILLAMINA_CITY = "82350"
WILLIAMS_CDP = "82450"
WILSONVILLE_CITY = "82800"
WIMER_CDP = "82850"
WINCHESTER_BAY_CDP = "83050"
WINSTON_CITY = "83400"
WOOD_VILLAGE_CITY = "83950"
WOODBURN_CITY = "83750"
YACHATS_CITY = "84200"
YAMHILL_CITY = "84250"
YONCALLA_CITY = "84600"
