# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Maryland."""


ABERDEEN_PROVING_GROUND_CDP = "00175"
ABERDEEN_CITY = "00125"
ABINGDON_CDP = "00200"
ACCIDENT_TOWN = "00225"
ACCOKEEK_CDP = "00250"
ADAMSTOWN_CDP = "00350"
ADELPHI_CDP = "00400"
ALGONQUIN_CDP = "00712"
ALLEN_CDP = "00800"
ANDREWS_AFB_CDP = "01450"
ANNAPOLIS_NECK_CDP = "01635"
ANNAPOLIS_CITY = "01600"
ANTIETAM_CDP = "01750"
AQUASCO_CDP = "01925"
ARBUTUS_CDP = "01975"
ARDEN_ON_THE_SEVERN_CDP = "02025"
ARNOLD_CDP = "02275"
ASHTON_SANDY_SPRING_CDP = "02762"
ASPEN_HILL_CDP = "02825"
BADEN_CDP = "03500"
BAGTOWN_CDP = "03514"
BAKERSVILLE_CDP = "03575"
BALLENGER_CREEK_CDP = "03800"
BALTIMORE_HIGHLANDS_CDP = "04050"
BALTIMORE_CITY = "04000"
BARCLAY_TOWN = "04250"
BARNESVILLE_TOWN = "04475"
BARRELVILLE_CDP = "04525"
BARTON_TOWN = "04625"
BARTONSVILLE_CDP = "04650"
BEAVER_CREEK_CDP = "05250"
BEL_AIR_CDP = "05525"
BEL_AIR_NORTH_CDP = "05825"
BEL_AIR_SOUTH_CDP = "05950"
BEL_AIR_TOWN = "05550"
BELTSVILLE_CDP = "06400"
BENEDICT_CDP = "06550"
BENSVILLE_CDP = "06662"
BERLIN_TOWN = "06800"
BERWYN_HEIGHTS_TOWN = "06925"
BETHESDA_CDP = "07125"
BETTERTON_TOWN = "07200"
BIER_CDP = "07285"
BIG_POOL_CDP = "07375"
BIG_SPRING_CDP = "07400"
BISHOPVILLE_CDP = "07625"
BIVALVE_CDP = "07675"
BLADENSBURG_TOWN = "07850"
BLOOMINGTON_CDP = "08050"
BOONSBORO_TOWN = "08625"
BOWIE_CITY = "08775"
BOWLEYS_QUARTERS_CDP = "08800"
BOWLING_GREEN_CDP = "08850"
BOWMANS_ADDITION_CDP = "08862"
BRADDOCK_HEIGHTS_CDP = "09100"
BRANDYWINE_CDP = "09325"
BREATHEDSVILLE_CDP = "09400"
BRENTWOOD_TOWN = "09500"
BROCK_HALL_CDP = "10150"
BROOKEVILLE_TOWN = "10225"
BROOKLYN_PARK_CDP = "10475"
BROOKMONT_CDP = "10500"
BROOKVIEW_TOWN = "10575"
BROOMES_ISLAND_CDP = "10650"
BROWN_STATION_CDP = "10737"
BROWNSVILLE_CDP = "10800"
BRUNSWICK_CITY = "10900"
BRYANS_ROAD_CDP = "10925"
BRYANTOWN_CDP = "10950"
BUCKEYSTOWN_CDP = "11050"
BURKITTSVILLE_TOWN = "11400"
BURNT_MILLS_CDP = "11550"
BURTONSVILLE_CDP = "11750"
BUTLERTOWN_CDP = "11900"
CABIN_JOHN_CDP = "12075"
CALIFORNIA_CDP = "12150"
CALLAWAY_CDP = "12175"
CALVERT_BEACH_CDP = "12300"
CALVERTON_CDP = "12350"
CAMBRIDGE_CITY = "12400"
CAMP_SPRINGS_CDP = "12600"
CAPE_ST_CLAIRE_CDP = "12912"
CAPITOL_HEIGHTS_TOWN = "13000"
CARLOS_CDP = "13225"
CARNEY_CDP = "13325"
CATONSVILLE_CDP = "14125"
CAVETOWN_CDP = "14225"
CEARFOSS_CDP = "14300"
CECILTON_TOWN = "14325"
CEDAR_HEIGHTS_CDP = "14550"
CEDARVILLE_CDP = "14800"
CENTREVILLE_TOWN = "14950"
CHANCE_CDP = "15075"
CHARLESTOWN_TOWN = "15400"
CHARLOTTE_HALL_CDP = "15475"
CHARLTON_CDP = "15500"
CHESAPEAKE_BEACH_TOWN = "15925"
CHESAPEAKE_CITY_TOWN = "15950"
CHESAPEAKE_LANDING_CDP = "16025"
CHESAPEAKE_RANCH_ESTATES_CDP = "16050"
CHESTER_CDP = "16125"
CHESTERTOWN_TOWN = "16225"
CHEVERLY_TOWN = "16550"
CHEVY_CHASE_CDP = "16625"
CHEVY_CHASE_SECTION_FIVE_VILLAGE = "16720"
CHEVY_CHASE_SECTION_THREE_VILLAGE = "16730"
CHEVY_CHASE_VIEW_TOWN = "16775"
CHEVY_CHASE_VILLAGE_TOWN = "16787"
CHEVY_CHASE_TOWN = "16620"
CHEWSVILLE_CDP = "16800"
CHILLUM_CDP = "16875"
CHOPTANK_CDP = "17000"
CHURCH_CREEK_TOWN = "17050"
CHURCH_HILL_TOWN = "17100"
CLARKSBURG_CDP = "17350"
CLARYSVILLE_CDP = "17475"
CLEAR_SPRING_TOWN = "17600"
CLINTON_CDP = "17900"
CLOVERLY_CDP = "18150"
COBB_ISLAND_CDP = "18200"
COCKEYSVILLE_CDP = "18250"
COLESVILLE_CDP = "18475"
COLLEGE_PARK_CITY = "18750"
COLMAR_MANOR_TOWN = "18850"
COLUMBIA_CDP = "19125"
CORAL_HILLS_CDP = "19825"
CORDOVA_CDP = "19900"
CORRIGANVILLE_CDP = "19975"
COTTAGE_CITY_TOWN = "20050"
CRELLIN_CDP = "20500"
CRESAPTOWN_CDP = "20525"
CRISFIELD_CITY = "20775"
CROFTON_CDP = "20875"
CROOM_CDP = "20925"
CROWNSVILLE_CDP = "21075"
CRUMPTON_CDP = "21150"
CUMBERLAND_CITY = "21325"
DAMASCUS_CDP = "21475"
DAMES_QUARTER_CDP = "21550"
DANVILLE_CDP = "21675"
DARGAN_CDP = "21750"
DARLINGTON_CDP = "21800"
DARNESTOWN_CDP = "21825"
DAWSON_CDP = "21925"
DEAL_ISLAND_CDP = "22100"
DEALE_CDP = "22050"
DEER_PARK_TOWN = "22275"
DELMAR_TOWN = "22600"
DENTON_TOWN = "22725"
DERWOOD_CDP = "22775"
DETMOLD_CDP = "22825"
DISTRICT_HEIGHTS_CITY = "23025"
DOWNSVILLE_CDP = "23500"
DRUM_POINT_CDP = "23700"
DUNDALK_CDP = "23975"
DUNKIRK_CDP = "24050"
EAGLE_HARBOR_TOWN = "24200"
EAKLES_MILL_CDP = "24250"
EAST_NEW_MARKET_TOWN = "24450"
EAST_RIVERDALE_CDP = "24650"
EASTON_TOWN = "24475"
ECKHART_MINES_CDP = "24825"
EDEN_CDP = "24850"
EDESVILLE_CDP = "24925"
EDGEMERE_CDP = "24950"
EDGEMONT_CDP = "25000"
EDGEWATER_CDP = "25050"
EDGEWOOD_CDP = "25150"
EDMONSTON_TOWN = "25425"
ELDERSBURG_CDP = "25575"
ELDORADO_TOWN = "25600"
ELKRIDGE_CDP = "25750"
ELKTON_TOWN = "25800"
ELLERSLIE_CDP = "25925"
ELLICOTT_CITY_CDP = "26000"
ELLIOTT_CDP = "26025"
EMMITSBURG_TOWN = "26200"
ERNSTVILLE_CDP = "26550"
ESSEX_CDP = "26600"
FAIRLAND_CDP = "27250"
FAIRLEE_CDP = "27325"
FAIRMOUNT_CDP = "27375"
FAIRMOUNT_HEIGHTS_TOWN = "27400"
FAIRPLAY_CDP = "27425"
FAIRVIEW_CDP = "27500"
FAIRWOOD_CDP = "27580"
FALLSTON_CDP = "27700"
FEDERALSBURG_TOWN = "27900"
FERNDALE_CDP = "28075"
FINZEL_CDP = "28275"
FISHING_CREEK_CDP = "28300"
FLINTSTONE_CDP = "28425"
FLOWER_HILL_CDP = "28512"
FOREST_GLEN_CDP = "28640"
FOREST_HEIGHTS_TOWN = "28725"
FORESTVILLE_CDP = "29000"
FORT_MEADE_CDP = "29400"
FORT_RITCHIE_CDP = "29450"
FORT_WASHINGTON_CDP = "29525"
FOUNTAINHEAD_ORCHARD_HILLS_CDP = "29712"
FOUR_CORNERS_CDP = "29790"
FRANKLIN_CDP = "30100"
FREDERICK_CITY = "30325"
FRENCHTOWN_RUMBLY_CDP = "30567"
FRIENDLY_CDP = "30575"
FRIENDSHIP_CDP = "30650"
FRIENDSHIP_HEIGHTS_VILLAGE_CDP = "30800"
FRIENDSVILLE_TOWN = "30850"
FROSTBURG_CITY = "30900"
FRUITLAND_CITY = "30950"
FULTON_CDP = "31025"
FUNKSTOWN_TOWN = "31100"
GAITHERSBURG_CITY = "31175"
GALENA_TOWN = "31225"
GALESTOWN_TOWN = "31250"
GALESVILLE_CDP = "31275"
GAMBRILLS_CDP = "31350"
GAPLAND_CDP = "31400"
GARRETT_PARK_TOWN = "31525"
GARRETTS_MILL_CDP = "31575"
GARRISON_CDP = "31625"
GEORGETOWN_CDP = "31875"
GERMANTOWN_CDP = "32025"
GILMORE_CDP = "32175"
GIRDLETREE_CDP = "32250"
GLASSMANOR_CDP = "32350"
GLEN_BURNIE_CDP = "32650"
GLEN_ECHO_TOWN = "32900"
GLENARDEN_CITY = "32500"
GLENMONT_CDP = "33250"
GLENN_DALE_CDP = "33400"
GOLDEN_BEACH_CDP = "33850"
GOLDSBORO_TOWN = "33950"
GORMAN_CDP = "34150"
GRACEHAM_CDP = "34350"
GRAHAMTOWN_CDP = "34425"
GRANTSVILLE_TOWN = "34525"
GRASONVILLE_CDP = "34550"
GREEN_VALLEY_CDP = "35412"
GREENBELT_CITY = "34775"
GREENSBORO_TOWN = "35200"
GREENSBURG_CDP = "35225"
HAGERSTOWN_CITY = "36075"
HALFWAY_CDP = "36125"
HAMPSTEAD_TOWN = "36500"
HAMPTON_CDP = "36512"
HANCOCK_TOWN = "36600"
HAVRE_DE_GRACE_CITY = "37600"
HEBRON_TOWN = "37875"
HENDERSON_TOWN = "37925"
HERALD_HARBOR_CDP = "38025"
HIGHFIELD_CASCADE_CDP = "38437"
HIGHLAND_BEACH_TOWN = "38500"
HIGHLAND_CDP = "38475"
HILLANDALE_CDP = "38850"
HILLCREST_HEIGHTS_CDP = "38975"
HILLSBORO_TOWN = "39175"
HONEYGO_CDP = "40200"
HUGHESVILLE_CDP = "40700"
HUNTINGTOWN_CDP = "41025"
HURLOCK_TOWN = "41125"
HUTTON_CDP = "41175"
HYATTSVILLE_CITY = "41250"
ILCHESTER_CDP = "41475"
INDIAN_HEAD_TOWN = "41500"
INDIAN_SPRINGS_CDP = "41700"
JARRETTSVILLE_CDP = "42325"
JEFFERSON_CDP = "42350"
JENNINGS_CDP = "42450"
JESSUP_CDP = "42550"
JESTERVILLE_CDP = "42575"
JOPPATOWNE_CDP = "42875"
JUGTOWN_CDP = "42950"
KEEDYSVILLE_TOWN = "43100"
KEMP_MILL_CDP = "43200"
KEMPS_MILL_CDP = "43280"
KENNEDYVILLE_CDP = "43475"
KENSINGTON_TOWN = "43500"
KENT_NARROWS_CDP = "43725"
KETTERING_CDP = "43900"
KINGSTOWN_CDP = "44325"
KINGSVILLE_CDP = "44350"
KITZMILLER_TOWN = "44450"
KLONDIKE_CDP = "44525"
KONTERRA_CDP = "44715"
LA_PLATA_TOWN = "45750"
LA_VALE_CDP = "46075"
LAKE_ARBOR_CDP = "44817"
LAKE_SHORE_CDP = "44975"
LANDOVER_CDP = "45325"
LANDOVER_HILLS_TOWN = "45400"
LANGLEY_PARK_CDP = "45525"
LANHAM_CDP = "45550"
LANSDOWNE_CDP = "45650"
LARGO_CDP = "45825"
LAUREL_CITY = "45900"
LAYHILL_CDP = "46150"
LAYTONSVILLE_TOWN = "46250"
LEISURE_WORLD_CDP = "46375"
LEITERSBURG_CDP = "46400"
LEONARDTOWN_TOWN = "46475"
LEWISTOWN_CDP = "46650"
LEXINGTON_PARK_CDP = "46725"
LIBERTYTOWN_CDP = "46800"
LINGANORE_CDP = "47040"
LINTHICUM_CDP = "47125"
LISBON_CDP = "47250"
LITTLE_ORLEANS_CDP = "47275"
LOCH_LYNN_HEIGHTS_TOWN = "47525"
LOCHEARN_CDP = "47450"
LONACONING_TOWN = "47875"
LONG_BEACH_CDP = "48025"
LUKE_TOWN = "48775"
LUSBY_CDP = "48800"
LUTHERVILLE_CDP = "48875"
MADISON_CDP = "49700"
MANCHESTER_TOWN = "49950"
MAPLEVILLE_CDP = "50375"
MARDELA_SPRINGS_TOWN = "50525"
MARLBORO_MEADOWS_CDP = "50680"
MARLBORO_VILLAGE_CDP = "50685"
MARLOW_HEIGHTS_CDP = "50750"
MARLTON_CDP = "50775"
MARTINS_ADDITIONS_VILLAGE = "50965"
MARYDEL_TOWN = "51025"
MARYLAND_CITY_CDP = "51075"
MARYLAND_PARK_CDP = "51125"
MAUGANSVILLE_CDP = "51425"
MAYO_CDP = "51575"
MAYS_CHAPEL_CDP = "51587"
MCCOOLE_CDP = "49325"
MECHANICSVILLE_CDP = "51800"
MELWOOD_CDP = "51940"
MERCERSVILLE_CDP = "51945"
MIDDLE_RIVER_CDP = "52300"
MIDDLEBURG_CDP = "52225"
MIDDLETOWN_TOWN = "52425"
MIDLAND_TOWN = "52475"
MIDLOTHIAN_CDP = "52525"
MILFORD_MILL_CDP = "52562"
MILLINGTON_TOWN = "52825"
MITCHELLVILLE_CDP = "52975"
MONROVIA_CDP = "53100"
MONTGOMERY_VILLAGE_CDP = "53325"
MORNINGSIDE_TOWN = "53625"
MOSCOW_CDP = "53700"
MOUNT_AETNA_CDP = "53750"
MOUNT_AIRY_TOWN = "53875"
MOUNT_BRIAR_CDP = "53925"
MOUNT_LENA_CDP = "54125"
MOUNT_RAINIER_CITY = "54275"
MOUNT_SAVAGE_CDP = "54325"
MOUNT_VERNON_CDP = "54375"
MOUNTAIN_LAKE_PARK_TOWN = "53800"
MYERSVILLE_TOWN = "54875"
NANTICOKE_ACRES_CDP = "54930"
NANTICOKE_CDP = "54925"
NATIONAL_CDP = "55000"
NATIONAL_HARBOR_CDP = "55018"
NAVAL_ACADEMY_CDP = "55050"
NEW_CARROLLTON_CITY = "55400"
NEW_MARKET_TOWN = "55650"
NEW_WINDSOR_TOWN = "55925"
NEWARK_CDP = "55325"
NIKEP_CDP = "55950"
NORTH_BEACH_TOWN = "56300"
NORTH_BETHESDA_CDP = "56337"
NORTH_BRENTWOOD_TOWN = "56375"
NORTH_CHEVY_CHASE_VILLAGE = "56400"
NORTH_EAST_TOWN = "56450"
NORTH_KENSINGTON_CDP = "56712"
NORTH_LAUREL_CDP = "56725"
NORTH_POTOMAC_CDP = "56875"
OAKLAND_TOWN = "57650"
OCEAN_CDP = "58215"
OCEAN_CITY_TOWN = "58225"
OCEAN_PINES_CDP = "58275"
ODENTON_CDP = "58300"
OLDTOWN_CDP = "58775"
OLNEY_CDP = "58900"
OVERLEA_CDP = "59325"
OWINGS_CDP = "59375"
OWINGS_MILLS_CDP = "59425"
OXFORD_TOWN = "59450"
OXON_HILL_CDP = "59500"
PARAMOUNT_LONG_MEADOW_CDP = "59787"
PARKVILLE_CDP = "60275"
PAROLE_CDP = "60325"
PARSONSBURG_CDP = "60425"
PASADENA_CDP = "60475"
PECKTONVILLE_CDP = "60770"
PEPPERMILL_VILLAGE_CDP = "60950"
PERRY_HALL_CDP = "60975"
PERRYMAN_CDP = "61075"
PERRYVILLE_TOWN = "61150"
PIKESVILLE_CDP = "61400"
PINESBURG_CDP = "61700"
PINEY_POINT_CDP = "61875"
PITTSVILLE_TOWN = "62025"
PLEASANT_GROVE_CDP = "62100"
PLEASANT_HILLS_CDP = "62175"
POCOMOKE_CITY_CITY = "62475"
POINT_OF_ROCKS_CDP = "62575"
POMFRET_CDP = "62675"
PONDSVILLE_CDP = "62775"
POOLESVILLE_TOWN = "62850"
PORT_DEPOSIT_TOWN = "63075"
PORT_TOBACCO_VILLAGE_TOWN = "63225"
POTOMAC_CDP = "63300"
POTOMAC_HEIGHTS_CDP = "63375"
POTOMAC_PARK_CDP = "63425"
POWELLVILLE_CDP = "63725"
PRESTON_TOWN = "63825"
PRINCE_FREDERICK_CDP = "63950"
PRINCESS_ANNE_TOWN = "64000"
PYLESVILLE_CDP = "64375"
QUANTICO_CDP = "64475"
QUEEN_ANNE_CDP = "64495"
QUEEN_ANNE_TOWN = "64500"
QUEENSLAND_CDP = "64568"
QUEENSTOWN_TOWN = "64600"
RANDALLSTOWN_CDP = "64950"
RAWLINGS_CDP = "65150"
REDLAND_CDP = "65312"
REID_CDP = "65550"
REISTERSTOWN_CDP = "65600"
RIDGELY_TOWN = "66000"
RINGGOLD_CDP = "66150"
RISING_SUN_TOWN = "66275"
RIVA_CDP = "66400"
RIVERDALE_PARK_TOWN = "66635"
RIVERSIDE_CDP = "66762"
RIVIERA_BEACH_CDP = "66850"
ROBINWOOD_CDP = "67000"
ROCK_HALL_TOWN = "67400"
ROCK_POINT_CDP = "67500"
ROCKVILLE_CITY = "67675"
ROHRERSVILLE_CDP = "67950"
ROMANCOKE_CDP = "68265"
ROSARYVILLE_CDP = "68300"
ROSEDALE_CDP = "68400"
ROSEMONT_VILLAGE = "68600"
ROSSVILLE_CDP = "68700"
SABILLASVILLE_CDP = "69200"
SALISBURY_CITY = "69925"
SAN_MAR_CDP = "70300"
SANDY_HOOK_CDP = "70175"
SAVAGE_CDP = "70475"
SCAGGSVILLE_CDP = "70525"
SEABROOK_CDP = "70775"
SEAT_PLEASANT_CITY = "70850"
SECRETARY_TOWN = "70900"
SEVERN_CDP = "71150"
SEVERNA_PARK_CDP = "71200"
SHADY_SIDE_CDP = "71450"
SHAFT_CDP = "71460"
SHARPSBURG_TOWN = "71600"
SHARPTOWN_TOWN = "71650"
SILVER_HILL_CDP = "72350"
SILVER_SPRING_CDP = "72450"
SMITH_ISLAND_CDP = "72887"
SMITHSBURG_TOWN = "72900"
SNOW_HILL_TOWN = "73075"
SOLOMONS_CDP = "73325"
SOMERSET_TOWN = "73350"
SOUTH_KENSINGTON_CDP = "73600"
SOUTH_LAUREL_CDP = "73650"
SPENCERVILLE_CDP = "74050"
SPRING_GAP_CDP = "74350"
SPRING_RIDGE_CDP = "74560"
SPRINGDALE_CDP = "74282"
ST_GEORGE_ISLAND_CDP = "69425"
ST_JAMES_CDP = "69550"
ST_LEONARD_CDP = "69675"
ST_MICHAELS_TOWN = "69825"
STEVENSVILLE_CDP = "75025"
STILL_POND_CDP = "75150"
STOCKTON_CDP = "75200"
SUDLERSVILLE_TOWN = "75650"
SUITLAND_CDP = "75725"
SUMMERFIELD_CDP = "75810"
SWANTON_CDP = "76450"
SYKESVILLE_TOWN = "76550"
TAKOMA_PARK_CITY = "76650"
TALL_TIMBERS_CDP = "76675"
TANEYTOWN_CITY = "76725"
TAYLORS_ISLAND_CDP = "76925"
TEMPLE_HILLS_CDP = "77100"
TEMPLEVILLE_TOWN = "77200"
TEN_MILE_CREEK_CDP = "77262"
THURMONT_TOWN = "77825"
TILGHMAN_ISLAND_CDP = "77912"
TILGHMANTON_CDP = "77925"
TIMONIUM_CDP = "78050"
TOLCHESTER_CDP = "78120"
TOWSON_CDP = "78425"
TRAPPE_TOWN = "78575"
TRAVILAH_CDP = "78650"
TREGO_ROHRERSVILLE_STATION_CDP = "78705"
TYASKIN_CDP = "79225"
UNION_BRIDGE_TOWN = "79350"
UNIVERSITY_PARK_TOWN = "79675"
UPPER_MARLBORO_TOWN = "79875"
URBANA_CDP = "79900"
VALE_SUMMIT_CDP = "80075"
VIENNA_TOWN = "80600"
WALDORF_CDP = "81175"
WALKER_MILL_CDP = "81250"
WALKERSVILLE_TOWN = "81275"
WASHINGTON_GROVE_TOWN = "81675"
WATERVIEW_CDP = "81925"
WEST_DENTON_CDP = "82625"
WEST_LAUREL_CDP = "83025"
WEST_OCEAN_CITY_CDP = "83225"
WEST_POCOMOKE_CDP = "83337"
WESTERNPORT_TOWN = "82750"
WESTMINSTER_CITY = "83100"
WESTPHALIA_CDP = "83290"
WHALEYVILLE_CDP = "83746"
WHEATON_CDP = "83775"
WHITE_MARSH_CDP = "84350"
WHITE_OAK_CDP = "84375"
WHITEHAVEN_CDP = "84225"
WILDEWOOD_CDP = "84784"
WILLARDS_TOWN = "84950"
WILLIAMSPORT_TOWN = "85100"
WILLISTON_CDP = "85175"
WILSON_CONOCOCHEAGUE_CDP = "85395"
WOODLAND_CDP = "86275"
WOODLAWN_CDP_BALTIMORE_COUNTY = "86475"
WOODLAWN_CDP_PRINCE_GEORGES_COUNTY = "86525"
WOODMORE_CDP = "86710"
WOODSBORO_TOWN = "86750"
WORTON_CDP = "87000"
YARROWSBURG_CDP = "87150"
ZIHLMAN_CDP = "87275"
