# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Kentucky."""


ADAIR = "001"
ALLEN = "003"
ANDERSON = "005"
BALLARD = "007"
BARREN = "009"
BATH = "011"
BELL = "013"
BOONE = "015"
BOURBON = "017"
BOYD = "019"
BOYLE = "021"
BRACKEN = "023"
BREATHITT = "025"
BRECKINRIDGE = "027"
BULLITT = "029"
BUTLER = "031"
CALDWELL = "033"
CALLOWAY = "035"
CAMPBELL = "037"
CARLISLE = "039"
CARROLL = "041"
CARTER = "043"
CASEY = "045"
CHRISTIAN = "047"
CLARK = "049"
CLAY = "051"
CLINTON = "053"
CRITTENDEN = "055"
CUMBERLAND = "057"
DAVIESS = "059"
EDMONSON = "061"
ELLIOTT = "063"
ESTILL = "065"
FAYETTE = "067"
FLEMING = "069"
FLOYD = "071"
FRANKLIN = "073"
FULTON = "075"
GALLATIN = "077"
GARRARD = "079"
GRANT = "081"
GRAVES = "083"
GRAYSON = "085"
GREEN = "087"
GREENUP = "089"
HANCOCK = "091"
HARDIN = "093"
HARLAN = "095"
HARRISON = "097"
HART = "099"
HENDERSON = "101"
HENRY = "103"
HICKMAN = "105"
HOPKINS = "107"
JACKSON = "109"
JEFFERSON = "111"
JESSAMINE = "113"
JOHNSON = "115"
KENTON = "117"
KNOTT = "119"
KNOX = "121"
LARUE = "123"
LAUREL = "125"
LAWRENCE = "127"
LEE = "129"
LESLIE = "131"
LETCHER = "133"
LEWIS = "135"
LINCOLN = "137"
LIVINGSTON = "139"
LOGAN = "141"
LYON = "143"
MADISON = "151"
MAGOFFIN = "153"
MARION = "155"
MARSHALL = "157"
MARTIN = "159"
MASON = "161"
MCCRACKEN = "145"
MCCREARY = "147"
MCLEAN = "149"
MEADE = "163"
MENIFEE = "165"
MERCER = "167"
METCALFE = "169"
MONROE = "171"
MONTGOMERY = "173"
MORGAN = "175"
MUHLENBERG = "177"
NELSON = "179"
NICHOLAS = "181"
OHIO = "183"
OLDHAM = "185"
OWEN = "187"
OWSLEY = "189"
PENDLETON = "191"
PERRY = "193"
PIKE = "195"
POWELL = "197"
PULASKI = "199"
ROBERTSON = "201"
ROCKCASTLE = "203"
ROWAN = "205"
RUSSELL = "207"
SCOTT = "209"
SHELBY = "211"
SIMPSON = "213"
SPENCER = "215"
TAYLOR = "217"
TODD = "219"
TRIGG = "221"
TRIMBLE = "223"
UNION = "225"
WARREN = "227"
WASHINGTON = "229"
WAYNE = "231"
WEBSTER = "233"
WHITLEY = "235"
WOLFE = "237"
WOODFORD = "239"
